/***************************************************************************//**
* \file  CNSL.h
* \version 3.20
*
* \brief
*  This file provides function prototypes and constants for the USBFS component. 
*
********************************************************************************
* \copyright
* Copyright 2008-2016, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_USBFS_CNSL_H)
#define CY_USBFS_CNSL_H

#include "cydevice_trm.h"
#include "cyfitter.h"
#include "cytypes.h"
#include "CyLib.h"


/*  User supplied definitions. */
/* `#START USER_DEFINITIONS` Place your declaration here */

/* `#END` */

/***************************************
* Enumerated Types and Parameters
***************************************/

/* USB IP memory management options. */
#define CNSL__EP_MANUAL    (0u)
#define CNSL__EP_DMAMANUAL (1u)
#define CNSL__EP_DMAAUTO   (2u)

/* USB IP memory allocation options. */
#define CNSL__MA_STATIC    (0u)
#define CNSL__MA_DYNAMIC   (1u)


/***************************************
*    Initial Parameter Constants
***************************************/

#define CNSL_NUM_DEVICES                       (1u)
#define CNSL_ENABLE_CDC_CLASS                  
#define CNSL_ENABLE_MIDI_CLASS                 (0u)
#define CNSL_ENABLE_MSC_CLASS                  (0u)
#define CNSL_BOS_ENABLE                        (0u)
#define CNSL_ENABLE_DESCRIPTOR_STRINGS         
#define CNSL_ENABLE_SN_STRING                  
#define CNSL_ENABLE_IDSN_STRING                
#define CNSL_ENABLE_STRINGS                    
#define CNSL_MAX_REPORTID_NUMBER               (0u)

#define CNSL_MON_VBUS               (0u)
#define CNSL_EXTERN_VBUS            (0u)
#define CNSL_POWER_PAD_VBUS         (0u)
#define CNSL_EXTERN_VND             (0u)
#define CNSL_EXTERN_CLS             (0u)
#define CNSL_MAX_INTERFACES_NUMBER  (2u)
#define CNSL_EP_MM                  (0u)
#define CNSL_EP_MA                  (0u)
#define CNSL_ENABLE_BATT_CHARG_DET  (0u)
#define CNSL_GEN_16BITS_EP_ACCESS   (1u)

/* Enable Class APIs: MIDI, CDC, MSC. */         
#define CNSL_ENABLE_CDC_CLASS_API   (0u != (1u))

/* General parameters */
#define CNSL_EP_ALLOC_STATIC            (CNSL_EP_MA == CNSL__MA_STATIC)
#define CNSL_EP_ALLOC_DYNAMIC           (CNSL_EP_MA == CNSL__MA_DYNAMIC)
#define CNSL_EP_MANAGEMENT_MANUAL       (CNSL_EP_MM == CNSL__EP_MANUAL)
#define CNSL_EP_MANAGEMENT_DMA          (CNSL_EP_MM != CNSL__EP_MANUAL)
#define CNSL_EP_MANAGEMENT_DMA_MANUAL   (CNSL_EP_MM == CNSL__EP_DMAMANUAL)
#define CNSL_EP_MANAGEMENT_DMA_AUTO     (CNSL_EP_MM == CNSL__EP_DMAAUTO)
#define CNSL_BATT_CHARG_DET_ENABLE      (CY_PSOC4 && (0u != CNSL_ENABLE_BATT_CHARG_DET))
#define CNSL_16BITS_EP_ACCESS_ENABLE    (CY_PSOC4 && (0u != CNSL_GEN_16BITS_EP_ACCESS))
#define CNSL_VBUS_MONITORING_ENABLE     (0u != CNSL_MON_VBUS)
#define CNSL_VBUS_MONITORING_INTERNAL   (0u == CNSL_EXTERN_VBUS)
#define CNSL_VBUS_POWER_PAD_ENABLE      (0u != CNSL_POWER_PAD_VBUS)

/* Control endpoints availability */
#define CNSL_SOF_ISR_REMOVE       (0u)
#define CNSL_BUS_RESET_ISR_REMOVE (0u)
#define CNSL_EP0_ISR_REMOVE       (0u)
#define CNSL_ARB_ISR_REMOVE       (0u)
#define CNSL_DP_ISR_REMOVE        (0u)
#define CNSL_LPM_REMOVE           (1u)
#define CNSL_SOF_ISR_ACTIVE       ((0u == CNSL_SOF_ISR_REMOVE) ? 1u: 0u)
#define CNSL_BUS_RESET_ISR_ACTIVE ((0u == CNSL_BUS_RESET_ISR_REMOVE) ? 1u: 0u)
#define CNSL_EP0_ISR_ACTIVE       ((0u == CNSL_EP0_ISR_REMOVE) ? 1u: 0u)
#define CNSL_ARB_ISR_ACTIVE       ((0u == CNSL_ARB_ISR_REMOVE) ? 1u: 0u)
#define CNSL_DP_ISR_ACTIVE        ((0u == CNSL_DP_ISR_REMOVE) ? 1u: 0u)
#define CNSL_LPM_ACTIVE           ((CY_PSOC4 && (0u == CNSL_LPM_REMOVE)) ? 1u: 0u)

/* Data endpoints availability */
#define CNSL_EP1_ISR_REMOVE     (0u)
#define CNSL_EP2_ISR_REMOVE     (0u)
#define CNSL_EP3_ISR_REMOVE     (0u)
#define CNSL_EP4_ISR_REMOVE     (1u)
#define CNSL_EP5_ISR_REMOVE     (1u)
#define CNSL_EP6_ISR_REMOVE     (1u)
#define CNSL_EP7_ISR_REMOVE     (1u)
#define CNSL_EP8_ISR_REMOVE     (1u)
#define CNSL_EP1_ISR_ACTIVE     ((0u == CNSL_EP1_ISR_REMOVE) ? 1u: 0u)
#define CNSL_EP2_ISR_ACTIVE     ((0u == CNSL_EP2_ISR_REMOVE) ? 1u: 0u)
#define CNSL_EP3_ISR_ACTIVE     ((0u == CNSL_EP3_ISR_REMOVE) ? 1u: 0u)
#define CNSL_EP4_ISR_ACTIVE     ((0u == CNSL_EP4_ISR_REMOVE) ? 1u: 0u)
#define CNSL_EP5_ISR_ACTIVE     ((0u == CNSL_EP5_ISR_REMOVE) ? 1u: 0u)
#define CNSL_EP6_ISR_ACTIVE     ((0u == CNSL_EP6_ISR_REMOVE) ? 1u: 0u)
#define CNSL_EP7_ISR_ACTIVE     ((0u == CNSL_EP7_ISR_REMOVE) ? 1u: 0u)
#define CNSL_EP8_ISR_ACTIVE     ((0u == CNSL_EP8_ISR_REMOVE) ? 1u: 0u)

#define CNSL_EP_DMA_AUTO_OPT    ((CY_PSOC4) ? (1u) : (0u))
#define CNSL_DMA1_REMOVE        (1u)
#define CNSL_DMA2_REMOVE        (1u)
#define CNSL_DMA3_REMOVE        (1u)
#define CNSL_DMA4_REMOVE        (1u)
#define CNSL_DMA5_REMOVE        (1u)
#define CNSL_DMA6_REMOVE        (1u)
#define CNSL_DMA7_REMOVE        (1u)
#define CNSL_DMA8_REMOVE        (1u)
#define CNSL_DMA1_ACTIVE        ((0u == CNSL_DMA1_REMOVE) ? 1u: 0u)
#define CNSL_DMA2_ACTIVE        ((0u == CNSL_DMA2_REMOVE) ? 1u: 0u)
#define CNSL_DMA3_ACTIVE        ((0u == CNSL_DMA3_REMOVE) ? 1u: 0u)
#define CNSL_DMA4_ACTIVE        ((0u == CNSL_DMA4_REMOVE) ? 1u: 0u)
#define CNSL_DMA5_ACTIVE        ((0u == CNSL_DMA5_REMOVE) ? 1u: 0u)
#define CNSL_DMA6_ACTIVE        ((0u == CNSL_DMA6_REMOVE) ? 1u: 0u)
#define CNSL_DMA7_ACTIVE        ((0u == CNSL_DMA7_REMOVE) ? 1u: 0u)
#define CNSL_DMA8_ACTIVE        ((0u == CNSL_DMA8_REMOVE) ? 1u: 0u)


/***************************************
*    Data Structures Definition
***************************************/

typedef struct
{
    uint8  attrib;
    uint8  apiEpState;
    uint8  hwEpState;
    uint8  epToggle;
    uint8  addr;
    uint8  epMode;
    uint16 buffOffset;
    uint16 bufferSize;
    uint8  interface;
} T_CNSL_EP_CTL_BLOCK;

typedef struct
{
    uint8  interface;
    uint8  altSetting;
    uint8  addr;
    uint8  attributes;
    uint16 bufferSize;
    uint8  bMisc;
} T_CNSL_EP_SETTINGS_BLOCK;

typedef struct
{
    uint8  status;
    uint16 length;
} T_CNSL_XFER_STATUS_BLOCK;

typedef struct
{
    uint16  count;
    volatile uint8 *pData;
    T_CNSL_XFER_STATUS_BLOCK *pStatusBlock;
} T_CNSL_TD;

typedef struct
{
    uint8   c;
    const void *p_list;
} T_CNSL_LUT;

/* Resume/Suspend API Support */
typedef struct
{
    uint8 enableState;
    uint8 mode;
#if (CY_PSOC4)
    uint8 intrSeiMask;
#endif /* (CY_PSOC4) */
} CNSL_BACKUP_STRUCT;

/* Number of endpoint 0 data registers. */
#define CNSL_EP0_DR_MAPPED_REG_CNT  (8u)

/* Structure to access data registers for EP0. */
typedef struct
{
    uint8 epData[CNSL_EP0_DR_MAPPED_REG_CNT];
} CNSL_ep0_data_struct;

/* Number of SIE endpoint registers group. */
#define CNSL_SIE_EP_REG_SIZE   (CNSL_USB__SIE_EP1_CR0 - \
                                            CNSL_USB__SIE_EP1_CNT0)

/* Size of gap between SIE endpoint registers groups. */
#define CNSL_SIE_GAP_CNT        (((CNSL_USB__SIE_EP2_CNT0 - \
                                             (CNSL_USB__SIE_EP1_CNT0 + \
                                              CNSL_SIE_EP_REG_SIZE)) / sizeof(reg8)) - 1u)

/* Structure to access to SIE registers for endpoint. */
typedef struct
{
    uint8 epCnt0;
    uint8 epCnt1;
    uint8 epCr0;
    uint8 gap[CNSL_SIE_GAP_CNT];
} CNSL_sie_ep_struct;

/* Number of ARB endpoint registers group. */
#define CNSL_ARB_EP_REG_SIZE    (CNSL_USB__ARB_RW1_DR - \
                                             CNSL_USB__ARB_EP1_CFG)

/* Size of gap between ARB endpoint registers groups. */
#define CNSL_ARB_GAP_CNT        (((CNSL_USB__ARB_EP2_CFG - \
                                             (CNSL_USB__ARB_EP1_CFG + \
                                              CNSL_ARB_EP_REG_SIZE)) / sizeof(reg8)) - 1u)

/* Structure to access to ARB registers for endpoint. */
typedef struct
{
    uint8 epCfg;
    uint8 epIntEn;
    uint8 epSr;
    uint8 reserved;
    uint8 rwWa;
    uint8 rwWaMsb;
    uint8 rwRa;
    uint8 rwRaMsb;
    uint8 rwDr;
    uint8 gap[CNSL_ARB_GAP_CNT];
} CNSL_arb_ep_struct;

#if (CY_PSOC4)
    /* Number of ARB endpoint registers group (16-bits access). */
    #define CNSL_ARB_EP_REG16_SIZE      (CNSL_USB__ARB_RW1_DR16 - \
                                                     CNSL_USB__ARB_RW1_WA16)

    /* Size of gap between ARB endpoint registers groups (16-bits access). */
    #define CNSL_ARB_EP_REG16_GAP_CNT   (((CNSL_USB__ARB_RW2_WA16 - \
                                                     (CNSL_USB__ARB_RW1_WA16 + \
                                                      CNSL_ARB_EP_REG16_SIZE)) / sizeof(reg8)) - 1u)

    /* Structure to access to ARB registers for endpoint (16-bits access). */
    typedef struct
    {
        uint8 rwWa16;
        uint8 reserved0;
        uint8 rwRa16;
        uint8 reserved1;
        uint8 rwDr16;
        uint8 gap[CNSL_ARB_EP_REG16_GAP_CNT];
    } CNSL_arb_ep_reg16_struct;
#endif /* (CY_PSOC4) */

/* Number of endpoint (takes to account that endpoints numbers are 1-8). */
#define CNSL_NUMBER_EP  (9u)

/* Consoled SIE register groups for endpoints 1-8. */
typedef struct
{
    CNSL_sie_ep_struct sieEp[CNSL_NUMBER_EP];
} CNSL_sie_eps_struct;

/* Consolidate ARB register groups for endpoints 1-8.*/
typedef struct
{
    CNSL_arb_ep_struct arbEp[CNSL_NUMBER_EP];
} CNSL_arb_eps_struct;

#if (CY_PSOC4)
    /* Consolidate ARB register groups for endpoints 1-8 (16-bits access). */
    typedef struct
    {
        CNSL_arb_ep_reg16_struct arbEp[CNSL_NUMBER_EP];
    } CNSL_arb_eps_reg16_struct;
#endif /* (CY_PSOC4) */


/***************************************
*       Function Prototypes
***************************************/
/**
* \addtogroup group_general
* @{
*/
void   CNSL_InitComponent(uint8 device, uint8 mode) ;
void   CNSL_Start(uint8 device, uint8 mode)         ;
void   CNSL_Init(void)                              ;
void   CNSL_Stop(void)                              ;
uint8  CNSL_GetConfiguration(void)                  ;
uint8  CNSL_IsConfigurationChanged(void)            ;
uint8  CNSL_GetInterfaceSetting(uint8 interfaceNumber) ;
uint8  CNSL_GetEPState(uint8 epNumber)              ;
uint16 CNSL_GetEPCount(uint8 epNumber)              ;
void   CNSL_LoadInEP(uint8 epNumber, const uint8 pData[], uint16 length)
                                                                ;
uint16 CNSL_ReadOutEP(uint8 epNumber, uint8 pData[], uint16 length)
                                                                ;
void   CNSL_EnableOutEP(uint8 epNumber)             ;
void   CNSL_DisableOutEP(uint8 epNumber)            ;
void   CNSL_Force(uint8 bState)                     ;
uint8  CNSL_GetEPAckState(uint8 epNumber)           ;
void   CNSL_SetPowerStatus(uint8 powerStatus)       ;
void   CNSL_TerminateEP(uint8 epNumber)             ;

uint8 CNSL_GetDeviceAddress(void) ;

void CNSL_EnableSofInt(void)  ;
void CNSL_DisableSofInt(void) ;


#if defined(CNSL_ENABLE_FWSN_STRING)
    void   CNSL_SerialNumString(uint8 snString[]) ;
#endif  /* CNSL_ENABLE_FWSN_STRING */

#if (CNSL_VBUS_MONITORING_ENABLE)
    uint8  CNSL_VBusPresent(void) ;
#endif /*  (CNSL_VBUS_MONITORING_ENABLE) */

#if (CNSL_16BITS_EP_ACCESS_ENABLE)
    /* PSoC4 specific functions for 16-bit data register access. */
    void   CNSL_LoadInEP16 (uint8 epNumber, const uint8 pData[], uint16 length);
    uint16 CNSL_ReadOutEP16(uint8 epNumber,       uint8 pData[], uint16 length);
#endif /* (CNSL_16BITS_EP_ACCESS_ENABLE) */

#if (CNSL_BATT_CHARG_DET_ENABLE)
        uint8 CNSL_Bcd_DetectPortType(void);
#endif /* (CNSL_BATT_CHARG_DET_ENABLE) */

#if (CNSL_EP_MANAGEMENT_DMA)
    void CNSL_InitEP_DMA(uint8 epNumber, const uint8 *pData) ;   
    void CNSL_Stop_DMA(uint8 epNumber) ;
/** @} general */ 
#endif /* (CNSL_EP_MANAGEMENT_DMA) */

/**
* \addtogroup group_power
* @{
*/
uint8  CNSL_CheckActivity(void) ;
void   CNSL_Suspend(void)       ;
void   CNSL_Resume(void)        ;
uint8  CNSL_RWUEnabled(void)    ;

#if (CNSL_LPM_ACTIVE)
    uint32 CNSL_Lpm_GetBeslValue(void);
    uint32 CNSL_Lpm_RemoteWakeUpAllowed(void);
    void   CNSL_Lpm_SetResponse(uint32 response);
    uint32 CNSL_Lpm_GetResponse(void);
#endif /* (CNSL_LPM_ACTIVE) */

/** @} power */


#if defined(CYDEV_BOOTLOADER_IO_COMP) && ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_CNSL) || \
                                          (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))
/**
* \addtogroup group_bootloader
* @{
*/
    void CNSL_CyBtldrCommStart(void)        ;
    void CNSL_CyBtldrCommStop(void)         ;
    void CNSL_CyBtldrCommReset(void)        ;
    cystatus CNSL_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 *count, uint8 timeOut) CYSMALL
                                                        ;
    cystatus CNSL_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 *count, uint8 timeOut) CYSMALL
                                                        ;
/** @} bootloader */

    #define CNSL_BTLDR_OUT_EP   (0x01u)
    #define CNSL_BTLDR_IN_EP    (0x02u)

    #define CNSL_BTLDR_SIZEOF_WRITE_BUFFER  (64u)   /* Endpoint 1 (OUT) buffer size. */
    #define CNSL_BTLDR_SIZEOF_READ_BUFFER   (64u)   /* Endpoint 2 (IN)  buffer size. */
    #define CNSL_BTLDR_MAX_PACKET_SIZE      CNSL_BTLDR_SIZEOF_WRITE_BUFFER

    #define CNSL_BTLDR_WAIT_1_MS            (1u)    /* Time Out quantity equal 1mS */

    /* Map-specific USB bootloader communication functions to common bootloader functions */
    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_CNSL)
        #define CyBtldrCommStart        CNSL_CyBtldrCommStart
        #define CyBtldrCommStop         CNSL_CyBtldrCommStop
        #define CyBtldrCommReset        CNSL_CyBtldrCommReset
        #define CyBtldrCommWrite        CNSL_CyBtldrCommWrite
        #define CyBtldrCommRead         CNSL_CyBtldrCommRead
    #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_CNSL) */
#endif /* CYDEV_BOOTLOADER_IO_COMP */


/***************************************
*          API Constants
***************************************/

#define CNSL_EP0                        (0u)
#define CNSL_EP1                        (1u)
#define CNSL_EP2                        (2u)
#define CNSL_EP3                        (3u)
#define CNSL_EP4                        (4u)
#define CNSL_EP5                        (5u)
#define CNSL_EP6                        (6u)
#define CNSL_EP7                        (7u)
#define CNSL_EP8                        (8u)
#define CNSL_MAX_EP                     (9u)

#define CNSL_TRUE                       (1u)
#define CNSL_FALSE                      (0u)

#define CNSL_NO_EVENT_ALLOWED           (2u)
#define CNSL_EVENT_PENDING              (1u)
#define CNSL_NO_EVENT_PENDING           (0u)

#define CNSL_IN_BUFFER_FULL             CNSL_NO_EVENT_PENDING
#define CNSL_IN_BUFFER_EMPTY            CNSL_EVENT_PENDING
#define CNSL_OUT_BUFFER_FULL            CNSL_EVENT_PENDING
#define CNSL_OUT_BUFFER_EMPTY           CNSL_NO_EVENT_PENDING

#define CNSL_FORCE_J                    (0xA0u)
#define CNSL_FORCE_K                    (0x80u)
#define CNSL_FORCE_SE0                  (0xC0u)
#define CNSL_FORCE_NONE                 (0x00u)

#define CNSL_IDLE_TIMER_RUNNING         (0x02u)
#define CNSL_IDLE_TIMER_EXPIRED         (0x01u)
#define CNSL_IDLE_TIMER_INDEFINITE      (0x00u)

#define CNSL_DEVICE_STATUS_BUS_POWERED  (0x00u)
#define CNSL_DEVICE_STATUS_SELF_POWERED (0x01u)

#define CNSL_3V_OPERATION               (0x00u)
#define CNSL_5V_OPERATION               (0x01u)
#define CNSL_DWR_POWER_OPERATION        (0x02u)

#define CNSL_MODE_DISABLE               (0x00u)
#define CNSL_MODE_NAK_IN_OUT            (0x01u)
#define CNSL_MODE_STATUS_OUT_ONLY       (0x02u)
#define CNSL_MODE_STALL_IN_OUT          (0x03u)
#define CNSL_MODE_RESERVED_0100         (0x04u)
#define CNSL_MODE_ISO_OUT               (0x05u)
#define CNSL_MODE_STATUS_IN_ONLY        (0x06u)
#define CNSL_MODE_ISO_IN                (0x07u)
#define CNSL_MODE_NAK_OUT               (0x08u)
#define CNSL_MODE_ACK_OUT               (0x09u)
#define CNSL_MODE_RESERVED_1010         (0x0Au)
#define CNSL_MODE_ACK_OUT_STATUS_IN     (0x0Bu)
#define CNSL_MODE_NAK_IN                (0x0Cu)
#define CNSL_MODE_ACK_IN                (0x0Du)
#define CNSL_MODE_RESERVED_1110         (0x0Eu)
#define CNSL_MODE_ACK_IN_STATUS_OUT     (0x0Fu)
#define CNSL_MODE_MASK                  (0x0Fu)
#define CNSL_MODE_STALL_DATA_EP         (0x80u)

#define CNSL_MODE_ACKD                  (0x10u)
#define CNSL_MODE_OUT_RCVD              (0x20u)
#define CNSL_MODE_IN_RCVD               (0x40u)
#define CNSL_MODE_SETUP_RCVD            (0x80u)

#define CNSL_RQST_TYPE_MASK             (0x60u)
#define CNSL_RQST_TYPE_STD              (0x00u)
#define CNSL_RQST_TYPE_CLS              (0x20u)
#define CNSL_RQST_TYPE_VND              (0x40u)
#define CNSL_RQST_DIR_MASK              (0x80u)
#define CNSL_RQST_DIR_D2H               (0x80u)
#define CNSL_RQST_DIR_H2D               (0x00u)
#define CNSL_RQST_RCPT_MASK             (0x03u)
#define CNSL_RQST_RCPT_DEV              (0x00u)
#define CNSL_RQST_RCPT_IFC              (0x01u)
#define CNSL_RQST_RCPT_EP               (0x02u)
#define CNSL_RQST_RCPT_OTHER            (0x03u)

#if (CNSL_LPM_ACTIVE)
    #define CNSL_LPM_REQ_ACK            (0x01u << CNSL_LPM_CTRL_LPM_ACK_RESP_POS)
    #define CNSL_LPM_REQ_NACK           (0x00u)
    #define CNSL_LPM_REQ_NYET           (0x01u << CNSL_LPM_CTRL_NYET_EN_POS)
#endif /*(CNSL_LPM_ACTIVE)*/

/* USB Class Codes */
#define CNSL_CLASS_DEVICE               (0x00u)     /* Use class code info from Interface Descriptors */
#define CNSL_CLASS_AUDIO                (0x01u)     /* Audio device */
#define CNSL_CLASS_CDC                  (0x02u)     /* Communication device class */
#define CNSL_CLASS_HID                  (0x03u)     /* Human Interface Device */
#define CNSL_CLASS_PDC                  (0x05u)     /* Physical device class */
#define CNSL_CLASS_IMAGE                (0x06u)     /* Still Imaging device */
#define CNSL_CLASS_PRINTER              (0x07u)     /* Printer device  */
#define CNSL_CLASS_MSD                  (0x08u)     /* Mass Storage device  */
#define CNSL_CLASS_HUB                  (0x09u)     /* Full/Hi speed Hub */
#define CNSL_CLASS_CDC_DATA             (0x0Au)     /* CDC data device */
#define CNSL_CLASS_SMART_CARD           (0x0Bu)     /* Smart Card device */
#define CNSL_CLASS_CSD                  (0x0Du)     /* Content Security device */
#define CNSL_CLASS_VIDEO                (0x0Eu)     /* Video device */
#define CNSL_CLASS_PHD                  (0x0Fu)     /* Personal Health care device */
#define CNSL_CLASS_WIRELESSD            (0xDCu)     /* Wireless Controller */
#define CNSL_CLASS_MIS                  (0xE0u)     /* Miscellaneous */
#define CNSL_CLASS_APP                  (0xEFu)     /* Application Specific */
#define CNSL_CLASS_VENDOR               (0xFFu)     /* Vendor specific */

/* Standard Request Types (Table 9-4) */
#define CNSL_GET_STATUS                 (0x00u)
#define CNSL_CLEAR_FEATURE              (0x01u)
#define CNSL_SET_FEATURE                (0x03u)
#define CNSL_SET_ADDRESS                (0x05u)
#define CNSL_GET_DESCRIPTOR             (0x06u)
#define CNSL_SET_DESCRIPTOR             (0x07u)
#define CNSL_GET_CONFIGURATION          (0x08u)
#define CNSL_SET_CONFIGURATION          (0x09u)
#define CNSL_GET_INTERFACE              (0x0Au)
#define CNSL_SET_INTERFACE              (0x0Bu)
#define CNSL_SYNCH_FRAME                (0x0Cu)

/* Vendor Specific Request Types */
/* Request for Microsoft OS String Descriptor */
#define CNSL_GET_EXTENDED_CONFIG_DESCRIPTOR (0x01u)

/* Descriptor Types (Table 9-5) */
#define CNSL_DESCR_DEVICE                   (1u)
#define CNSL_DESCR_CONFIG                   (2u)
#define CNSL_DESCR_STRING                   (3u)
#define CNSL_DESCR_INTERFACE                (4u)
#define CNSL_DESCR_ENDPOINT                 (5u)
#define CNSL_DESCR_DEVICE_QUALIFIER         (6u)
#define CNSL_DESCR_OTHER_SPEED              (7u)
#define CNSL_DESCR_INTERFACE_POWER          (8u)
#if (CNSL_BOS_ENABLE)
    #define CNSL_DESCR_BOS                  (15u)
#endif /* (CNSL_BOS_ENABLE) */
/* Device Descriptor Defines */
#define CNSL_DEVICE_DESCR_LENGTH            (18u)
#define CNSL_DEVICE_DESCR_SN_SHIFT          (16u)

/* Config Descriptor Shifts and Masks */
#define CNSL_CONFIG_DESCR_LENGTH                (0u)
#define CNSL_CONFIG_DESCR_TYPE                  (1u)
#define CNSL_CONFIG_DESCR_TOTAL_LENGTH_LOW      (2u)
#define CNSL_CONFIG_DESCR_TOTAL_LENGTH_HI       (3u)
#define CNSL_CONFIG_DESCR_NUM_INTERFACES        (4u)
#define CNSL_CONFIG_DESCR_CONFIG_VALUE          (5u)
#define CNSL_CONFIG_DESCR_CONFIGURATION         (6u)
#define CNSL_CONFIG_DESCR_ATTRIB                (7u)
#define CNSL_CONFIG_DESCR_ATTRIB_SELF_POWERED   (0x40u)
#define CNSL_CONFIG_DESCR_ATTRIB_RWU_EN         (0x20u)

#if (CNSL_BOS_ENABLE)
    /* Config Descriptor BOS */
    #define CNSL_BOS_DESCR_LENGTH               (0u)
    #define CNSL_BOS_DESCR_TYPE                 (1u)
    #define CNSL_BOS_DESCR_TOTAL_LENGTH_LOW     (2u)
    #define CNSL_BOS_DESCR_TOTAL_LENGTH_HI      (3u)
    #define CNSL_BOS_DESCR_NUM_DEV_CAPS         (4u)
#endif /* (CNSL_BOS_ENABLE) */

/* Feature Selectors (Table 9-6) */
#define CNSL_DEVICE_REMOTE_WAKEUP           (0x01u)
#define CNSL_ENDPOINT_HALT                  (0x00u)
#define CNSL_TEST_MODE                      (0x02u)

/* USB Device Status (Figure 9-4) */
#define CNSL_DEVICE_STATUS_BUS_POWERED      (0x00u)
#define CNSL_DEVICE_STATUS_SELF_POWERED     (0x01u)
#define CNSL_DEVICE_STATUS_REMOTE_WAKEUP    (0x02u)

/* USB Endpoint Status (Figure 9-4) */
#define CNSL_ENDPOINT_STATUS_HALT           (0x01u)

/* USB Endpoint Directions */
#define CNSL_DIR_IN                         (0x80u)
#define CNSL_DIR_OUT                        (0x00u)
#define CNSL_DIR_UNUSED                     (0x7Fu)

/* USB Endpoint Attributes */
#define CNSL_EP_TYPE_CTRL                   (0x00u)
#define CNSL_EP_TYPE_ISOC                   (0x01u)
#define CNSL_EP_TYPE_BULK                   (0x02u)
#define CNSL_EP_TYPE_INT                    (0x03u)
#define CNSL_EP_TYPE_MASK                   (0x03u)

#define CNSL_EP_SYNC_TYPE_NO_SYNC           (0x00u)
#define CNSL_EP_SYNC_TYPE_ASYNC             (0x04u)
#define CNSL_EP_SYNC_TYPE_ADAPTIVE          (0x08u)
#define CNSL_EP_SYNC_TYPE_SYNCHRONOUS       (0x0Cu)
#define CNSL_EP_SYNC_TYPE_MASK              (0x0Cu)

#define CNSL_EP_USAGE_TYPE_DATA             (0x00u)
#define CNSL_EP_USAGE_TYPE_FEEDBACK         (0x10u)
#define CNSL_EP_USAGE_TYPE_IMPLICIT         (0x20u)
#define CNSL_EP_USAGE_TYPE_RESERVED         (0x30u)
#define CNSL_EP_USAGE_TYPE_MASK             (0x30u)

/* Point Status defines */
#define CNSL_EP_STATUS_LENGTH               (0x02u)

/* Point Device defines */
#define CNSL_DEVICE_STATUS_LENGTH           (0x02u)

#define CNSL_STATUS_LENGTH_MAX \
                 ((CNSL_EP_STATUS_LENGTH > CNSL_DEVICE_STATUS_LENGTH) ? \
                        CNSL_EP_STATUS_LENGTH : CNSL_DEVICE_STATUS_LENGTH)

/* Transfer Completion Notification */
#define CNSL_XFER_IDLE                      (0x00u)
#define CNSL_XFER_STATUS_ACK                (0x01u)
#define CNSL_XFER_PREMATURE                 (0x02u)
#define CNSL_XFER_ERROR                     (0x03u)

/* Driver State defines */
#define CNSL_TRANS_STATE_IDLE               (0x00u)
#define CNSL_TRANS_STATE_CONTROL_READ       (0x02u)
#define CNSL_TRANS_STATE_CONTROL_WRITE      (0x04u)
#define CNSL_TRANS_STATE_NO_DATA_CONTROL    (0x06u)

/* String Descriptor defines */
#define CNSL_STRING_MSOS                    (0xEEu)
#define CNSL_MSOS_DESCRIPTOR_LENGTH         (18u)
#define CNSL_MSOS_CONF_DESCR_LENGTH         (40u)

/* Return values */
#define CNSL_BCD_PORT_SDP       (1u) /* Standard downstream port detected */
#define CNSL_BCD_PORT_CDP       (2u) /* Charging downstream port detected */
#define CNSL_BCD_PORT_DCP       (3u) /* Dedicated charging port detected */
#define CNSL_BCD_PORT_UNKNOWN   (0u) /* Unable to detect charging port */
#define CNSL_BCD_PORT_ERR       (4u) /* Error condition in detection process*/


/* Timeouts for BCD */
#define CNSL_BCD_TIMEOUT                (400u)  /* Copied from PBK#163 TIMEOUT (300 ms) */
#define CNSL_BCD_TDCD_DBNC              (10u)  /*BCD v1.2: DCD debounce time 10 ms*/
#define CNSL_BCD_PRIMARY_WAIT           (40u)   /* Copied from PBK#163 TIMEOUT (40 ms)  */
#define CNSL_BCD_SECONDARY_WAIT         (47u)   /* Copied from PBK#163 TIMEOUT (40 ms)  */
#define CNSL_BCD_SUSPEND_DISABLE_WAIT   (2u)    /* Copied from PBK#163 TIMEOUT (2 us)   */

/* Wait cycles required before clearing SUSPEND_DEL in POWER_CTRL: 2us */
#define CNSL_WAIT_SUSPEND_DEL_DISABLE   (2u)

/* Wait cycles required for USB regulator stabilization after it is enabled : 50ns */
#define CNSL_WAIT_VREF_STABILITY        (0u)

#if (CY_PSOC3 || CY_PSOC5LP)
/* Wait cycles required for USB reference restore: 40us */
#define CNSL_WAIT_VREF_RESTORE          (40u)

/* Wait cycles required for stabilization after register is written : 50ns */
#define CNSL_WAIT_REG_STABILITY_50NS    (0u)
#define CNSL_WAIT_REG_STABILITY_1US     (1u)

/* Wait cycles required after CR0 register write: 1 cycle */
#define CNSL_WAIT_CR0_REG_STABILITY     (1u)

/* Wait cycles required after PD_PULLUP_N bit is set in PM_USB_CR0: 2us */
#define CNSL_WAIT_PD_PULLUP_N_ENABLE    (2u)
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

#if (CY_PSOC4)
    #if (CNSL_EP_MANAGEMENT_DMA)
        #define CNSL_DMA_DESCR0         (0u)
        #define CNSL_DMA_DESCR1         (1u)
    #endif /* (CNSL_EP_MANAGEMENT_DMA) */

    #if (CNSL_EP_MANAGEMENT_DMA_AUTO)
        /* BUF_SIZE-BYTES_PER_BURST examples: 0x55 - 32 bytes, 0x44 - 16 bytes, 0x33 - 8 bytes, etc. */
        #define CNSL_DMA_BUF_SIZE             (0x55u)
        #define CNSL_DMA_BYTES_PER_BURST      (32u)
        #define CNSL_DMA_HALFWORDS_PER_BURST  (16u)
        #define CNSL_DMA_BURST_BYTES_MASK     (CNSL_DMA_BYTES_PER_BURST - 1u)

        #define CNSL_DMA_DESCR0_MASK        (0x00u)
        #define CNSL_DMA_DESCR1_MASK        (0x80u)
        #define CNSL_DMA_DESCR_REVERT       (0x40u)
        #define CNSL_DMA_DESCR_16BITS       (0x20u)
        #define CNSL_DMA_DESCR_SHIFT        (7u)

        #define CNSL_DMA_GET_DESCR_NUM(desrc)
        #define CNSL_DMA_GET_BURST_CNT(dmaBurstCnt) \
                    (((dmaBurstCnt) > 2u)? ((dmaBurstCnt) - 2u) : 0u)

        #define CNSL_DMA_GET_MAX_ELEM_PER_BURST(dmaLastBurstEl) \
                    ((0u != ((dmaLastBurstEl) & CNSL_DMA_DESCR_16BITS)) ? \
                                (CNSL_DMA_HALFWORDS_PER_BURST - 1u) : (CNSL_DMA_BYTES_PER_BURST - 1u))
    #endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO) */
#else
    #if (CNSL_EP_MANAGEMENT_DMA_MANUAL)
        #define CNSL_DMA_BYTES_PER_BURST    (0u)
        #define CNSL_DMA_REQUEST_PER_BURST  (0u)
    #endif /* (CNSL_EP_MANAGEMENT_DMA_MANUAL) */

    #if (CNSL_EP_MANAGEMENT_DMA_AUTO)
        #define CNSL_DMA_BYTES_PER_BURST    (32u)
        #define CNSL_DMA_BYTES_REPEAT       (2u)

        /* BUF_SIZE-BYTES_PER_BURST examples: 0x55 - 32 bytes, 0x44 - 16 bytes, 0x33 - 8 bytes, etc. */
        #define CNSL_DMA_BUF_SIZE           (0x55u)
        #define CNSL_DMA_REQUEST_PER_BURST  (1u)

        #define CNSL_EP17_SR_MASK           (0x7Fu)
        #define CNSL_EP8_SR_MASK            (0x03u)
    #endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO) */
#endif /* (CY_PSOC4) */

/* DIE ID string descriptor defines */
#if defined(CNSL_ENABLE_IDSN_STRING)
    #define CNSL_IDSN_DESCR_LENGTH      (0x22u)
#endif /* (CNSL_ENABLE_IDSN_STRING) */


/***************************************
*     Vars with External Linkage
***************************************/

/**
* \addtogroup group_globals
* @{
*/
extern uint8 CNSL_initVar;
extern volatile uint8 CNSL_device;
extern volatile uint8 CNSL_transferState;
extern volatile uint8 CNSL_configuration;
extern volatile uint8 CNSL_configurationChanged;
extern volatile uint8 CNSL_deviceStatus;
/** @} globals */

/**
* \addtogroup group_hid
* @{
*/
/* HID Variables */
#if defined(CNSL_ENABLE_HID_CLASS)
    extern volatile uint8 CNSL_hidProtocol [CNSL_MAX_INTERFACES_NUMBER]; 
    extern volatile uint8 CNSL_hidIdleRate [CNSL_MAX_INTERFACES_NUMBER];
    extern volatile uint8 CNSL_hidIdleTimer[CNSL_MAX_INTERFACES_NUMBER];
#endif /* (CNSL_ENABLE_HID_CLASS) */
/** @} hid */


/***************************************
*              Registers
***************************************/

/* Common registers for all PSoCs: 3/4/5LP */
#define CNSL_ARB_CFG_PTR        ( (reg8 *) CNSL_USB__ARB_CFG)
#define CNSL_ARB_CFG_REG        (*(reg8 *) CNSL_USB__ARB_CFG)

#define CNSL_ARB_EP1_CFG_PTR    ( (reg8 *) CNSL_USB__ARB_EP1_CFG)
#define CNSL_ARB_EP1_CFG_REG    (*(reg8 *) CNSL_USB__ARB_EP1_CFG)
#define CNSL_ARB_EP1_INT_EN_PTR ( (reg8 *) CNSL_USB__ARB_EP1_INT_EN)
#define CNSL_ARB_EP1_INT_EN_REG (*(reg8 *) CNSL_USB__ARB_EP1_INT_EN)
#define CNSL_ARB_EP1_SR_PTR     ( (reg8 *) CNSL_USB__ARB_EP1_SR)
#define CNSL_ARB_EP1_SR_REG     (*(reg8 *) CNSL_USB__ARB_EP1_SR)
#define CNSL_ARB_EP1_CFG_IND    CNSL_USB__ARB_EP1_CFG
#define CNSL_ARB_EP1_INT_EN_IND CNSL_USB__ARB_EP1_INT_EN
#define CNSL_ARB_EP1_SR_IND     CNSL_USB__ARB_EP1_SR
#define CNSL_ARB_EP_BASE        (*(volatile CNSL_arb_eps_struct CYXDATA *) \
                                            (CNSL_USB__ARB_EP1_CFG - sizeof(CNSL_arb_ep_struct)))

#define CNSL_ARB_EP2_CFG_PTR    ( (reg8 *) CNSL_USB__ARB_EP2_CFG)
#define CNSL_ARB_EP2_CFG_REG    (*(reg8 *) CNSL_USB__ARB_EP2_CFG)
#define CNSL_ARB_EP2_INT_EN_PTR ( (reg8 *) CNSL_USB__ARB_EP2_INT_EN)
#define CNSL_ARB_EP2_INT_EN_REG (*(reg8 *) CNSL_USB__ARB_EP2_INT_EN)
#define CNSL_ARB_EP2_SR_PTR     ( (reg8 *) CNSL_USB__ARB_EP2_SR)
#define CNSL_ARB_EP2_SR_REG     (*(reg8 *) CNSL_USB__ARB_EP2_SR)

#define CNSL_ARB_EP3_CFG_PTR    ( (reg8 *) CNSL_USB__ARB_EP3_CFG)
#define CNSL_ARB_EP3_CFG_REG    (*(reg8 *) CNSL_USB__ARB_EP3_CFG)
#define CNSL_ARB_EP3_INT_EN_PTR ( (reg8 *) CNSL_USB__ARB_EP3_INT_EN)
#define CNSL_ARB_EP3_INT_EN_REG (*(reg8 *) CNSL_USB__ARB_EP3_INT_EN)
#define CNSL_ARB_EP3_SR_PTR     ( (reg8 *) CNSL_USB__ARB_EP3_SR)
#define CNSL_ARB_EP3_SR_REG     (*(reg8 *) CNSL_USB__ARB_EP3_SR)

#define CNSL_ARB_EP4_CFG_PTR    ( (reg8 *) CNSL_USB__ARB_EP4_CFG)
#define CNSL_ARB_EP4_CFG_REG    (*(reg8 *) CNSL_USB__ARB_EP4_CFG)
#define CNSL_ARB_EP4_INT_EN_PTR ( (reg8 *) CNSL_USB__ARB_EP4_INT_EN)
#define CNSL_ARB_EP4_INT_EN_REG (*(reg8 *) CNSL_USB__ARB_EP4_INT_EN)
#define CNSL_ARB_EP4_SR_PTR     ( (reg8 *) CNSL_USB__ARB_EP4_SR)
#define CNSL_ARB_EP4_SR_REG     (*(reg8 *) CNSL_USB__ARB_EP4_SR)

#define CNSL_ARB_EP5_CFG_PTR    ( (reg8 *) CNSL_USB__ARB_EP5_CFG)
#define CNSL_ARB_EP5_CFG_REG    (*(reg8 *) CNSL_USB__ARB_EP5_CFG)
#define CNSL_ARB_EP5_INT_EN_PTR ( (reg8 *) CNSL_USB__ARB_EP5_INT_EN)
#define CNSL_ARB_EP5_INT_EN_REG (*(reg8 *) CNSL_USB__ARB_EP5_INT_EN)
#define CNSL_ARB_EP5_SR_PTR     ( (reg8 *) CNSL_USB__ARB_EP5_SR)
#define CNSL_ARB_EP5_SR_REG     (*(reg8 *) CNSL_USB__ARB_EP5_SR)

#define CNSL_ARB_EP6_CFG_PTR    ( (reg8 *) CNSL_USB__ARB_EP6_CFG)
#define CNSL_ARB_EP6_CFG_REG    (*(reg8 *) CNSL_USB__ARB_EP6_CFG)
#define CNSL_ARB_EP6_INT_EN_PTR ( (reg8 *) CNSL_USB__ARB_EP6_INT_EN)
#define CNSL_ARB_EP6_INT_EN_REG (*(reg8 *) CNSL_USB__ARB_EP6_INT_EN)
#define CNSL_ARB_EP6_SR_PTR     ( (reg8 *) CNSL_USB__ARB_EP6_SR)
#define CNSL_ARB_EP6_SR_REG     (*(reg8 *) CNSL_USB__ARB_EP6_SR)

#define CNSL_ARB_EP7_CFG_PTR    ( (reg8 *) CNSL_USB__ARB_EP7_CFG)
#define CNSL_ARB_EP7_CFG_REG    (*(reg8 *) CNSL_USB__ARB_EP7_CFG)
#define CNSL_ARB_EP7_INT_EN_PTR ( (reg8 *) CNSL_USB__ARB_EP7_INT_EN)
#define CNSL_ARB_EP7_INT_EN_REG (*(reg8 *) CNSL_USB__ARB_EP7_INT_EN)
#define CNSL_ARB_EP7_SR_PTR     ( (reg8 *) CNSL_USB__ARB_EP7_SR)
#define CNSL_ARB_EP7_SR_REG     (*(reg8 *) CNSL_USB__ARB_EP7_SR)

#define CNSL_ARB_EP8_CFG_PTR    ( (reg8 *) CNSL_USB__ARB_EP8_CFG)
#define CNSL_ARB_EP8_CFG_REG    (*(reg8 *) CNSL_USB__ARB_EP8_CFG)
#define CNSL_ARB_EP8_INT_EN_PTR ( (reg8 *) CNSL_USB__ARB_EP8_INT_EN)
#define CNSL_ARB_EP8_INT_EN_REG (*(reg8 *) CNSL_USB__ARB_EP8_INT_EN)
#define CNSL_ARB_EP8_SR_PTR     ( (reg8 *) CNSL_USB__ARB_EP8_SR)
#define CNSL_ARB_EP8_SR_REG     (*(reg8 *) CNSL_USB__ARB_EP8_SR)

#define CNSL_ARB_INT_EN_PTR     ( (reg8 *) CNSL_USB__ARB_INT_EN)
#define CNSL_ARB_INT_EN_REG     (*(reg8 *) CNSL_USB__ARB_INT_EN)
#define CNSL_ARB_INT_SR_PTR     ( (reg8 *) CNSL_USB__ARB_INT_SR)
#define CNSL_ARB_INT_SR_REG     (*(reg8 *) CNSL_USB__ARB_INT_SR)

#define CNSL_ARB_RW1_DR_PTR     ( (reg8 *) CNSL_USB__ARB_RW1_DR)
#define CNSL_ARB_RW1_RA_PTR     ( (reg8 *) CNSL_USB__ARB_RW1_RA)

#define CNSL_ARB_RW1_RA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW1_RA_MSB)
#define CNSL_ARB_RW1_WA_PTR     ( (reg8 *) CNSL_USB__ARB_RW1_WA)
#define CNSL_ARB_RW1_WA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW1_WA_MSB)
#define CNSL_ARB_RW1_DR_IND     CNSL_USB__ARB_RW1_DR
#define CNSL_ARB_RW1_RA_IND     CNSL_USB__ARB_RW1_RA
#define CNSL_ARB_RW1_RA_MSB_IND CNSL_USB__ARB_RW1_RA_MSB
#define CNSL_ARB_RW1_WA_IND     CNSL_USB__ARB_RW1_WA
#define CNSL_ARB_RW1_WA_MSB_IND CNSL_USB__ARB_RW1_WA_MSB

#define CNSL_ARB_RW2_DR_PTR     ( (reg8 *) CNSL_USB__ARB_RW2_DR)
#define CNSL_ARB_RW2_RA_PTR     ( (reg8 *) CNSL_USB__ARB_RW2_RA)
#define CNSL_ARB_RW2_RA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW2_RA_MSB)
#define CNSL_ARB_RW2_WA_PTR     ( (reg8 *) CNSL_USB__ARB_RW2_WA)
#define CNSL_ARB_RW2_WA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW2_WA_MSB)

#define CNSL_ARB_RW3_DR_PTR     ( (reg8 *) CNSL_USB__ARB_RW3_DR)
#define CNSL_ARB_RW3_RA_PTR     ( (reg8 *) CNSL_USB__ARB_RW3_RA)
#define CNSL_ARB_RW3_RA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW3_RA_MSB)
#define CNSL_ARB_RW3_WA_PTR     ( (reg8 *) CNSL_USB__ARB_RW3_WA)
#define CNSL_ARB_RW3_WA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW3_WA_MSB)

#define CNSL_ARB_RW4_DR_PTR     ( (reg8 *) CNSL_USB__ARB_RW4_DR)
#define CNSL_ARB_RW4_RA_PTR     ( (reg8 *) CNSL_USB__ARB_RW4_RA)
#define CNSL_ARB_RW4_RA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW4_RA_MSB)
#define CNSL_ARB_RW4_WA_PTR     ( (reg8 *) CNSL_USB__ARB_RW4_WA)
#define CNSL_ARB_RW4_WA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW4_WA_MSB)

#define CNSL_ARB_RW5_DR_PTR     ( (reg8 *) CNSL_USB__ARB_RW5_DR)
#define CNSL_ARB_RW5_RA_PTR     ( (reg8 *) CNSL_USB__ARB_RW5_RA)
#define CNSL_ARB_RW5_RA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW5_RA_MSB)
#define CNSL_ARB_RW5_WA_PTR     ( (reg8 *) CNSL_USB__ARB_RW5_WA)
#define CNSL_ARB_RW5_WA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW5_WA_MSB)

#define CNSL_ARB_RW6_DR_PTR     ( (reg8 *) CNSL_USB__ARB_RW6_DR)
#define CNSL_ARB_RW6_RA_PTR     ( (reg8 *) CNSL_USB__ARB_RW6_RA)
#define CNSL_ARB_RW6_RA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW6_RA_MSB)
#define CNSL_ARB_RW6_WA_PTR     ( (reg8 *) CNSL_USB__ARB_RW6_WA)
#define CNSL_ARB_RW6_WA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW6_WA_MSB)

#define CNSL_ARB_RW7_DR_PTR     ( (reg8 *) CNSL_USB__ARB_RW7_DR)
#define CNSL_ARB_RW7_RA_PTR     ( (reg8 *) CNSL_USB__ARB_RW7_RA)
#define CNSL_ARB_RW7_RA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW7_RA_MSB)
#define CNSL_ARB_RW7_WA_PTR     ( (reg8 *) CNSL_USB__ARB_RW7_WA)
#define CNSL_ARB_RW7_WA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW7_WA_MSB)

#define CNSL_ARB_RW8_DR_PTR     ( (reg8 *) CNSL_USB__ARB_RW8_DR)
#define CNSL_ARB_RW8_RA_PTR     ( (reg8 *) CNSL_USB__ARB_RW8_RA)
#define CNSL_ARB_RW8_RA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW8_RA_MSB)
#define CNSL_ARB_RW8_WA_PTR     ( (reg8 *) CNSL_USB__ARB_RW8_WA)
#define CNSL_ARB_RW8_WA_MSB_PTR ( (reg8 *) CNSL_USB__ARB_RW8_WA_MSB)

#define CNSL_BUF_SIZE_PTR       ( (reg8 *) CNSL_USB__BUF_SIZE)
#define CNSL_BUF_SIZE_REG       (*(reg8 *) CNSL_USB__BUF_SIZE)
#define CNSL_BUS_RST_CNT_PTR    ( (reg8 *) CNSL_USB__BUS_RST_CNT)
#define CNSL_BUS_RST_CNT_REG    (*(reg8 *) CNSL_USB__BUS_RST_CNT)
#define CNSL_CWA_PTR            ( (reg8 *) CNSL_USB__CWA)
#define CNSL_CWA_REG            (*(reg8 *) CNSL_USB__CWA)
#define CNSL_CWA_MSB_PTR        ( (reg8 *) CNSL_USB__CWA_MSB)
#define CNSL_CWA_MSB_REG        (*(reg8 *) CNSL_USB__CWA_MSB)
#define CNSL_CR0_PTR            ( (reg8 *) CNSL_USB__CR0)
#define CNSL_CR0_REG            (*(reg8 *) CNSL_USB__CR0)
#define CNSL_CR1_PTR            ( (reg8 *) CNSL_USB__CR1)
#define CNSL_CR1_REG            (*(reg8 *) CNSL_USB__CR1)

#define CNSL_DMA_THRES_PTR      ( (reg8 *) CNSL_USB__DMA_THRES)
#define CNSL_DMA_THRES_REG      (*(reg8 *) CNSL_USB__DMA_THRES)
#define CNSL_DMA_THRES_MSB_PTR  ( (reg8 *) CNSL_USB__DMA_THRES_MSB)
#define CNSL_DMA_THRES_MSB_REG  (*(reg8 *) CNSL_USB__DMA_THRES_MSB)

#define CNSL_EP_ACTIVE_PTR      ( (reg8 *) CNSL_USB__EP_ACTIVE)
#define CNSL_EP_ACTIVE_REG      (*(reg8 *) CNSL_USB__EP_ACTIVE)
#define CNSL_EP_TYPE_PTR        ( (reg8 *) CNSL_USB__EP_TYPE)
#define CNSL_EP_TYPE_REG        (*(reg8 *) CNSL_USB__EP_TYPE)

#define CNSL_EP0_CNT_PTR        ( (reg8 *) CNSL_USB__EP0_CNT)
#define CNSL_EP0_CNT_REG        (*(reg8 *) CNSL_USB__EP0_CNT)
#define CNSL_EP0_CR_PTR         ( (reg8 *) CNSL_USB__EP0_CR)
#define CNSL_EP0_CR_REG         (*(reg8 *) CNSL_USB__EP0_CR)
#define CNSL_EP0_DR0_PTR        ( (reg8 *) CNSL_USB__EP0_DR0)
#define CNSL_EP0_DR0_REG        (*(reg8 *) CNSL_USB__EP0_DR0)
#define CNSL_EP0_DR1_PTR        ( (reg8 *) CNSL_USB__EP0_DR1)
#define CNSL_EP0_DR1_REG        (*(reg8 *) CNSL_USB__EP0_DR1)
#define CNSL_EP0_DR2_PTR        ( (reg8 *) CNSL_USB__EP0_DR2)
#define CNSL_EP0_DR2_REG        (*(reg8 *) CNSL_USB__EP0_DR2)
#define CNSL_EP0_DR3_PTR        ( (reg8 *) CNSL_USB__EP0_DR3)
#define CNSL_EP0_DR3_REG        (*(reg8 *) CNSL_USB__EP0_DR3)
#define CNSL_EP0_DR4_PTR        ( (reg8 *) CNSL_USB__EP0_DR4)
#define CNSL_EP0_DR4_REG        (*(reg8 *) CNSL_USB__EP0_DR4)
#define CNSL_EP0_DR5_PTR        ( (reg8 *) CNSL_USB__EP0_DR5)
#define CNSL_EP0_DR5_REG        (*(reg8 *) CNSL_USB__EP0_DR5)
#define CNSL_EP0_DR6_PTR        ( (reg8 *) CNSL_USB__EP0_DR6)
#define CNSL_EP0_DR6_REG        (*(reg8 *) CNSL_USB__EP0_DR6)
#define CNSL_EP0_DR7_PTR        ( (reg8 *) CNSL_USB__EP0_DR7)
#define CNSL_EP0_DR7_REG        (*(reg8 *) CNSL_USB__EP0_DR7)
#define CNSL_EP0_DR0_IND        CNSL_USB__EP0_DR0
#define CNSL_EP0_DR_BASE        (*(volatile CNSL_ep0_data_struct CYXDATA *) CNSL_USB__EP0_DR0)

#define CNSL_OSCLK_DR0_PTR      ( (reg8 *) CNSL_USB__OSCLK_DR0)
#define CNSL_OSCLK_DR0_REG      (*(reg8 *) CNSL_USB__OSCLK_DR0)
#define CNSL_OSCLK_DR1_PTR      ( (reg8 *) CNSL_USB__OSCLK_DR1)
#define CNSL_OSCLK_DR1_REG      (*(reg8 *) CNSL_USB__OSCLK_DR1)

#define CNSL_SIE_EP_INT_EN_PTR  ( (reg8 *) CNSL_USB__SIE_EP_INT_EN)
#define CNSL_SIE_EP_INT_EN_REG  (*(reg8 *) CNSL_USB__SIE_EP_INT_EN)
#define CNSL_SIE_EP_INT_SR_PTR  ( (reg8 *) CNSL_USB__SIE_EP_INT_SR)
#define CNSL_SIE_EP_INT_SR_REG  (*(reg8 *) CNSL_USB__SIE_EP_INT_SR)

#define CNSL_SIE_EP1_CNT0_PTR   ( (reg8 *) CNSL_USB__SIE_EP1_CNT0)
#define CNSL_SIE_EP1_CNT0_REG   (*(reg8 *) CNSL_USB__SIE_EP1_CNT0)
#define CNSL_SIE_EP1_CNT1_PTR   ( (reg8 *) CNSL_USB__SIE_EP1_CNT1)
#define CNSL_SIE_EP1_CNT1_REG   (*(reg8 *) CNSL_USB__SIE_EP1_CNT1)
#define CNSL_SIE_EP1_CR0_PTR    ( (reg8 *) CNSL_USB__SIE_EP1_CR0)
#define CNSL_SIE_EP1_CR0_REG    (*(reg8 *) CNSL_USB__SIE_EP1_CR0)
#define CNSL_SIE_EP1_CNT1_IND   CNSL_USB__SIE_EP1_CNT1
#define CNSL_SIE_EP1_CNT0_IND   CNSL_USB__SIE_EP1_CNT0
#define CNSL_SIE_EP1_CR0_IND    CNSL_USB__SIE_EP1_CR0
#define CNSL_SIE_EP_BASE        (*(volatile CNSL_sie_eps_struct CYXDATA *) \
                                            (CNSL_USB__SIE_EP1_CNT0 - sizeof(CNSL_sie_ep_struct)))

#define CNSL_SIE_EP2_CNT0_PTR   ( (reg8 *) CNSL_USB__SIE_EP2_CNT0)
#define CNSL_SIE_EP2_CNT0_REG   (*(reg8 *) CNSL_USB__SIE_EP2_CNT0)
#define CNSL_SIE_EP2_CNT1_PTR   ( (reg8 *) CNSL_USB__SIE_EP2_CNT1)
#define CNSL_SIE_EP2_CNT1_REG   (*(reg8 *) CNSL_USB__SIE_EP2_CNT1)
#define CNSL_SIE_EP2_CR0_PTR    ( (reg8 *) CNSL_USB__SIE_EP2_CR0)
#define CNSL_SIE_EP2_CR0_REG    (*(reg8 *) CNSL_USB__SIE_EP2_CR0)

#define CNSL_SIE_EP3_CNT0_PTR   ( (reg8 *) CNSL_USB__SIE_EP3_CNT0)
#define CNSL_SIE_EP3_CNT0_REG   (*(reg8 *) CNSL_USB__SIE_EP3_CNT0)
#define CNSL_SIE_EP3_CNT1_PTR   ( (reg8 *) CNSL_USB__SIE_EP3_CNT1)
#define CNSL_SIE_EP3_CNT1_REG   (*(reg8 *) CNSL_USB__SIE_EP3_CNT1)
#define CNSL_SIE_EP3_CR0_PTR    ( (reg8 *) CNSL_USB__SIE_EP3_CR0)
#define CNSL_SIE_EP3_CR0_REG    (*(reg8 *) CNSL_USB__SIE_EP3_CR0)

#define CNSL_SIE_EP4_CNT0_PTR   ( (reg8 *) CNSL_USB__SIE_EP4_CNT0)
#define CNSL_SIE_EP4_CNT0_REG   (*(reg8 *) CNSL_USB__SIE_EP4_CNT0)
#define CNSL_SIE_EP4_CNT1_PTR   ( (reg8 *) CNSL_USB__SIE_EP4_CNT1)
#define CNSL_SIE_EP4_CNT1_REG   (*(reg8 *) CNSL_USB__SIE_EP4_CNT1)
#define CNSL_SIE_EP4_CR0_PTR    ( (reg8 *) CNSL_USB__SIE_EP4_CR0)
#define CNSL_SIE_EP4_CR0_REG    (*(reg8 *) CNSL_USB__SIE_EP4_CR0)

#define CNSL_SIE_EP5_CNT0_PTR   ( (reg8 *) CNSL_USB__SIE_EP5_CNT0)
#define CNSL_SIE_EP5_CNT0_REG   (*(reg8 *) CNSL_USB__SIE_EP5_CNT0)
#define CNSL_SIE_EP5_CNT1_PTR   ( (reg8 *) CNSL_USB__SIE_EP5_CNT1)
#define CNSL_SIE_EP5_CNT1_REG   (*(reg8 *) CNSL_USB__SIE_EP5_CNT1)
#define CNSL_SIE_EP5_CR0_PTR    ( (reg8 *) CNSL_USB__SIE_EP5_CR0)
#define CNSL_SIE_EP5_CR0_REG    (*(reg8 *) CNSL_USB__SIE_EP5_CR0)

#define CNSL_SIE_EP6_CNT0_PTR   ( (reg8 *) CNSL_USB__SIE_EP6_CNT0)
#define CNSL_SIE_EP6_CNT0_REG   (*(reg8 *) CNSL_USB__SIE_EP6_CNT0)
#define CNSL_SIE_EP6_CNT1_PTR   ( (reg8 *) CNSL_USB__SIE_EP6_CNT1)
#define CNSL_SIE_EP6_CNT1_REG   (*(reg8 *) CNSL_USB__SIE_EP6_CNT1)
#define CNSL_SIE_EP6_CR0_PTR    ( (reg8 *) CNSL_USB__SIE_EP6_CR0)
#define CNSL_SIE_EP6_CR0_REG    (*(reg8 *) CNSL_USB__SIE_EP6_CR0)

#define CNSL_SIE_EP7_CNT0_PTR   ( (reg8 *) CNSL_USB__SIE_EP7_CNT0)
#define CNSL_SIE_EP7_CNT0_REG   (*(reg8 *) CNSL_USB__SIE_EP7_CNT0)
#define CNSL_SIE_EP7_CNT1_PTR   ( (reg8 *) CNSL_USB__SIE_EP7_CNT1)
#define CNSL_SIE_EP7_CNT1_REG   (*(reg8 *) CNSL_USB__SIE_EP7_CNT1)
#define CNSL_SIE_EP7_CR0_PTR    ( (reg8 *) CNSL_USB__SIE_EP7_CR0)
#define CNSL_SIE_EP7_CR0_REG    (*(reg8 *) CNSL_USB__SIE_EP7_CR0)

#define CNSL_SIE_EP8_CNT0_PTR   ( (reg8 *) CNSL_USB__SIE_EP8_CNT0)
#define CNSL_SIE_EP8_CNT0_REG   (*(reg8 *) CNSL_USB__SIE_EP8_CNT0)
#define CNSL_SIE_EP8_CNT1_PTR   ( (reg8 *) CNSL_USB__SIE_EP8_CNT1)
#define CNSL_SIE_EP8_CNT1_REG   (*(reg8 *) CNSL_USB__SIE_EP8_CNT1)
#define CNSL_SIE_EP8_CR0_PTR    ( (reg8 *) CNSL_USB__SIE_EP8_CR0)
#define CNSL_SIE_EP8_CR0_REG    (*(reg8 *) CNSL_USB__SIE_EP8_CR0)

#define CNSL_SOF0_PTR           ( (reg8 *) CNSL_USB__SOF0)
#define CNSL_SOF0_REG           (*(reg8 *) CNSL_USB__SOF0)
#define CNSL_SOF1_PTR           ( (reg8 *) CNSL_USB__SOF1)
#define CNSL_SOF1_REG           (*(reg8 *) CNSL_USB__SOF1)

#define CNSL_USB_CLK_EN_PTR     ( (reg8 *) CNSL_USB__USB_CLK_EN)
#define CNSL_USB_CLK_EN_REG     (*(reg8 *) CNSL_USB__USB_CLK_EN)

#define CNSL_USBIO_CR0_PTR      ( (reg8 *) CNSL_USB__USBIO_CR0)
#define CNSL_USBIO_CR0_REG      (*(reg8 *) CNSL_USB__USBIO_CR0)
#define CNSL_USBIO_CR1_PTR      ( (reg8 *) CNSL_USB__USBIO_CR1)
#define CNSL_USBIO_CR1_REG      (*(reg8 *) CNSL_USB__USBIO_CR1)

#define CNSL_DYN_RECONFIG_PTR   ( (reg8 *) CNSL_USB__DYN_RECONFIG)
#define CNSL_DYN_RECONFIG_REG   (*(reg8 *) CNSL_USB__DYN_RECONFIG)

#if (CY_PSOC4)
    #define CNSL_ARB_RW1_RA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW1_RA16)
    #define CNSL_ARB_RW1_RA16_REG   (*(reg32 *) CNSL_cy_m0s8_usb__ARB_RW1_RA16)
    #define CNSL_ARB_RW1_WA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW1_WA16)
    #define CNSL_ARB_RW1_WA16_REG   (*(reg32 *) CNSL_cy_m0s8_usb__ARB_RW1_WA16)
    #define CNSL_ARB_RW1_DR16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW1_DR16)
    #define CNSL_ARB_RW1_DR16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW1_DR16)
    #define CNSL_ARB_EP16_BASE      (*(volatile CNSL_arb_eps_reg16_struct CYXDATA *) \
                                                (CNSL_USB__ARB_RW1_WA16 - sizeof(CNSL_arb_ep_reg16_struct)))

    #define CNSL_ARB_RW2_DR16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW2_DR16)
    #define CNSL_ARB_RW2_RA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW2_RA16)
    #define CNSL_ARB_RW2_WA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW2_WA16)

    #define CNSL_ARB_RW3_DR16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW3_DR16)
    #define CNSL_ARB_RW3_RA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW3_RA16)
    #define CNSL_ARB_RW3_WA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW3_WA16)

    #define CNSL_ARB_RW4_DR16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW4_DR16)
    #define CNSL_ARB_RW4_RA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW4_RA16)
    #define CNSL_ARB_RW4_WA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW4_WA16)

    #define CNSL_ARB_RW5_DR16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW5_DR16)
    #define CNSL_ARB_RW5_RA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW5_RA16)
    #define CNSL_ARB_RW5_WA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW5_WA16)

    #define CNSL_ARB_RW6_DR16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW6_DR16)
    #define CNSL_ARB_RW6_RA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW6_RA16)
    #define CNSL_ARB_RW6_WA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW6_WA16)

    #define CNSL_ARB_RW7_DR16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW7_DR16)
    #define CNSL_ARB_RW7_RA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW7_RA16)
    #define CNSL_ARB_RW7_WA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW7_WA16)

    #define CNSL_ARB_RW8_DR16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW8_DR16)
    #define CNSL_ARB_RW8_RA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW8_RA16)
    #define CNSL_ARB_RW8_WA16_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__ARB_RW8_WA16)

    #define CNSL_OSCLK_DR16_PTR     ( (reg32 *) CNSL_cy_m0s8_usb__OSCLK_DR16)
    #define CNSL_OSCLK_DR16_REG     (*(reg32 *) CNSL_cy_m0s8_usb__OSCLK_DR16)

    #define CNSL_SOF16_PTR          ( (reg32 *) CNSL_cy_m0s8_usb__SOF16)
    #define CNSL_SOF16_REG          (*(reg32 *) CNSL_cy_m0s8_usb__SOF16)
    
    #define CNSL_CWA16_PTR          ( (reg32 *) CNSL_cy_m0s8_usb__CWA16)
    #define CNSL_CWA16_REG          (*(reg32 *) CNSL_cy_m0s8_usb__CWA16)

    #define CNSL_DMA_THRES16_PTR    ( (reg32 *) CNSL_cy_m0s8_usb__DMA_THRES16)
    #define CNSL_DMA_THRES16_REG    (*(reg32 *) CNSL_cy_m0s8_usb__DMA_THRES16)

    #define CNSL_USB_CLK_EN_PTR     ( (reg32 *) CNSL_cy_m0s8_usb__USB_CLK_EN)
    #define CNSL_USB_CLK_EN_REG     (*(reg32 *) CNSL_cy_m0s8_usb__USB_CLK_EN)

    #define CNSL_USBIO_CR2_PTR      ( (reg32 *) CNSL_cy_m0s8_usb__USBIO_CR2)
    #define CNSL_USBIO_CR2_REG      (*(reg32 *) CNSL_cy_m0s8_usb__USBIO_CR2)

    #define CNSL_USB_MEM            ( (reg32 *) CNSL_cy_m0s8_usb__MEM_DATA0)

    #define CNSL_POWER_CTRL_REG      (*(reg32 *) CNSL_cy_m0s8_usb__USB_POWER_CTRL)
    #define CNSL_POWER_CTRL_PTR      ( (reg32 *) CNSL_cy_m0s8_usb__USB_POWER_CTRL)

    #define CNSL_CHGDET_CTRL_REG     (*(reg32 *) CNSL_cy_m0s8_usb__USB_CHGDET_CTRL)
    #define CNSL_CHGDET_CTRL_PTR     ( (reg32 *) CNSL_cy_m0s8_usb__USB_CHGDET_CTRL)

    #define CNSL_USBIO_CTRL_REG      (*(reg32 *) CNSL_cy_m0s8_usb__USB_USBIO_CTRL)
    #define CNSL_USBIO_CTRL_PTR      ( (reg32 *) CNSL_cy_m0s8_usb__USB_USBIO_CTRL)

    #define CNSL_FLOW_CTRL_REG       (*(reg32 *) CNSL_cy_m0s8_usb__USB_FLOW_CTRL)
    #define CNSL_FLOW_CTRL_PTR       ( (reg32 *) CNSL_cy_m0s8_usb__USB_FLOW_CTRL)

    #define CNSL_LPM_CTRL_REG        (*(reg32 *) CNSL_cy_m0s8_usb__USB_LPM_CTRL)
    #define CNSL_LPM_CTRL_PTR        ( (reg32 *) CNSL_cy_m0s8_usb__USB_LPM_CTRL)

    #define CNSL_LPM_STAT_REG        (*(reg32 *) CNSL_cy_m0s8_usb__USB_LPM_STAT)
    #define CNSL_LPM_STAT_PTR        ( (reg32 *) CNSL_cy_m0s8_usb__USB_LPM_STAT)

    #define CNSL_PHY_CONTROL_REG     (*(reg32 *) CNSL_cy_m0s8_usb__USB_PHY_CONTROL)
    #define CNSL_PHY_CONTROL_PTR     ( (reg32 *) CNSL_cy_m0s8_usb__USB_PHY_CONTROL)

    #define CNSL_INTR_SIE_REG        (*(reg32 *) CNSL_cy_m0s8_usb__USB_INTR_SIE)
    #define CNSL_INTR_SIE_PTR        ( (reg32 *) CNSL_cy_m0s8_usb__USB_INTR_SIE)

    #define CNSL_INTR_SIE_SET_REG    (*(reg32 *) CNSL_cy_m0s8_usb__USB_INTR_SIE_SET)
    #define CNSL_INTR_SIE_SET_PTR    ( (reg32 *) CNSL_cy_m0s8_usb__USB_INTR_SIE_SET)

    #define CNSL_INTR_SIE_MASK_REG   (*(reg32 *) CNSL_cy_m0s8_usb__USB_INTR_SIE_MASK)
    #define CNSL_INTR_SIE_MASK_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__USB_INTR_SIE_MASK)

    #define CNSL_INTR_SIE_MASKED_REG (*(reg32 *) CNSL_cy_m0s8_usb__USB_INTR_SIE_MASKED)
    #define CNSL_INTR_SIE_MASKED_PTR ( (reg32 *) CNSL_cy_m0s8_usb__USB_INTR_SIE_MASKED)

    #define CNSL_INTR_LVL_SEL_REG    (*(reg32 *) CNSL_cy_m0s8_usb__USB_INTR_LVL_SEL)
    #define CNSL_INTR_LVL_SEL_PTR    ( (reg32 *) CNSL_cy_m0s8_usb__USB_INTR_LVL_SEL)

    #define CNSL_INTR_CAUSE_HI_REG   (*(reg32 *) CNSL_cy_m0s8_usb__USB_INTR_CAUSE_HI)
    #define CNSL_INTR_CAUSE_HI_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__USB_INTR_CAUSE_HI)

    #define CNSL_INTR_CAUSE_LO_REG   (*(reg32 *) CNSL_cy_m0s8_usb__USB_INTR_CAUSE_LO)
    #define CNSL_INTR_CAUSE_LO_PTR   ( (reg32 *) CNSL_cy_m0s8_usb__USB_INTR_CAUSE_LO)

    #define CNSL_INTR_CAUSE_MED_REG  (*(reg32 *) CNSL_cy_m0s8_usb__USB_INTR_CAUSE_MED)
    #define CNSL_INTR_CAUSE_MED_PTR  ( (reg32 *) CNSL_cy_m0s8_usb__USB_INTR_CAUSE_MED)

    #define CNSL_DFT_CTRL_REG        (*(reg32 *) CNSL_cy_m0s8_usb__USB_DFT_CTRL)
    #define CNSL_DFT_CTRL_PTR        ( (reg32 *) CNSL_cy_m0s8_usb__USB_DFT_CTRL)

    #if (CNSL_VBUS_MONITORING_ENABLE)
        #if (CNSL_VBUS_POWER_PAD_ENABLE)
            /* Vbus power pad pin is hard wired to P13[2] */
            #define CNSL_VBUS_STATUS_REG    (*(reg32 *) CYREG_GPIO_PRT13_PS)
            #define CNSL_VBUS_STATUS_PTR    ( (reg32 *) CYREG_GPIO_PRT13_PS)
            #define CNSL_VBUS_VALID         (0x04u)
        #else
            /* Vbus valid pin is hard wired to P0[0] */
            #define CNSL_VBUS_STATUS_REG    (*(reg32 *) CYREG_GPIO_PRT0_PS)
            #define CNSL_VBUS_STATUS_PTR    ( (reg32 *) CYREG_GPIO_PRT0_PS)
            #define CNSL_VBUS_VALID         (0x01u)
        #endif
    #endif /*(CNSL_VBUS_MONITORING_ENABLE) */

    #define CNSL_BURSTEND_0_TR_OUTPUT    (CNSL_cy_m0s8_usb__BURSTEND0_TR_OUTPUT)
    #define CNSL_BURSTEND_1_TR_OUTPUT    (CNSL_cy_m0s8_usb__BURSTEND1_TR_OUTPUT)
    #define CNSL_BURSTEND_2_TR_OUTPUT    (CNSL_cy_m0s8_usb__BURSTEND2_TR_OUTPUT)
    #define CNSL_BURSTEND_3_TR_OUTPUT    (CNSL_cy_m0s8_usb__BURSTEND3_TR_OUTPUT)
    #define CNSL_BURSTEND_4_TR_OUTPUT    (CNSL_cy_m0s8_usb__BURSTEND4_TR_OUTPUT)
    #define CNSL_BURSTEND_5_TR_OUTPUT    (CNSL_cy_m0s8_usb__BURSTEND5_TR_OUTPUT)
    #define CNSL_BURSTEND_6_TR_OUTPUT    (CNSL_cy_m0s8_usb__BURSTEND6_TR_OUTPUT)
    #define CNSL_BURSTEND_7_TR_OUTPUT    (CNSL_cy_m0s8_usb__BURSTEND7_TR_OUTPUT)
    
#else /* (CY_PSOC3 || CY_PSOC5LP) */

    /* CNSL_PM_USB_CR0 */
    #define CNSL_PM_USB_CR0_PTR     ( (reg8 *) CYREG_PM_USB_CR0)
    #define CNSL_PM_USB_CR0_REG     (*(reg8 *) CYREG_PM_USB_CR0)

    /* CNSL_PM_ACT/STBY_CFG */
    #define CNSL_PM_ACT_CFG_PTR     ( (reg8 *) CNSL_USB__PM_ACT_CFG)
    #define CNSL_PM_ACT_CFG_REG     (*(reg8 *) CNSL_USB__PM_ACT_CFG)
    #define CNSL_PM_STBY_CFG_PTR    ( (reg8 *) CNSL_USB__PM_STBY_CFG)
    #define CNSL_PM_STBY_CFG_REG    (*(reg8 *) CNSL_USB__PM_STBY_CFG)

    #if (!CY_PSOC5LP)
        #define CNSL_USBIO_CR2_PTR  (  (reg8 *) CNSL_USB__USBIO_CR2)
        #define CNSL_USBIO_CR2_REG  (* (reg8 *) CNSL_USB__USBIO_CR2)
    #endif /* (!CY_PSOC5LP) */

    /* CNSL_USB_MEM - USB IP memory buffer */
    #define CNSL_USB_MEM            ((reg8 *) CYDEV_USB_MEM_BASE)

    #if (CNSL_VBUS_MONITORING_ENABLE)
        #if (CNSL_VBUS_MONITORING_INTERNAL)
            #define CNSL_VBUS_STATUS_REG    (*(reg8 *) CNSL_VBUS__PS)
            #define CNSL_VBUS_STATUS_PTR    ( (reg8 *) CNSL_VBUS__PS)
            #define CNSL_VBUS_VALID         (CNSL_VBUS__MASK)
        #else
            #define CNSL_VBUS_STATUS_REG    (*(reg8 *) CNSL_Vbus_ps_sts_sts_reg__STATUS_REG)
            #define CNSL_VBUS_STATUS_PTR    ( (reg8 *) CNSL_Vbus_ps_sts_sts_reg__STATUS_REG)
            #define CNSL_VBUS_VALID         (CNSL_Vbus_ps_sts_sts_reg__MASK)
        #endif /* (CNSL_VBUS_MONITORING_INTERNAL) */
    #endif /*(CNSL_VBUS_MONITORING_ENABLE) */
#endif /* (CY_PSOC4) */


/***************************************
*       Interrupt source constants
***************************************/

#define CNSL_DP_INTC_PRIORITY       CNSL_dp_int__INTC_PRIOR_NUM
#define CNSL_DP_INTC_VECT_NUM       CNSL_dp_int__INTC_NUMBER

#if (CY_PSOC4)
    #define CNSL_DMA_AUTO_INTR_PRIO (0u)
    
    #define CNSL_INTR_HI_PRIORITY   CNSL_high_int__INTC_PRIOR_NUM
    #define CNSL_INTR_HI_VECT_NUM   CNSL_high_int__INTC_NUMBER

    #define CNSL_INTR_MED_PRIORITY  CNSL_med_int__INTC_PRIOR_NUM
    #define CNSL_INTR_MED_VECT_NUM  CNSL_med_int__INTC_NUMBER

    #define CNSL_INTR_LO_PRIORITY   CNSL_lo_int__INTC_PRIOR_NUM
    #define CNSL_INTR_LO_VECT_NUM   CNSL_lo_int__INTC_NUMBER

    /* Interrupt sources in CNSL_isrCallbacks[] table */
    #define CNSL_SOF_INTR_NUM       (0u)
    #define CNSL_BUS_RESET_INT_NUM  (1u)
    #define CNSL_EP0_INTR_NUM       (2u)
    #define CNSL_LPM_INTR_NUM       (3u)
    #define CNSL_ARB_EP_INTR_NUM    (4u)
    #define CNSL_EP1_INTR_NUM       (5u)
    #define CNSL_EP2_INTR_NUM       (6u)
    #define CNSL_EP3_INTR_NUM       (7u)
    #define CNSL_EP4_INTR_NUM       (8u)
    #define CNSL_EP5_INTR_NUM       (9u)
    #define CNSL_EP6_INTR_NUM       (10u)
    #define CNSL_EP7_INTR_NUM       (11u)
    #define CNSL_EP8_INTR_NUM       (12u)

#else
    #define CNSL_BUS_RESET_PRIOR    CNSL_bus_reset__INTC_PRIOR_NUM
    #define CNSL_BUS_RESET_MASK     CNSL_bus_reset__INTC_MASK
    #define CNSL_BUS_RESET_VECT_NUM CNSL_bus_reset__INTC_NUMBER

    #define CNSL_SOF_PRIOR          CNSL_sof_int__INTC_PRIOR_NUM
    #define CNSL_SOF_MASK           CNSL_sof_int__INTC_MASK
    #define CNSL_SOF_VECT_NUM       CNSL_sof_int__INTC_NUMBER

    #define CNSL_EP_0_PRIOR         CNSL_ep_0__INTC_PRIOR_NUM
    #define CNSL_EP_0_MASK          CNSL_ep_0__INTC_MASK
    #define CNSL_EP_0_VECT_NUM      CNSL_ep_0__INTC_NUMBER

    #define CNSL_EP_1_PRIOR         CNSL_ep_1__INTC_PRIOR_NUM
    #define CNSL_EP_1_MASK          CNSL_ep_1__INTC_MASK
    #define CNSL_EP_1_VECT_NUM      CNSL_ep_1__INTC_NUMBER

    #define CNSL_EP_2_PRIOR         CNSL_ep_2__INTC_PRIOR_NUM
    #define CNSL_EP_2_MASK          CNSL_ep_2__INTC_MASK
    #define CNSL_EP_2_VECT_NUM      CNSL_ep_2__INTC_NUMBER

    #define CNSL_EP_3_PRIOR         CNSL_ep_3__INTC_PRIOR_NUM
    #define CNSL_EP_3_MASK          CNSL_ep_3__INTC_MASK
    #define CNSL_EP_3_VECT_NUM      CNSL_ep_3__INTC_NUMBER

    #define CNSL_EP_4_PRIOR         CNSL_ep_4__INTC_PRIOR_NUM
    #define CNSL_EP_4_MASK          CNSL_ep_4__INTC_MASK
    #define CNSL_EP_4_VECT_NUM      CNSL_ep_4__INTC_NUMBER

    #define CNSL_EP_5_PRIOR         CNSL_ep_5__INTC_PRIOR_NUM
    #define CNSL_EP_5_MASK          CNSL_ep_5__INTC_MASK
    #define CNSL_EP_5_VECT_NUM      CNSL_ep_5__INTC_NUMBER

    #define CNSL_EP_6_PRIOR         CNSL_ep_6__INTC_PRIOR_NUM
    #define CNSL_EP_6_MASK          CNSL_ep_6__INTC_MASK
    #define CNSL_EP_6_VECT_NUM      CNSL_ep_6__INTC_NUMBER

    #define CNSL_EP_7_PRIOR         CNSL_ep_7__INTC_PRIOR_NUM
    #define CNSL_EP_7_MASK          CNSL_ep_7__INTC_MASK
    #define CNSL_EP_7_VECT_NUM      CNSL_ep_7__INTC_NUMBER

    #define CNSL_EP_8_PRIOR         CNSL_ep_8__INTC_PRIOR_NUM
    #define CNSL_EP_8_MASK          CNSL_ep_8__INTC_MASK
    #define CNSL_EP_8_VECT_NUM      CNSL_ep_8__INTC_NUMBER

    /* Set ARB ISR priority 0 to be highest for all EPX ISRs. */
    #define CNSL_ARB_PRIOR          (0u)
    #define CNSL_ARB_MASK           CNSL_arb_int__INTC_MASK
    #define CNSL_ARB_VECT_NUM       CNSL_arb_int__INTC_NUMBER
#endif /* (CY_PSOC4) */


/***************************************
*       Endpoint 0 offsets (Table 9-2)
***************************************/
#define CNSL_bmRequestTypeReg      CNSL_EP0_DR_BASE.epData[0u]
#define CNSL_bRequestReg           CNSL_EP0_DR_BASE.epData[1u]
#define CNSL_wValueLoReg           CNSL_EP0_DR_BASE.epData[2u]
#define CNSL_wValueHiReg           CNSL_EP0_DR_BASE.epData[3u]
#define CNSL_wIndexLoReg           CNSL_EP0_DR_BASE.epData[4u]
#define CNSL_wIndexHiReg           CNSL_EP0_DR_BASE.epData[5u]
#define CNSL_wLengthLoReg          CNSL_EP0_DR_BASE.epData[6u]
#define CNSL_wLengthHiReg          CNSL_EP0_DR_BASE.epData[7u]

/* Compatibility defines */
#define CNSL_lengthLoReg           CNSL_EP0_DR_BASE.epData[6u]
#define CNSL_lengthHiReg           CNSL_EP0_DR_BASE.epData[7u]


/***************************************
*       Register Constants
***************************************/

#define CNSL_3500MV     (3500u)
#if (CY_PSOC4)
    #define CNSL_VDDD_MV    (CYDEV_VBUS_MV)
#else
    #define CNSL_VDDD_MV    (CYDEV_VDDD_MV)
#endif /* (CY_PSOC4) */


/* CNSL_USB_CLK */
#define CNSL_USB_CLK_CSR_CLK_EN_POS (0u)
#define CNSL_USB_CLK_CSR_CLK_EN     ((uint8) ((uint8) 0x1u << CNSL_USB_CLK_CSR_CLK_EN_POS))
#define CNSL_USB_CLK_ENABLE         (CNSL_USB_CLK_CSR_CLK_EN)

/* CNSL_CR0 */
#define CNSL_CR0_DEVICE_ADDRESS_POS     (0u)
#define CNSL_CR0_ENABLE_POS             (7u)
#define CNSL_CR0_DEVICE_ADDRESS_MASK    ((uint8) ((uint8) 0x7Fu << CNSL_CR0_DEVICE_ADDRESS_POS))
#define CNSL_CR0_ENABLE                 ((uint8) ((uint8) 0x01u << CNSL_CR0_ENABLE_POS))


/* CNSL_CR1 */
#define CNSL_CR1_REG_ENABLE_POS         (0u)
#define CNSL_CR1_ENABLE_LOCK_POS        (1u)
#define CNSL_CR1_BUS_ACTIVITY_POS       (2u)
#define CNSL_CR1_TRIM_OFFSET_MSB_POS    (3u)
#define CNSL_CR1_REG_ENABLE             ((uint8) ((uint8) 0x1u << CNSL_CR1_REG_ENABLE_POS))
#define CNSL_CR1_ENABLE_LOCK            ((uint8) ((uint8) 0x1u << CNSL_CR1_ENABLE_LOCK_POS))
#define CNSL_CR1_BUS_ACTIVITY           ((uint8) ((uint8) 0x1u << CNSL_CR1_BUS_ACTIVITY_POS))
#define CNSL_CR1_TRIM_OFFSET_MSB        ((uint8) ((uint8) 0x1u << CNSL_CR1_TRIM_OFFSET_MSB_POS))

/* CNSL_EPX_CNT */
#define CNSL_EP0_CNT_DATA_TOGGLE        (0x80u)
#define CNSL_EPX_CNT_DATA_TOGGLE        (0x80u)
#define CNSL_EPX_CNT0_MASK              (0x0Fu)
#define CNSL_EPX_CNTX_MSB_MASK          (0x07u)
#define CNSL_EPX_CNTX_ADDR_SHIFT        (0x04u)
#define CNSL_EPX_CNTX_ADDR_OFFSET       (0x10u)
#define CNSL_EPX_CNTX_CRC_COUNT         (0x02u)
#define CNSL_EPX_DATA_BUF_MAX           (512u)

/* CNSL_USBIO_CR0 */

#define CNSL_USBIO_CR0_TEN              (0x80u)
#define CNSL_USBIO_CR0_TSE0             (0x40u)
#define CNSL_USBIO_CR0_TD               (0x20u)
#define CNSL_USBIO_CR0_RD               (0x01u)

/* CNSL_USBIO_CR1 */
#define CNSL_USBIO_CR1_DM0_POS      (0u)
#define CNSL_USBIO_CR1_DP0_POS      (1u)
#define CNSL_USBIO_CR1_USBPUEN_POS  (2u)
#define CNSL_USBIO_CR1_IOMODE_POS   (5u)
#define CNSL_USBIO_CR1_DM0          ((uint8) ((uint8) 0x1u << CNSL_USBIO_CR1_DM0_POS))
#define CNSL_USBIO_CR1_DP0          ((uint8) ((uint8) 0x1u << CNSL_USBIO_CR1_DP0_POS))
#define CNSL_USBIO_CR1_USBPUEN      ((uint8) ((uint8) 0x1u << CNSL_USBIO_CR1_USBPUEN_POS))
#define CNSL_USBIO_CR1_IOMODE       ((uint8) ((uint8) 0x1u << CNSL_USBIO_CR1_IOMODE_POS))

/* CNSL_FASTCLK_IMO_CR */
#define CNSL_FASTCLK_IMO_CR_USBCLK_ON   (0x40u)
#define CNSL_FASTCLK_IMO_CR_XCLKEN      (0x20u)
#define CNSL_FASTCLK_IMO_CR_FX2ON       (0x10u)

/* CNSL_ARB_EPX_CFG */
#define CNSL_ARB_EPX_CFG_IN_DATA_RDY_POS    (0u)
#define CNSL_ARB_EPX_CFG_DMA_REQ_POS        (1u)
#define CNSL_ARB_EPX_CFG_CRC_BYPASS_POS     (2u)
#define CNSL_ARB_EPX_CFG_RESET_POS          (3u)
#define CNSL_ARB_EPX_CFG_IN_DATA_RDY        ((uint8) ((uint8) 0x1u << CNSL_ARB_EPX_CFG_IN_DATA_RDY_POS))
#define CNSL_ARB_EPX_CFG_DMA_REQ            ((uint8) ((uint8) 0x1u << CNSL_ARB_EPX_CFG_DMA_REQ_POS))
#define CNSL_ARB_EPX_CFG_CRC_BYPASS         ((uint8) ((uint8) 0x1u << CNSL_ARB_EPX_CFG_CRC_BYPASS_POS))
#define CNSL_ARB_EPX_CFG_RESET              ((uint8) ((uint8) 0x1u << CNSL_ARB_EPX_CFG_RESET_POS))

/* CNSL_ARB_EPX_INT / SR */
#define CNSL_ARB_EPX_INT_IN_BUF_FULL_POS    (0u)
#define CNSL_ARB_EPX_INT_DMA_GNT_POS        (1u)
#define CNSL_ARB_EPX_INT_BUF_OVER_POS       (2u)
#define CNSL_ARB_EPX_INT_BUF_UNDER_POS      (3u)
#define CNSL_ARB_EPX_INT_ERR_INT_POS        (4u)
#define CNSL_ARB_EPX_INT_IN_BUF_FULL        ((uint8) ((uint8) 0x1u << CNSL_ARB_EPX_INT_IN_BUF_FULL_POS))
#define CNSL_ARB_EPX_INT_DMA_GNT            ((uint8) ((uint8) 0x1u << CNSL_ARB_EPX_INT_DMA_GNT_POS))
#define CNSL_ARB_EPX_INT_BUF_OVER           ((uint8) ((uint8) 0x1u << CNSL_ARB_EPX_INT_BUF_OVER_POS))
#define CNSL_ARB_EPX_INT_BUF_UNDER          ((uint8) ((uint8) 0x1u << CNSL_ARB_EPX_INT_BUF_UNDER_POS))
#define CNSL_ARB_EPX_INT_ERR_INT            ((uint8) ((uint8) 0x1u << CNSL_ARB_EPX_INT_ERR_INT_POS))

#if (CY_PSOC4)
#define CNSL_ARB_EPX_INT_DMA_TERMIN_POS     (5u)
#define CNSL_ARB_EPX_INT_DMA_TERMIN         ((uint8) ((uint8) 0x1u << CNSL_ARB_EPX_INT_DMA_TERMIN_POS))
#endif /* (CY_PSOC4) */

/* Common arbiter interrupt sources for all PSoC devices. */
#define CNSL_ARB_EPX_INT_COMMON    (CNSL_ARB_EPX_INT_IN_BUF_FULL | \
                                                CNSL_ARB_EPX_INT_DMA_GNT     | \
                                                CNSL_ARB_EPX_INT_BUF_OVER    | \
                                                CNSL_ARB_EPX_INT_BUF_UNDER   | \
                                                CNSL_ARB_EPX_INT_ERR_INT)

#if (CY_PSOC4)
    #define CNSL_ARB_EPX_INT_ALL    (CNSL_ARB_EPX_INT_COMMON | CNSL_ARB_EPX_INT_DMA_TERMIN)
#else
    #define CNSL_ARB_EPX_INT_ALL    (CNSL_ARB_EPX_INT_COMMON)
#endif /* (CY_PSOC4) */

/* CNSL_ARB_CFG */
#define CNSL_ARB_CFG_AUTO_MEM_POS   (4u)
#define CNSL_ARB_CFG_DMA_CFG_POS    (5u)
#define CNSL_ARB_CFG_CFG_CMP_POS    (7u)
#define CNSL_ARB_CFG_AUTO_MEM       ((uint8) ((uint8) 0x1u << CNSL_ARB_CFG_AUTO_MEM_POS))
#define CNSL_ARB_CFG_DMA_CFG_MASK   ((uint8) ((uint8) 0x3u << CNSL_ARB_CFG_DMA_CFG_POS))
#define CNSL_ARB_CFG_DMA_CFG_NONE   ((uint8) ((uint8) 0x0u << CNSL_ARB_CFG_DMA_CFG_POS))
#define CNSL_ARB_CFG_DMA_CFG_MANUAL ((uint8) ((uint8) 0x1u << CNSL_ARB_CFG_DMA_CFG_POS))
#define CNSL_ARB_CFG_DMA_CFG_AUTO   ((uint8) ((uint8) 0x2u << CNSL_ARB_CFG_DMA_CFG_POS))
#define CNSL_ARB_CFG_CFG_CMP        ((uint8) ((uint8) 0x1u << CNSL_ARB_CFG_CFG_CMP_POS))

/* CNSL_DYN_RECONFIG */
#define CNSL_DYN_RECONFIG_EP_SHIFT      (1u)
#define CNSL_DYN_RECONFIG_ENABLE_POS    (0u)
#define CNSL_DYN_RECONFIG_EPNO_POS      (1u)
#define CNSL_DYN_RECONFIG_RDY_STS_POS   (4u)
#define CNSL_DYN_RECONFIG_ENABLE        ((uint8) ((uint8) 0x1u << CNSL_DYN_RECONFIG_ENABLE_POS))
#define CNSL_DYN_RECONFIG_EPNO_MASK     ((uint8) ((uint8) 0x7u << CNSL_DYN_RECONFIG_EPNO_POS))
#define CNSL_DYN_RECONFIG_RDY_STS       ((uint8) ((uint8) 0x1u << CNSL_DYN_RECONFIG_RDY_STS_POS))

/* CNSL_ARB_INT */
#define CNSL_ARB_INT_EP1_INTR_POS          (0u) /* [0] Interrupt for USB EP1 */
#define CNSL_ARB_INT_EP2_INTR_POS          (1u) /* [1] Interrupt for USB EP2 */
#define CNSL_ARB_INT_EP3_INTR_POS          (2u) /* [2] Interrupt for USB EP3 */
#define CNSL_ARB_INT_EP4_INTR_POS          (3u) /* [3] Interrupt for USB EP4 */
#define CNSL_ARB_INT_EP5_INTR_POS          (4u) /* [4] Interrupt for USB EP5 */
#define CNSL_ARB_INT_EP6_INTR_POS          (5u) /* [5] Interrupt for USB EP6 */
#define CNSL_ARB_INT_EP7_INTR_POS          (6u) /* [6] Interrupt for USB EP7 */
#define CNSL_ARB_INT_EP8_INTR_POS          (7u) /* [7] Interrupt for USB EP8 */
#define CNSL_ARB_INT_EP1_INTR              ((uint8) ((uint8) 0x1u << CNSL_ARB_INT_EP1_INTR_POS))
#define CNSL_ARB_INT_EP2_INTR              ((uint8) ((uint8) 0x1u << CNSL_ARB_INT_EP2_INTR_POS))
#define CNSL_ARB_INT_EP3_INTR              ((uint8) ((uint8) 0x1u << CNSL_ARB_INT_EP3_INTR_POS))
#define CNSL_ARB_INT_EP4_INTR              ((uint8) ((uint8) 0x1u << CNSL_ARB_INT_EP4_INTR_POS))
#define CNSL_ARB_INT_EP5_INTR              ((uint8) ((uint8) 0x1u << CNSL_ARB_INT_EP5_INTR_POS))
#define CNSL_ARB_INT_EP6_INTR              ((uint8) ((uint8) 0x1u << CNSL_ARB_INT_EP6_INTR_POS))
#define CNSL_ARB_INT_EP7_INTR              ((uint8) ((uint8) 0x1u << CNSL_ARB_INT_EP7_INTR_POS))
#define CNSL_ARB_INT_EP8_INTR              ((uint8) ((uint8) 0x1u << CNSL_ARB_INT_EP8_INTR_POS))

/* CNSL_SIE_INT */
#define CNSL_SIE_INT_EP1_INTR_POS          (0u) /* [0] Interrupt for USB EP1 */
#define CNSL_SIE_INT_EP2_INTR_POS          (1u) /* [1] Interrupt for USB EP2 */
#define CNSL_SIE_INT_EP3_INTR_POS          (2u) /* [2] Interrupt for USB EP3 */
#define CNSL_SIE_INT_EP4_INTR_POS          (3u) /* [3] Interrupt for USB EP4 */
#define CNSL_SIE_INT_EP5_INTR_POS          (4u) /* [4] Interrupt for USB EP5 */
#define CNSL_SIE_INT_EP6_INTR_POS          (5u) /* [5] Interrupt for USB EP6 */
#define CNSL_SIE_INT_EP7_INTR_POS          (6u) /* [6] Interrupt for USB EP7 */
#define CNSL_SIE_INT_EP8_INTR_POS          (7u) /* [7] Interrupt for USB EP8 */
#define CNSL_SIE_INT_EP1_INTR              ((uint8) ((uint8) 0x01u << CNSL_SIE_INT_EP1_INTR_POS))
#define CNSL_SIE_INT_EP2_INTR              ((uint8) ((uint8) 0x01u << CNSL_SIE_INT_EP2_INTR_POS))
#define CNSL_SIE_INT_EP3_INTR              ((uint8) ((uint8) 0x01u << CNSL_SIE_INT_EP3_INTR_POS))
#define CNSL_SIE_INT_EP4_INTR              ((uint8) ((uint8) 0x01u << CNSL_SIE_INT_EP4_INTR_POS))
#define CNSL_SIE_INT_EP5_INTR              ((uint8) ((uint8) 0x01u << CNSL_SIE_INT_EP5_INTR_POS))
#define CNSL_SIE_INT_EP6_INTR              ((uint8) ((uint8) 0x01u << CNSL_SIE_INT_EP6_INTR_POS))
#define CNSL_SIE_INT_EP7_INTR              ((uint8) ((uint8) 0x01u << CNSL_SIE_INT_EP7_INTR_POS))
#define CNSL_SIE_INT_EP8_INTR              ((uint8) ((uint8) 0x01u << CNSL_SIE_INT_EP8_INTR_POS))

#if (CY_PSOC4)
    /* CNSL_POWER_CTRL_REG */
    #define CNSL_POWER_CTRL_VBUS_VALID_OVR_POS       (0u)  /* [0] */
    #define CNSL_POWER_CTRL_SUSPEND_POS              (2u)  /* [1] */
    #define CNSL_POWER_CTRL_SUSPEND_DEL_POS          (3u)  /* [3] */
    #define CNSL_POWER_CTRL_ISOLATE_POS              (4u)  /* [4] */
    #define CNSL_POWER_CTRL_CHDET_PWR_CTL_POS        (5u)  /* [5] */
    #define CNSL_POWER_CTRL_ENABLE_DM_PULLDOWN_POS   (25u) /* [25] */
    #define CNSL_POWER_CTRL_ENABLE_VBUS_PULLDOWN_POS (26u) /* [26] */
    #define CNSL_POWER_CTRL_ENABLE_RCVR_POS          (27u) /* [27] */
    #define CNSL_POWER_CTRL_ENABLE_DPO_POS           (28u) /* [28] */
    #define CNSL_POWER_CTRL_ENABLE_DMO_POS           (29u) /* [29] */
    #define CNSL_POWER_CTRL_ENABLE_CHGDET_POS        (30u) /* [30] */
    #define CNSL_POWER_CTRL_ENABLE_POS               (31u) /* [31] */
    #define CNSL_POWER_CTRL_VBUS_VALID_OVR_MASK      ((uint32) 0x03u << CNSL_POWER_CTRL_VBUS_VALID_OVR_POS)
    #define CNSL_POWER_CTRL_VBUS_VALID_OVR_0         ((uint32) 0x00u << CNSL_POWER_CTRL_VBUS_VALID_OVR_POS)
    #define CNSL_POWER_CTRL_VBUS_VALID_OVR_1         ((uint32) 0x01u << CNSL_POWER_CTRL_VBUS_VALID_OVR_POS)
    #define CNSL_POWER_CTRL_VBUS_VALID_OVR_GPIO      ((uint32) 0x02u << CNSL_POWER_CTRL_VBUS_VALID_OVR_POS)
    #define CNSL_POWER_CTRL_VBUS_VALID_OVR_PHY       ((uint32) 0x03u << CNSL_POWER_CTRL_VBUS_VALID_OVR_POS)
    #define CNSL_POWER_CTRL_SUSPEND                  ((uint32) 0x01u << CNSL_POWER_CTRL_SUSPEND_POS)
    #define CNSL_POWER_CTRL_SUSPEND_DEL              ((uint32) 0x01u << CNSL_POWER_CTRL_SUSPEND_DEL_POS)
    #define CNSL_POWER_CTRL_ISOLATE                  ((uint32) 0x01u << CNSL_POWER_CTRL_ISOLATE_POS)
    #define CNSL_POWER_CTRL_CHDET_PWR_CTL_MASK       ((uint32) 0x03u << CNSL_POWER_CTRL_CHDET_PWR_CTL_POS)
    #define CNSL_POWER_CTRL_ENABLE_DM_PULLDOWN       ((uint32) 0x01u << CNSL_POWER_CTRL_ENABLE_DM_PULLDOWN_POS)
    #define CNSL_POWER_CTRL_ENABLE_VBUS_PULLDOWN     ((uint32) 0x01u << CNSL_POWER_CTRL_ENABLE_VBUS_PULLDOWN_POS)
    #define CNSL_POWER_CTRL_ENABLE_RCVR              ((uint32) 0x01u << CNSL_POWER_CTRL_ENABLE_RCVR_POS)
    #define CNSL_POWER_CTRL_ENABLE_DPO               ((uint32) 0x01u << CNSL_POWER_CTRL_ENABLE_DPO_POS)
    #define CNSL_POWER_CTRL_ENABLE_DMO               ((uint32) 0x01u << CNSL_POWER_CTRL_ENABLE_DMO_POS)
    #define CNSL_POWER_CTRL_ENABLE_CHGDET            ((uint32) 0x01u << CNSL_POWER_CTRL_ENABLE_CHGDET_POS)
    #define CNSL_POWER_CTRL_ENABLE                   ((uint32) 0x01u << CNSL_POWER_CTRL_ENABLE_POS)

    /* CNSL_CHGDET_CTRL_REG */
    #define CNSL_CHGDET_CTRL_COMP_DP_POS        (0u)  /* [0] */
    #define CNSL_CHGDET_CTRL_COMP_DM_POS        (1u)  /* [1] */
    #define CNSL_CHGDET_CTRL_COMP_EN_POS        (2u)  /* [2] */
    #define CNSL_CHGDET_CTRL_REF_DP_POS         (3u)  /* [3] */
    #define CNSL_CHGDET_CTRL_REF_DM_POS         (4u)  /* [4] */
    #define CNSL_CHGDET_CTRL_REF_EN_POS         (5u)  /* [5] */
    #define CNSL_CHGDET_CTRL_DCD_SRC_EN_POS     (6u)  /* [6] */
    #define CNSL_CHGDET_CTRL_ADFT_CTRL_POS      (12u) /* [12] */
    #define CNSL_CHGDET_CTRL_COMP_OUT_POS       (31u) /* [31] */
    #define CNSL_CHGDET_CTRL_COMP_DP            ((uint32) 0x01u << CNSL_CHGDET_CTRL_COMP_DP_POS)
    #define CNSL_CHGDET_CTRL_COMP_DM            ((uint32) 0x01u << CNSL_CHGDET_CTRL_COMP_DM_POS)
    #define CNSL_CHGDET_CTRL_COMP_EN            ((uint32) 0x01u << CNSL_CHGDET_CTRL_COMP_EN_POS)
    #define CNSL_CHGDET_CTRL_REF_DP             ((uint32) 0x01u << CNSL_CHGDET_CTRL_REF_DP_POS)
    #define CNSL_CHGDET_CTRL_REF_DM             ((uint32) 0x01u << CNSL_CHGDET_CTRL_REF_DM_POS)
    #define CNSL_CHGDET_CTRL_REF_EN             ((uint32) 0x01u << CNSL_CHGDET_CTRL_REF_EN_POS)
    #define CNSL_CHGDET_CTRL_DCD_SRC_EN         ((uint32) 0x01u << CNSL_CHGDET_CTRL_DCD_SRC_EN_POS)
    #define CNSL_CHGDET_CTRL_ADFT_CTRL_MASK     ((uint32) 0x03u << CNSL_CHGDET_CTRL_ADFT_CTRL_POS)
    #define CNSL_CHGDET_CTRL_ADFT_CTRL_NORMAL   ((uint32) 0x00u << CNSL_CHGDET_CTRL_ADFT_CTRL_POS)
    #define CNSL_CHGDET_CTRL_ADFT_CTRL_VBG      ((uint32) 0x01u << CNSL_CHGDET_CTRL_ADFT_CTRL_POS)
    #define CNSL_CHGDET_CTRL_ADFT_CTRL_DONTUSE  ((uint32) 0x02u << CNSL_CHGDET_CTRL_ADFT_CTRL_POS)
    #define CNSL_CHGDET_CTRL_ADFT_CTRL_ADFTIN   ((uint32) 0x03u << CNSL_CHGDET_CTRL_ADFT_CTRL_POS)
    #define CNSL_CHGDET_CTRL_COMP_OUT           ((uint32) 0x01u << CNSL_CHGDET_CTRL_COMP_OUT_POS)

    /* CNSL_LPM_CTRL */
    #define CNSL_LPM_CTRL_LPM_EN_POS        (0u)
    #define CNSL_LPM_CTRL_LPM_ACK_RESP_POS  (1u)
    #define CNSL_LPM_CTRL_NYET_EN_POS       (2u)
    #define CNSL_LPM_CTRL_SUB_RESP_POS      (4u)
    #define CNSL_LPM_CTRL_LPM_EN            ((uint32) 0x01u << CNSL_LPM_CTRL_LPM_EN_POS)
    #define CNSL_LPM_CTRL_LPM_ACK_RESP      ((uint32) 0x01u << CNSL_LPM_CTRL_LPM_ACK_RESP_POS)
    #define CNSL_LPM_CTRL_NYET_EN           ((uint32) 0x01u << CNSL_LPM_CTRL_NYET_EN_POS)
    #define CNSL_LPM_CTRL_ACK_NYET_MASK     ((uint32) 0x03u << CNSL_LPM_CTRL_LPM_ACK_RESP_POS)
    #define CNSL_LPM_CTRL_SUB_RESP          ((uint32) 0x01u << CNSL_LPM_CTRL_SUB_RESP_POS)

    #define CNSL_LPM_STAT_LPM_BESL_POS          (0u)
    #define CNSL_LPM_STAT_LPM_REMOTE_WAKE_POS   (4u)
    #define CNSL_LPM_STAT_LPM_BESL_MASK         ((uint32) 0x0Fu << CNSL_LPM_STAT_LPM_BESL_POS)
    #define CNSL_LPM_STAT_LPM_REMOTE_WAKE       ((uint32) 0x01u << CNSL_LPM_STAT_LPM_REMOTE_WAKE_POS)

    /* CNSL_INTR_SIE */
    #define CNSL_INTR_SIE_SOF_INTR_POS          (0u) /* [0] Interrupt for USB SOF   */
    #define CNSL_INTR_SIE_BUS_RESET_INTR_POS    (1u) /* [1] Interrupt for BUS RESET */
    #define CNSL_INTR_SIE_EP0_INTR_POS          (2u) /* [2] Interrupt for EP0       */
    #define CNSL_INTR_SIE_LPM_INTR_POS          (3u) /* [3] Interrupt for LPM       */
    #define CNSL_INTR_SIE_RESUME_INTR_POS       (4u) /* [4] Interrupt for RESUME (not used by component) */
    #define CNSL_INTR_SIE_SOF_INTR              ((uint32) 0x01u << CNSL_INTR_SIE_SOF_INTR_POS)
    #define CNSL_INTR_SIE_BUS_RESET_INTR        ((uint32) 0x01u << CNSL_INTR_SIE_BUS_RESET_INTR_POS)
    #define CNSL_INTR_SIE_EP0_INTR              ((uint32) 0x01u << CNSL_INTR_SIE_EP0_INTR_POS)
    #define CNSL_INTR_SIE_LPM_INTR              ((uint32) 0x01u << CNSL_INTR_SIE_LPM_INTR_POS)
    #define CNSL_INTR_SIE_RESUME_INTR           ((uint32) 0x01u << CNSL_INTR_SIE_RESUME_INTR_POS)

    /* CNSL_INTR_CAUSE_LO, MED and HI */
    #define CNSL_INTR_CAUSE_SOF_INTR_POS       (0u)  /* [0] Interrupt status for USB SOF    */
    #define CNSL_INTR_CAUSE_BUS_RESET_INTR_POS (1u)  /* [1] Interrupt status for USB BUS RSET */
    #define CNSL_INTR_CAUSE_EP0_INTR_POS       (2u)  /* [2] Interrupt status for USB EP0    */
    #define CNSL_INTR_CAUSE_LPM_INTR_POS       (3u)  /* [3] Interrupt status for USB LPM    */
    #define CNSL_INTR_CAUSE_RESUME_INTR_POS    (4u)  /* [4] Interrupt status for USB RESUME */
    #define CNSL_INTR_CAUSE_ARB_INTR_POS       (7u)  /* [7] Interrupt status for USB ARB    */
    #define CNSL_INTR_CAUSE_EP1_INTR_POS       (8u)  /* [8] Interrupt status for USB EP1    */
    #define CNSL_INTR_CAUSE_EP2_INTR_POS       (9u)  /* [9] Interrupt status for USB EP2    */
    #define CNSL_INTR_CAUSE_EP3_INTR_POS       (10u) /* [10] Interrupt status for USB EP3   */
    #define CNSL_INTR_CAUSE_EP4_INTR_POS       (11u) /* [11] Interrupt status for USB EP4   */
    #define CNSL_INTR_CAUSE_EP5_INTR_POS       (12u) /* [12] Interrupt status for USB EP5   */
    #define CNSL_INTR_CAUSE_EP6_INTR_POS       (13u) /* [13] Interrupt status for USB EP6   */
    #define CNSL_INTR_CAUSE_EP7_INTR_POS       (14u) /* [14] Interrupt status for USB EP7   */
    #define CNSL_INTR_CAUSE_EP8_INTR_POS       (15u) /* [15] Interrupt status for USB EP8   */
    #define CNSL_INTR_CAUSE_SOF_INTR           ((uint32) 0x01u << CNSL_INTR_CAUSE_SOF_INTR_POS)
    #define CNSL_INTR_CAUSE_BUS_RESET_INTR     ((uint32) 0x01u << CNSL_INTR_CAUSE_BUS_RESET_INTR_POS)
    #define CNSL_INTR_CAUSE_EP0_INTR           ((uint32) 0x01u << CNSL_INTR_CAUSE_EP0_INTR_POS)
    #define CNSL_INTR_CAUSE_LPM_INTR           ((uint32) 0x01u << CNSL_INTR_CAUSE_LPM_INTR_POS)
    #define CNSL_INTR_CAUSE_RESUME_INTR        ((uint32) 0x01u << CNSL_INTR_CAUSE_RESUME_INTR_POS)
    #define CNSL_INTR_CAUSE_ARB_INTR           ((uint32) 0x01u << CNSL_INTR_CAUSE_ARB_INTR_POS)
    #define CNSL_INTR_CAUSE_EP1_INTR           ((uint32) 0x01u << CNSL_INTR_CAUSE_EP1_INTR_POS)
    #define CNSL_INTR_CAUSE_EP2_INTR           ((uint32) 0x01u << CNSL_INTR_CAUSE_EP2_INTR_POS)
    #define CNSL_INTR_CAUSE_EP3_INTR           ((uint32) 0x01u << CNSL_INTR_CAUSE_EP3_INTR_POS)
    #define CNSL_INTR_CAUSE_EP4_INTR           ((uint32) 0x01u << CNSL_INTR_CAUSE_EP4_INTR_POS)
    #define CNSL_INTR_CAUSE_EP5_INTR           ((uint32) 0x01u << CNSL_INTR_CAUSE_EP5_INTR_POS)
    #define CNSL_INTR_CAUSE_EP6_INTR           ((uint32) 0x01u << CNSL_INTR_CAUSE_EP6_INTR_POS)
    #define CNSL_INTR_CAUSE_EP7_INTR           ((uint32) 0x01u << CNSL_INTR_CAUSE_EP7_INTR_POS)
    #define CNSL_INTR_CAUSE_EP8_INTR           ((uint32) 0x01u << CNSL_INTR_CAUSE_EP8_INTR_POS)

    #define CNSL_INTR_CAUSE_CTRL_INTR_MASK     (CNSL_INTR_CAUSE_SOF_INTR       | \
                                                            CNSL_INTR_CAUSE_BUS_RESET_INTR | \
                                                            CNSL_INTR_CAUSE_EP0_INTR       | \
                                                            CNSL_INTR_CAUSE_LPM_INTR)

    #define CNSL_INTR_CAUSE_EP1_8_INTR_MASK    (CNSL_INTR_CAUSE_EP1_INTR       | \
                                                            CNSL_INTR_CAUSE_EP2_INTR       | \
                                                            CNSL_INTR_CAUSE_EP3_INTR       | \
                                                            CNSL_INTR_CAUSE_EP4_INTR       | \
                                                            CNSL_INTR_CAUSE_EP5_INTR       | \
                                                            CNSL_INTR_CAUSE_EP6_INTR       | \
                                                            CNSL_INTR_CAUSE_EP7_INTR       | \
                                                            CNSL_INTR_CAUSE_EP8_INTR)

    #define CNSL_INTR_CAUSE_EP_INTR_SHIFT      (CNSL_INTR_CAUSE_ARB_INTR_POS - \
                                                           (CNSL_INTR_CAUSE_LPM_INTR_POS + 1u))
    #define CNSL_INTR_CAUSE_SRC_COUNT          (13u)

    #define CNSL_CHGDET_CTRL_PRIMARY    (CNSL_CHGDET_CTRL_COMP_EN | \
                                                     CNSL_CHGDET_CTRL_COMP_DM | \
                                                     CNSL_CHGDET_CTRL_REF_EN  | \
                                                     CNSL_CHGDET_CTRL_REF_DP)

    #define CNSL_CHGDET_CTRL_SECONDARY  (CNSL_CHGDET_CTRL_COMP_EN | \
                                                     CNSL_CHGDET_CTRL_COMP_DP | \
                                                     CNSL_CHGDET_CTRL_REF_EN  | \
                                                     CNSL_CHGDET_CTRL_REF_DM)

    #define CNSL_CHGDET_CTRL_DEFAULT    (0x00000900u)


#else /* (CY_PSOC3 || CY_PSOC5LP) */
    #define CNSL_PM_ACT_EN_FSUSB            CNSL_USB__PM_ACT_MSK
    #define CNSL_PM_STBY_EN_FSUSB           CNSL_USB__PM_STBY_MSK
    #define CNSL_PM_AVAIL_EN_FSUSBIO        (0x10u)

    #define CNSL_PM_USB_CR0_REF_EN          (0x01u)
    #define CNSL_PM_USB_CR0_PD_N            (0x02u)
    #define CNSL_PM_USB_CR0_PD_PULLUP_N     (0x04u)
#endif /* (CY_PSOC4) */


/***************************************
*       Macros Definitions
***************************************/

#if (CY_PSOC4)
    #define CNSL_ClearSieInterruptSource(intMask) \
                do{ \
                    CNSL_INTR_SIE_REG = (uint32) (intMask); \
                }while(0)
#else
    #define CNSL_ClearSieInterruptSource(intMask) \
                do{ /* Does nothing. */ }while(0)
#endif /* (CY_PSOC4) */

#define CNSL_ClearSieEpInterruptSource(intMask) \
            do{ \
                CNSL_SIE_EP_INT_SR_REG = (uint8) (intMask); \
            }while(0)

#define CNSL_GET_ACTIVE_IN_EP_CR0_MODE(epType)  (((epType) == CNSL_EP_TYPE_ISOC) ? \
                                                                (CNSL_MODE_ISO_IN) : (CNSL_MODE_ACK_IN))

#define CNSL_GET_ACTIVE_OUT_EP_CR0_MODE(epType) (((epType) == CNSL_EP_TYPE_ISOC) ? \
                                                                (CNSL_MODE_ISO_OUT) : (CNSL_MODE_ACK_OUT))

#define CNSL_GET_EP_TYPE(epNumber)  (CNSL_EP[epNumber].attrib & CNSL_EP_TYPE_MASK)

#define CNSL_GET_UINT16(hi, low)    (((uint16) ((uint16) (hi) << 8u)) | ((uint16) (low) & 0xFFu))


/***************************************
*    Initialization Register Settings
***************************************/

/* Clear device address and enable USB IP respond to USB traffic. */
#define CNSL_DEFUALT_CR0    (CNSL_CR0_ENABLE)

/* Arbiter configuration depends on memory management mode. */
#define CNSL_DEFAULT_ARB_CFG    ((CNSL_EP_MANAGEMENT_MANUAL) ? (CNSL_ARB_CFG_DMA_CFG_NONE) : \
                                                ((CNSL_EP_MANAGEMENT_DMA_MANUAL) ? \
                                                    (CNSL_ARB_CFG_DMA_CFG_MANUAL) : \
                                                        (CNSL_ARB_CFG_AUTO_MEM | CNSL_ARB_CFG_DMA_CFG_AUTO)))

/* Enable arbiter interrupt for active endpoints only */
#define CNSL_DEFAULT_ARB_INT_EN \
        ((uint8) ((uint8) CNSL_DMA1_ACTIVE << CNSL_ARB_INT_EP1_INTR_POS) | \
         (uint8) ((uint8) CNSL_DMA2_ACTIVE << CNSL_ARB_INT_EP2_INTR_POS) | \
         (uint8) ((uint8) CNSL_DMA3_ACTIVE << CNSL_ARB_INT_EP3_INTR_POS) | \
         (uint8) ((uint8) CNSL_DMA4_ACTIVE << CNSL_ARB_INT_EP4_INTR_POS) | \
         (uint8) ((uint8) CNSL_DMA5_ACTIVE << CNSL_ARB_INT_EP5_INTR_POS) | \
         (uint8) ((uint8) CNSL_DMA6_ACTIVE << CNSL_ARB_INT_EP6_INTR_POS) | \
         (uint8) ((uint8) CNSL_DMA7_ACTIVE << CNSL_ARB_INT_EP7_INTR_POS) | \
         (uint8) ((uint8) CNSL_DMA8_ACTIVE << CNSL_ARB_INT_EP8_INTR_POS))

/* Enable all SIE endpoints interrupts */
#define CNSL_DEFAULT_SIE_EP_INT_EN  (CNSL_SIE_INT_EP1_INTR | \
                                                 CNSL_SIE_INT_EP2_INTR | \
                                                 CNSL_SIE_INT_EP3_INTR | \
                                                 CNSL_SIE_INT_EP4_INTR | \
                                                 CNSL_SIE_INT_EP5_INTR | \
                                                 CNSL_SIE_INT_EP6_INTR | \
                                                 CNSL_SIE_INT_EP7_INTR | \
                                                 CNSL_SIE_INT_EP8_INTR)

#define CNSL_ARB_EPX_CFG_DEFAULT    (CNSL_ARB_EPX_CFG_RESET | \
                                                 CNSL_ARB_EPX_CFG_CRC_BYPASS)

/* Default EP arbiter interrupt source register */
#define CNSL_ARB_EPX_INT_COMMON_MASK   (CNSL_ARB_EPX_INT_IN_BUF_FULL | \
                                                    CNSL_ARB_EPX_INT_BUF_OVER    | \
                                                    CNSL_ARB_EPX_INT_BUF_UNDER   | \
                                                    CNSL_ARB_EPX_INT_ERR_INT     | \
                                                    (CNSL_EP_MANAGEMENT_DMA_MANUAL ? CNSL_ARB_EPX_INT_DMA_GNT : 0u))

#define CNSL_CLEAR_REG      (0u)

#if (CY_PSOC4)
    /* Set USB lock option when IMO is locked to USB traffic. */
    #define CNSL_DEFUALT_CR1    ((0u != CySysClkImoGetUsbLock()) ? (CNSL_CR1_ENABLE_LOCK) : (0u))

    /* Recommended value is increased from 3 to 10 due to suppress glitch on  
     * RSE0 with USB2.0 hubs (LF CLK = 32kHz equal to 350us). */
    #define CNSL_DEFUALT_BUS_RST_CNT  (10u)

    /* Select VBUS sources as: valid, PHY of GPIO, and clears isolate bit. */
    /* Application level must ensure that VBUS is valid valid to use. */
    #define CNSL_DEFAULT_POWER_CTRL_VBUS    (CNSL_POWER_CTRL_ENABLE_VBUS_PULLDOWN | \
                                                         ((!CNSL_VBUS_MONITORING_ENABLE) ? \
                                                            (CNSL_POWER_CTRL_VBUS_VALID_OVR_1) : \
                                                                (CNSL_VBUS_POWER_PAD_ENABLE ? \
                                                                    (CNSL_POWER_CTRL_VBUS_VALID_OVR_PHY) : \
                                                                    (CNSL_POWER_CTRL_VBUS_VALID_OVR_GPIO))))
    /* Enable USB IP. */
    #define CNSL_DEFAULT_POWER_CTRL_PHY (CNSL_POWER_CTRL_SUSPEND     | \
                                                     CNSL_POWER_CTRL_SUSPEND_DEL | \
                                                     CNSL_POWER_CTRL_ENABLE_RCVR | \
                                                     CNSL_POWER_CTRL_ENABLE_DPO  | \
                                                     CNSL_POWER_CTRL_ENABLE_DMO  | \
                                                     CNSL_POWER_CTRL_ENABLE)

    /* Assign interrupt between levels lo, med, hi. */
    #define CNSL_DEFAULT_INTR_LVL_SEL   ((uint32) (CNSL_INTR_LVL_SEL))

    /* Enable interrupt source in the INTR_SIE. The SOF is always disabled and EP0 is enabled. */
    #define CNSL_DEFAULT_INTR_SIE_MASK \
                ((uint32) ((uint32) CNSL_BUS_RESET_ISR_ACTIVE << CNSL_INTR_SIE_BUS_RESET_INTR_POS) | \
                 (uint32) ((uint32) CNSL_SOF_ISR_ACTIVE       << CNSL_INTR_SIE_SOF_INTR_POS)       | \
                 (uint32) ((uint32) CNSL_LPM_ACTIVE           << CNSL_INTR_SIE_LPM_INTR_POS)       | \
                 (uint32) ((uint32) CNSL_INTR_SIE_EP0_INTR))

    /* Arbiter interrupt sources */
    #define CNSL_ARB_EPX_INT_MASK   (CNSL_ARB_EPX_INT_COMMON_MASK | \
                                                (CNSL_EP_MANAGEMENT_DMA_AUTO ? CNSL_ARB_EPX_INT_DMA_TERMIN : 0u))

    /* Common DMA configuration */
    #define CNSL_DMA_COMMON_CFG     (CYDMA_PULSE | CYDMA_ENTIRE_DESCRIPTOR | \
                                                 CYDMA_NON_PREEMPTABLE)


#else
    #define CNSL_ARB_EPX_INT_MASK   (CNSL_ARB_EPX_INT_COMMON_MASK)

    #define CNSL_DEFUALT_CR1        (CNSL_CR1_ENABLE_LOCK)

    /* Recommended value is 3 for LF CLK = 100kHz equal to 100us. */
    #define CNSL_DEFUALT_BUS_RST_CNT    (10u)
#endif /* (CY_PSOC4) */

/*
* \addtogroup group_deprecated
* @{
*/

/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

/* Renamed type definitions */
#define CNSL_CODE CYCODE
#define CNSL_FAR CYFAR
#if defined(__C51__) || defined(__CX51__)
    #define CNSL_DATA data
    #define CNSL_XDATA xdata
#else
    #define CNSL_DATA
    #define CNSL_XDATA
#endif /*  __C51__ */
#define CNSL_NULL       NULL
/** @} deprecated */
/* Renamed structure fields */
#define wBuffOffset         buffOffset
#define wBufferSize         bufferSize
#define bStatus             status
#define wLength             length
#define wCount              count

/* Renamed global variable */
#define CurrentTD           CNSL_currentTD
#define CNSL_interfaceSetting_last       CNSL_interfaceSettingLast

/* Renamed global constants */
#define CNSL_DWR_VDDD_OPERATION         (CNSL_DWR_POWER_OPERATION)

/* Renamed functions */
#define CNSL_bCheckActivity             CNSL_CheckActivity
#define CNSL_bGetConfiguration          CNSL_GetConfiguration
#define CNSL_bGetInterfaceSetting       CNSL_GetInterfaceSetting
#define CNSL_bGetEPState                CNSL_GetEPState
#define CNSL_wGetEPCount                CNSL_GetEPCount
#define CNSL_bGetEPAckState             CNSL_GetEPAckState
#define CNSL_bRWUEnabled                CNSL_RWUEnabled
#define CNSL_bVBusPresent               CNSL_VBusPresent

#define CNSL_bConfiguration             CNSL_configuration
#define CNSL_bInterfaceSetting          CNSL_interfaceSetting
#define CNSL_bDeviceAddress             CNSL_deviceAddress
#define CNSL_bDeviceStatus              CNSL_deviceStatus
#define CNSL_bDevice                    CNSL_device
#define CNSL_bTransferState             CNSL_transferState
#define CNSL_bLastPacketSize            CNSL_lastPacketSize

#define CNSL_LoadEP                     CNSL_LoadInEP
#define CNSL_LoadInISOCEP               CNSL_LoadInEP
#define CNSL_EnableOutISOCEP            CNSL_EnableOutEP

#define CNSL_SetVector                  CyIntSetVector
#define CNSL_SetPriority                CyIntSetPriority
#define CNSL_EnableInt                  CyIntEnable

/* Replace with register access. */
#define CNSL_bmRequestType      CNSL_EP0_DR0_PTR
#define CNSL_bRequest           CNSL_EP0_DR1_PTR
#define CNSL_wValue             CNSL_EP0_DR2_PTR
#define CNSL_wValueHi           CNSL_EP0_DR3_PTR
#define CNSL_wValueLo           CNSL_EP0_DR2_PTR
#define CNSL_wIndex             CNSL_EP0_DR4_PTR
#define CNSL_wIndexHi           CNSL_EP0_DR5_PTR
#define CNSL_wIndexLo           CNSL_EP0_DR4_PTR
#define CNSL_length             CNSL_EP0_DR6_PTR
#define CNSL_lengthHi           CNSL_EP0_DR7_PTR
#define CNSL_lengthLo           CNSL_EP0_DR6_PTR

/* Rename VBUS monitoring registers. */
#if (CY_PSOC3 || CY_PSOC5LP)
    #if (CNSL_VBUS_MONITORING_ENABLE)
        #if (CNSL_VBUS_MONITORING_INTERNAL)
            #define CNSL_VBUS_DR_PTR    ( (reg8 *) CNSL_VBUS__DR)
            #define CNSL_VBUS_DR_REG    (*(reg8 *) CNSL_VBUS__DR)
            #define CNSL_VBUS_PS_PTR    ( (reg8 *) CNSL_VBUS__PS)
            #define CNSL_VBUS_PS_REG    (*(reg8 *) CNSL_VBUS__PS)
            #define CNSL_VBUS_MASK          CNSL_VBUS__MASK
        #else
            #define CNSL_VBUS_PS_PTR    ( (reg8 *) CNSL_Vbus_ps_sts_sts_reg__STATUS_REG)
            #define CNSL_VBUS_MASK      (0x01u)
        #endif /* (CNSL_VBUS_MONITORING_INTERNAL) */
    #endif /*(CNSL_VBUS_MONITORING_ENABLE) */
        
    /* Pointer DIE structure in flash (8 bytes): Y and X location, wafer, lot msb, lot lsb, 
    *  work week, fab/year, minor. */
    #define CNSL_DIE_ID             CYDEV_FLSHID_CUST_TABLES_BASE

     #if (CNSL_EP_MANAGEMENT_DMA_AUTO)
        #if (CNSL_DMA1_ACTIVE)
            #define CNSL_ep1_TD_TERMOUT_EN  (CNSL_ep1__TD_TERMOUT_EN)
        #else
            #define CNSL_ep1_TD_TERMOUT_EN  (0u)
        #endif /* (CNSL_DMA1_ACTIVE) */

        #if (CNSL_DMA2_ACTIVE)
            #define CNSL_ep2_TD_TERMOUT_EN  (CNSL_ep2__TD_TERMOUT_EN)
        #else
            #define CNSL_ep2_TD_TERMOUT_EN  (0u)
        #endif /* (CNSL_DMA2_ACTIVE) */

        #if (CNSL_DMA3_ACTIVE)
            #define CNSL_ep3_TD_TERMOUT_EN  (CNSL_ep3__TD_TERMOUT_EN)
        #else
            #define CNSL_ep3_TD_TERMOUT_EN  (0u)
        #endif /* (CNSL_DMA3_ACTIVE) */

        #if (CNSL_DMA4_ACTIVE)
            #define CNSL_ep4_TD_TERMOUT_EN  (CNSL_ep4__TD_TERMOUT_EN)
        #else
            #define CNSL_ep4_TD_TERMOUT_EN  (0u)
        #endif /* (CNSL_DMA4_ACTIVE) */

        #if (CNSL_DMA5_ACTIVE)
            #define CNSL_ep5_TD_TERMOUT_EN  (CNSL_ep5__TD_TERMOUT_EN)
        #else
            #define CNSL_ep5_TD_TERMOUT_EN  (0u)
        #endif /* (CNSL_DMA5_ACTIVE) */

        #if (CNSL_DMA6_ACTIVE)
            #define CNSL_ep6_TD_TERMOUT_EN  (CNSL_ep6__TD_TERMOUT_EN)
        #else
            #define CNSL_ep6_TD_TERMOUT_EN  (0u)
        #endif /* (CNSL_DMA6_ACTIVE) */

        #if (CNSL_DMA7_ACTIVE)
            #define CNSL_ep7_TD_TERMOUT_EN  (CNSL_ep7__TD_TERMOUT_EN)
        #else
            #define CNSL_ep7_TD_TERMOUT_EN  (0u)
        #endif /* (CNSL_DMA7_ACTIVE) */

        #if (CNSL_DMA8_ACTIVE)
            #define CNSL_ep8_TD_TERMOUT_EN  (CNSL_ep8__TD_TERMOUT_EN)
        #else
            #define CNSL_ep8_TD_TERMOUT_EN  (0u)
        #endif /* (CNSL_DMA8_ACTIVE) */
    #endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO) */   
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

/* Rename USB IP registers. */
#define CNSL_ARB_CFG        CNSL_ARB_CFG_PTR

#define CNSL_ARB_EP1_CFG    CNSL_ARB_EP1_CFG_PTR
#define CNSL_ARB_EP1_INT_EN CNSL_ARB_EP1_INT_EN_PTR
#define CNSL_ARB_EP1_SR     CNSL_ARB_EP1_SR_PTR

#define CNSL_ARB_EP2_CFG    CNSL_ARB_EP2_CFG_PTR
#define CNSL_ARB_EP2_INT_EN CNSL_ARB_EP2_INT_EN_PTR
#define CNSL_ARB_EP2_SR     CNSL_ARB_EP2_SR_PTR

#define CNSL_ARB_EP3_CFG    CNSL_ARB_EP3_CFG_PTR
#define CNSL_ARB_EP3_INT_EN CNSL_ARB_EP3_INT_EN_PTR
#define CNSL_ARB_EP3_SR     CNSL_ARB_EP3_SR_PTR

#define CNSL_ARB_EP4_CFG    CNSL_ARB_EP4_CFG_PTR
#define CNSL_ARB_EP4_INT_EN CNSL_ARB_EP4_INT_EN_PTR
#define CNSL_ARB_EP4_SR     CNSL_ARB_EP4_SR_PTR

#define CNSL_ARB_EP5_CFG    CNSL_ARB_EP5_CFG_PTR
#define CNSL_ARB_EP5_INT_EN CNSL_ARB_EP5_INT_EN_PTR
#define CNSL_ARB_EP5_SR     CNSL_ARB_EP5_SR_PTR

#define CNSL_ARB_EP6_CFG    CNSL_ARB_EP6_CFG_PTR
#define CNSL_ARB_EP6_INT_EN CNSL_ARB_EP6_INT_EN_PTR
#define CNSL_ARB_EP6_SR     CNSL_ARB_EP6_SR_PTR

#define CNSL_ARB_EP7_CFG    CNSL_ARB_EP7_CFG_PTR
#define CNSL_ARB_EP7_INT_EN CNSL_ARB_EP7_INT_EN_PTR
#define CNSL_ARB_EP7_SR     CNSL_ARB_EP7_SR_PTR

#define CNSL_ARB_EP8_CFG    CNSL_ARB_EP8_CFG_PTR
#define CNSL_ARB_EP8_INT_EN CNSL_ARB_EP8_INT_EN_PTR
#define CNSL_ARB_EP8_SR     CNSL_ARB_EP8_SR_PTR

#define CNSL_ARB_INT_EN     CNSL_ARB_INT_EN_PTR
#define CNSL_ARB_INT_SR     CNSL_ARB_INT_SR_PTR

#define CNSL_ARB_RW1_DR     CNSL_ARB_RW1_DR_PTR
#define CNSL_ARB_RW1_RA     CNSL_ARB_RW1_RA_PTR
#define CNSL_ARB_RW1_RA_MSB CNSL_ARB_RW1_RA_MSB_PTR
#define CNSL_ARB_RW1_WA     CNSL_ARB_RW1_WA_PTR
#define CNSL_ARB_RW1_WA_MSB CNSL_ARB_RW1_WA_MSB_PTR

#define CNSL_ARB_RW2_DR     CNSL_ARB_RW2_DR_PTR
#define CNSL_ARB_RW2_RA     CNSL_ARB_RW2_RA_PTR
#define CNSL_ARB_RW2_RA_MSB CNSL_ARB_RW2_RA_MSB_PTR
#define CNSL_ARB_RW2_WA     CNSL_ARB_RW2_WA_PTR
#define CNSL_ARB_RW2_WA_MSB CNSL_ARB_RW2_WA_MSB_PTR

#define CNSL_ARB_RW3_DR     CNSL_ARB_RW3_DR_PTR
#define CNSL_ARB_RW3_RA     CNSL_ARB_RW3_RA_PTR
#define CNSL_ARB_RW3_RA_MSB CNSL_ARB_RW3_RA_MSB_PTR
#define CNSL_ARB_RW3_WA     CNSL_ARB_RW3_WA_PTR
#define CNSL_ARB_RW3_WA_MSB CNSL_ARB_RW3_WA_MSB_PTR

#define CNSL_ARB_RW4_DR     CNSL_ARB_RW4_DR_PTR
#define CNSL_ARB_RW4_RA     CNSL_ARB_RW4_RA_PTR
#define CNSL_ARB_RW4_RA_MSB CNSL_ARB_RW4_RA_MSB_PTR
#define CNSL_ARB_RW4_WA     CNSL_ARB_RW4_WA_PTR
#define CNSL_ARB_RW4_WA_MSB CNSL_ARB_RW4_WA_MSB_PTR

#define CNSL_ARB_RW5_DR     CNSL_ARB_RW5_DR_PTR
#define CNSL_ARB_RW5_RA     CNSL_ARB_RW5_RA_PTR
#define CNSL_ARB_RW5_RA_MSB CNSL_ARB_RW5_RA_MSB_PTR
#define CNSL_ARB_RW5_WA     CNSL_ARB_RW5_WA_PTR
#define CNSL_ARB_RW5_WA_MSB CNSL_ARB_RW5_WA_MSB_PTR

#define CNSL_ARB_RW6_DR     CNSL_ARB_RW6_DR_PTR
#define CNSL_ARB_RW6_RA     CNSL_ARB_RW6_RA_PTR
#define CNSL_ARB_RW6_RA_MSB CNSL_ARB_RW6_RA_MSB_PTR
#define CNSL_ARB_RW6_WA     CNSL_ARB_RW6_WA_PTR
#define CNSL_ARB_RW6_WA_MSB CNSL_ARB_RW6_WA_MSB_PTR

#define CNSL_ARB_RW7_DR     CNSL_ARB_RW7_DR_PTR
#define CNSL_ARB_RW7_RA     CNSL_ARB_RW7_RA_PTR
#define CNSL_ARB_RW7_RA_MSB CNSL_ARB_RW7_RA_MSB_PTR
#define CNSL_ARB_RW7_WA     CNSL_ARB_RW7_WA_PTR
#define CNSL_ARB_RW7_WA_MSB CNSL_ARB_RW7_WA_MSB_PTR

#define CNSL_ARB_RW8_DR     CNSL_ARB_RW8_DR_PTR
#define CNSL_ARB_RW8_RA     CNSL_ARB_RW8_RA_PTR
#define CNSL_ARB_RW8_RA_MSB CNSL_ARB_RW8_RA_MSB_PTR
#define CNSL_ARB_RW8_WA     CNSL_ARB_RW8_WA_PTR
#define CNSL_ARB_RW8_WA_MSB CNSL_ARB_RW8_WA_MSB_PTR

#define CNSL_BUF_SIZE       CNSL_BUF_SIZE_PTR
#define CNSL_BUS_RST_CNT    CNSL_BUS_RST_CNT_PTR
#define CNSL_CR0            CNSL_CR0_PTR
#define CNSL_CR1            CNSL_CR1_PTR
#define CNSL_CWA            CNSL_CWA_PTR
#define CNSL_CWA_MSB        CNSL_CWA_MSB_PTR

#define CNSL_DMA_THRES      CNSL_DMA_THRES_PTR
#define CNSL_DMA_THRES_MSB  CNSL_DMA_THRES_MSB_PTR

#define CNSL_EP_ACTIVE      CNSL_EP_ACTIVE_PTR
#define CNSL_EP_TYPE        CNSL_EP_TYPE_PTR

#define CNSL_EP0_CNT        CNSL_EP0_CNT_PTR
#define CNSL_EP0_CR         CNSL_EP0_CR_PTR
#define CNSL_EP0_DR0        CNSL_EP0_DR0_PTR
#define CNSL_EP0_DR1        CNSL_EP0_DR1_PTR
#define CNSL_EP0_DR2        CNSL_EP0_DR2_PTR
#define CNSL_EP0_DR3        CNSL_EP0_DR3_PTR
#define CNSL_EP0_DR4        CNSL_EP0_DR4_PTR
#define CNSL_EP0_DR5        CNSL_EP0_DR5_PTR
#define CNSL_EP0_DR6        CNSL_EP0_DR6_PTR
#define CNSL_EP0_DR7        CNSL_EP0_DR7_PTR

#define CNSL_OSCLK_DR0      CNSL_OSCLK_DR0_PTR
#define CNSL_OSCLK_DR1      CNSL_OSCLK_DR1_PTR

#define CNSL_PM_ACT_CFG     CNSL_PM_ACT_CFG_PTR
#define CNSL_PM_STBY_CFG    CNSL_PM_STBY_CFG_PTR

#define CNSL_SIE_EP_INT_EN  CNSL_SIE_EP_INT_EN_PTR
#define CNSL_SIE_EP_INT_SR  CNSL_SIE_EP_INT_SR_PTR

#define CNSL_SIE_EP1_CNT0   CNSL_SIE_EP1_CNT0_PTR
#define CNSL_SIE_EP1_CNT1   CNSL_SIE_EP1_CNT1_PTR
#define CNSL_SIE_EP1_CR0    CNSL_SIE_EP1_CR0_PTR

#define CNSL_SIE_EP2_CNT0   CNSL_SIE_EP2_CNT0_PTR
#define CNSL_SIE_EP2_CNT1   CNSL_SIE_EP2_CNT1_PTR
#define CNSL_SIE_EP2_CR0    CNSL_SIE_EP2_CR0_PTR

#define CNSL_SIE_EP3_CNT0   CNSL_SIE_EP3_CNT0_PTR
#define CNSL_SIE_EP3_CNT1   CNSL_SIE_EP3_CNT1_PTR
#define CNSL_SIE_EP3_CR0    CNSL_SIE_EP3_CR0_PTR

#define CNSL_SIE_EP4_CNT0   CNSL_SIE_EP4_CNT0_PTR
#define CNSL_SIE_EP4_CNT1   CNSL_SIE_EP4_CNT1_PTR
#define CNSL_SIE_EP4_CR0    CNSL_SIE_EP4_CR0_PTR

#define CNSL_SIE_EP5_CNT0   CNSL_SIE_EP5_CNT0_PTR
#define CNSL_SIE_EP5_CNT1   CNSL_SIE_EP5_CNT1_PTR
#define CNSL_SIE_EP5_CR0    CNSL_SIE_EP5_CR0_PTR

#define CNSL_SIE_EP6_CNT0   CNSL_SIE_EP6_CNT0_PTR
#define CNSL_SIE_EP6_CNT1   CNSL_SIE_EP6_CNT1_PTR
#define CNSL_SIE_EP6_CR0    CNSL_SIE_EP6_CR0_PTR

#define CNSL_SIE_EP7_CNT0   CNSL_SIE_EP7_CNT0_PTR
#define CNSL_SIE_EP7_CNT1   CNSL_SIE_EP7_CNT1_PTR
#define CNSL_SIE_EP7_CR0    CNSL_SIE_EP7_CR0_PTR

#define CNSL_SIE_EP8_CNT0   CNSL_SIE_EP8_CNT0_PTR
#define CNSL_SIE_EP8_CNT1   CNSL_SIE_EP8_CNT1_PTR
#define CNSL_SIE_EP8_CR0    CNSL_SIE_EP8_CR0_PTR

#define CNSL_SOF0           CNSL_SOF0_PTR
#define CNSL_SOF1           CNSL_SOF1_PTR

#define CNSL_USB_CLK_EN     CNSL_USB_CLK_EN_PTR

#define CNSL_USBIO_CR0      CNSL_USBIO_CR0_PTR
#define CNSL_USBIO_CR1      CNSL_USBIO_CR1_PTR
#define CNSL_USBIO_CR2      CNSL_USBIO_CR2_PTR

#define CNSL_DM_INP_DIS_PTR     ( (reg8 *) CNSL_Dm__INP_DIS)
#define CNSL_DM_INP_DIS_REG     (*(reg8 *) CNSL_Dm__INP_DIS)
#define CNSL_DP_INP_DIS_PTR     ( (reg8 *) CNSL_Dp__INP_DIS)
#define CNSL_DP_INP_DIS_REG     (*(reg8 *) CNSL_Dp__INP_DIS)
#define CNSL_DP_INTSTAT_PTR     ( (reg8 *) CNSL_Dp__INTSTAT)
#define CNSL_DP_INTSTAT_REG     (*(reg8 *) CNSL_Dp__INTSTAT)
#define CNSL_DM_MASK            CNSL_Dm__0__MASK
#define CNSL_DP_MASK            CNSL_Dp__0__MASK

#define USBFS_SIE_EP_INT_EP1_MASK        (0x01u)
#define USBFS_SIE_EP_INT_EP2_MASK        (0x02u)
#define USBFS_SIE_EP_INT_EP3_MASK        (0x04u)
#define USBFS_SIE_EP_INT_EP4_MASK        (0x08u)
#define USBFS_SIE_EP_INT_EP5_MASK        (0x10u)
#define USBFS_SIE_EP_INT_EP6_MASK        (0x20u)
#define USBFS_SIE_EP_INT_EP7_MASK        (0x40u)
#define USBFS_SIE_EP_INT_EP8_MASK        (0x80u)

#define CNSL_ARB_EPX_SR_IN_BUF_FULL     (0x01u)
#define CNSL_ARB_EPX_SR_DMA_GNT         (0x02u)
#define CNSL_ARB_EPX_SR_BUF_OVER        (0x04u)
#define CNSL_ARB_EPX_SR_BUF_UNDER       (0x08u)

#define CNSL_ARB_EPX_INT_EN_ALL CNSL_ARB_EPX_INT_ALL

#define CNSL_CR1_BUS_ACTIVITY_SHIFT     (0x02u)

#define CNSL_BUS_RST_COUNT      CNSL_DEFUALT_BUS_RST_CNT

#define CNSL_ARB_INT_MASK       CNSL_DEFAULT_ARB_INT_EN

#if (CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
    /* CY_PSOC3 interrupt registers */
    #define CNSL_USB_ISR_PRIOR  ((reg8 *) CYDEV_INTC_PRIOR0)
    #define CNSL_USB_ISR_SET_EN ((reg8 *) CYDEV_INTC_SET_EN0)
    #define CNSL_USB_ISR_CLR_EN ((reg8 *) CYDEV_INTC_CLR_EN0)
    #define CNSL_USB_ISR_VECT   ((cyisraddress *) CYDEV_INTC_VECT_MBASE)
#elif (CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_PANTHER)
    /* CY_PSOC5LP interrupt registers */
    #define CNSL_USB_ISR_PRIOR  ((reg8 *) CYDEV_NVIC_PRI_0)
    #define CNSL_USB_ISR_SET_EN ((reg8 *) CYDEV_NVIC_SETENA0)
    #define CNSL_USB_ISR_CLR_EN ((reg8 *) CYDEV_NVIC_CLRENA0)
    #define CNSL_USB_ISR_VECT   ((cyisraddress *) CYDEV_NVIC_VECT_OFFSET)
#endif /*  CYDEV_CHIP_DIE_EXPECT */


#endif /* (CY_USBFS_CNSL_H) */


/* [] END OF FILE */
