/*******************************************************************************
* File Name: CNSL_Dp.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_CNSL_Dp_H) /* Pins CNSL_Dp_H */
#define CY_PINS_CNSL_Dp_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "CNSL_Dp_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 CNSL_Dp__PORT == 15 && ((CNSL_Dp__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    CNSL_Dp_Write(uint8 value);
void    CNSL_Dp_SetDriveMode(uint8 mode);
uint8   CNSL_Dp_ReadDataReg(void);
uint8   CNSL_Dp_Read(void);
void    CNSL_Dp_SetInterruptMode(uint16 position, uint16 mode);
uint8   CNSL_Dp_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the CNSL_Dp_SetDriveMode() function.
     *  @{
     */
        #define CNSL_Dp_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define CNSL_Dp_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define CNSL_Dp_DM_RES_UP          PIN_DM_RES_UP
        #define CNSL_Dp_DM_RES_DWN         PIN_DM_RES_DWN
        #define CNSL_Dp_DM_OD_LO           PIN_DM_OD_LO
        #define CNSL_Dp_DM_OD_HI           PIN_DM_OD_HI
        #define CNSL_Dp_DM_STRONG          PIN_DM_STRONG
        #define CNSL_Dp_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define CNSL_Dp_MASK               CNSL_Dp__MASK
#define CNSL_Dp_SHIFT              CNSL_Dp__SHIFT
#define CNSL_Dp_WIDTH              1u

/* Interrupt constants */
#if defined(CNSL_Dp__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in CNSL_Dp_SetInterruptMode() function.
     *  @{
     */
        #define CNSL_Dp_INTR_NONE      (uint16)(0x0000u)
        #define CNSL_Dp_INTR_RISING    (uint16)(0x0001u)
        #define CNSL_Dp_INTR_FALLING   (uint16)(0x0002u)
        #define CNSL_Dp_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define CNSL_Dp_INTR_MASK      (0x01u) 
#endif /* (CNSL_Dp__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define CNSL_Dp_PS                     (* (reg8 *) CNSL_Dp__PS)
/* Data Register */
#define CNSL_Dp_DR                     (* (reg8 *) CNSL_Dp__DR)
/* Port Number */
#define CNSL_Dp_PRT_NUM                (* (reg8 *) CNSL_Dp__PRT) 
/* Connect to Analog Globals */                                                  
#define CNSL_Dp_AG                     (* (reg8 *) CNSL_Dp__AG)                       
/* Analog MUX bux enable */
#define CNSL_Dp_AMUX                   (* (reg8 *) CNSL_Dp__AMUX) 
/* Bidirectional Enable */                                                        
#define CNSL_Dp_BIE                    (* (reg8 *) CNSL_Dp__BIE)
/* Bit-mask for Aliased Register Access */
#define CNSL_Dp_BIT_MASK               (* (reg8 *) CNSL_Dp__BIT_MASK)
/* Bypass Enable */
#define CNSL_Dp_BYP                    (* (reg8 *) CNSL_Dp__BYP)
/* Port wide control signals */                                                   
#define CNSL_Dp_CTL                    (* (reg8 *) CNSL_Dp__CTL)
/* Drive Modes */
#define CNSL_Dp_DM0                    (* (reg8 *) CNSL_Dp__DM0) 
#define CNSL_Dp_DM1                    (* (reg8 *) CNSL_Dp__DM1)
#define CNSL_Dp_DM2                    (* (reg8 *) CNSL_Dp__DM2) 
/* Input Buffer Disable Override */
#define CNSL_Dp_INP_DIS                (* (reg8 *) CNSL_Dp__INP_DIS)
/* LCD Common or Segment Drive */
#define CNSL_Dp_LCD_COM_SEG            (* (reg8 *) CNSL_Dp__LCD_COM_SEG)
/* Enable Segment LCD */
#define CNSL_Dp_LCD_EN                 (* (reg8 *) CNSL_Dp__LCD_EN)
/* Slew Rate Control */
#define CNSL_Dp_SLW                    (* (reg8 *) CNSL_Dp__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define CNSL_Dp_PRTDSI__CAPS_SEL       (* (reg8 *) CNSL_Dp__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define CNSL_Dp_PRTDSI__DBL_SYNC_IN    (* (reg8 *) CNSL_Dp__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define CNSL_Dp_PRTDSI__OE_SEL0        (* (reg8 *) CNSL_Dp__PRTDSI__OE_SEL0) 
#define CNSL_Dp_PRTDSI__OE_SEL1        (* (reg8 *) CNSL_Dp__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define CNSL_Dp_PRTDSI__OUT_SEL0       (* (reg8 *) CNSL_Dp__PRTDSI__OUT_SEL0) 
#define CNSL_Dp_PRTDSI__OUT_SEL1       (* (reg8 *) CNSL_Dp__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define CNSL_Dp_PRTDSI__SYNC_OUT       (* (reg8 *) CNSL_Dp__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(CNSL_Dp__SIO_CFG)
    #define CNSL_Dp_SIO_HYST_EN        (* (reg8 *) CNSL_Dp__SIO_HYST_EN)
    #define CNSL_Dp_SIO_REG_HIFREQ     (* (reg8 *) CNSL_Dp__SIO_REG_HIFREQ)
    #define CNSL_Dp_SIO_CFG            (* (reg8 *) CNSL_Dp__SIO_CFG)
    #define CNSL_Dp_SIO_DIFF           (* (reg8 *) CNSL_Dp__SIO_DIFF)
#endif /* (CNSL_Dp__SIO_CFG) */

/* Interrupt Registers */
#if defined(CNSL_Dp__INTSTAT)
    #define CNSL_Dp_INTSTAT            (* (reg8 *) CNSL_Dp__INTSTAT)
    #define CNSL_Dp_SNAP               (* (reg8 *) CNSL_Dp__SNAP)
    
	#define CNSL_Dp_0_INTTYPE_REG 		(* (reg8 *) CNSL_Dp__0__INTTYPE)
#endif /* (CNSL_Dp__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_CNSL_Dp_H */


/* [] END OF FILE */
