/***************************************************************************//**
* \file CNSL_cdc.h
* \version 3.20
*
* \brief
*  This file provides function prototypes and constants for the USBFS component 
*  CDC class.
*
* Related Document:
*  Universal Serial Bus Class Definitions for Communication Devices Version 1.1
*
********************************************************************************
* \copyright
* Copyright 2012-2016, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_USBFS_CNSL_cdc_H)
#define CY_USBFS_CNSL_cdc_H

#include "CNSL.h"


/*******************************************************************************
* Prototypes of the CNSL_cdc API.
*******************************************************************************/
/**
* \addtogroup group_cdc
* @{
*/
#if (CNSL_ENABLE_CDC_CLASS_API != 0u)
    uint8 CNSL_CDC_Init(void)            ;
    void CNSL_PutData(const uint8* pData, uint16 length) ;
    void CNSL_PutString(const char8 string[])            ;
    void CNSL_PutChar(char8 txDataByte) ;
    void CNSL_PutCRLF(void)             ;
    uint16 CNSL_GetCount(void)          ;
    uint8  CNSL_CDCIsReady(void)        ;
    uint8  CNSL_DataIsReady(void)       ;
    uint16 CNSL_GetData(uint8* pData, uint16 length)     ;
    uint16 CNSL_GetAll(uint8* pData)    ;
    uint8  CNSL_GetChar(void)           ;
    uint8  CNSL_IsLineChanged(void)     ;
    uint32 CNSL_GetDTERate(void)        ;
    uint8  CNSL_GetCharFormat(void)     ;
    uint8  CNSL_GetParityType(void)     ;
    uint8  CNSL_GetDataBits(void)       ;
    uint16 CNSL_GetLineControl(void)    ;
    void CNSL_SendSerialState (uint16 serialState) ;
    uint16 CNSL_GetSerialState (void)   ;
    void CNSL_SetComPort (uint8 comNumber) ;
    uint8 CNSL_GetComPort (void)        ;
    uint8 CNSL_NotificationIsReady(void) ;

#endif  /* (CNSL_ENABLE_CDC_CLASS_API) */
/** @} cdc */

/*******************************************************************************
*  Constants for CNSL_cdc API.
*******************************************************************************/

/* CDC Class-Specific Request Codes (CDC ver 1.2 Table 19) */
#define CNSL_CDC_SET_LINE_CODING        (0x20u)
#define CNSL_CDC_GET_LINE_CODING        (0x21u)
#define CNSL_CDC_SET_CONTROL_LINE_STATE (0x22u)

/*PSTN Subclass Specific Notifications (CDC ver 1.2 Table 30)*/
#define CNSL_SERIAL_STATE               (0x20u)

#define CNSL_LINE_CODING_CHANGED        (0x01u)
#define CNSL_LINE_CONTROL_CHANGED       (0x02u)

#define CNSL_1_STOPBIT                  (0x00u)
#define CNSL_1_5_STOPBITS               (0x01u)
#define CNSL_2_STOPBITS                 (0x02u)

#define CNSL_PARITY_NONE                (0x00u)
#define CNSL_PARITY_ODD                 (0x01u)
#define CNSL_PARITY_EVEN                (0x02u)
#define CNSL_PARITY_MARK                (0x03u)
#define CNSL_PARITY_SPACE               (0x04u)

#define CNSL_LINE_CODING_SIZE           (0x07u)
#define CNSL_LINE_CODING_RATE           (0x00u)
#define CNSL_LINE_CODING_STOP_BITS      (0x04u)
#define CNSL_LINE_CODING_PARITY         (0x05u)
#define CNSL_LINE_CODING_DATA_BITS      (0x06u)

#define CNSL_LINE_CONTROL_DTR           (0x01u)
#define CNSL_LINE_CONTROL_RTS           (0x02u)

#define CNSL_MAX_MULTI_COM_NUM          (2u) 

#define CNSL_COM_PORT1                  (0u) 
#define CNSL_COM_PORT2                  (1u) 

#define CNSL_SUCCESS                    (0u)
#define CNSL_FAILURE                    (1u)

#define CNSL_SERIAL_STATE_SIZE          (10u)

/* SerialState constants*/
#define CNSL_SERIAL_STATE_REQUEST_TYPE  (0xA1u)
#define CNSL_SERIAL_STATE_LENGTH        (0x2u)

/*******************************************************************************
* External data references
*******************************************************************************/
/**
* \addtogroup group_cdc
* @{
*/
extern volatile uint8  CNSL_linesCoding[CNSL_MAX_MULTI_COM_NUM][CNSL_LINE_CODING_SIZE];
extern volatile uint8  CNSL_linesChanged[CNSL_MAX_MULTI_COM_NUM];
extern volatile uint16 CNSL_linesControlBitmap[CNSL_MAX_MULTI_COM_NUM];
extern volatile uint16 CNSL_serialStateBitmap[CNSL_MAX_MULTI_COM_NUM];
extern volatile uint8  CNSL_cdcDataInEp[CNSL_MAX_MULTI_COM_NUM];
extern volatile uint8  CNSL_cdcDataOutEp[CNSL_MAX_MULTI_COM_NUM];
extern volatile uint8  CNSL_cdcCommInInterruptEp[CNSL_MAX_MULTI_COM_NUM];
/** @} cdc */

/*******************************************************************************
* The following code is DEPRECATED and
* must not be used.
*******************************************************************************/


#define CNSL_lineCoding             CNSL_linesCoding[0]
#define CNSL_lineChanged            CNSL_linesChanged[0]
#define CNSL_lineControlBitmap      CNSL_linesControlBitmap[0]
#define CNSL_cdc_data_in_ep         CNSL_cdcDataInEp[0]
#define CNSL_cdc_data_out_ep        CNSL_cdcDataOutEp[0]

#endif /* (CY_USBFS_CNSL_cdc_H) */


/* [] END OF FILE */
