/***************************************************************************//**
* \file CNSL_episr.c
* \version 3.20
*
* \brief
*  This file contains the Data endpoint Interrupt Service Routines.
*
********************************************************************************
* \copyright
* Copyright 2008-2016, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "CNSL_pvt.h"
#include "CNSL_cydmac.h"



/***************************************
* Custom Declarations
***************************************/
/* `#START CUSTOM_DECLARATIONS` Place your declaration here */

/* `#END` */


#if (CNSL_EP1_ISR_ACTIVE)
    /******************************************************************************
    * Function Name: CNSL_EP_1_ISR
    ***************************************************************************//**
    *
    *  Endpoint 1 Interrupt Service Routine
    *
    ******************************************************************************/
    CY_ISR(CNSL_EP_1_ISR)
    {

    #ifdef CNSL_EP_1_ISR_ENTRY_CALLBACK
        CNSL_EP_1_ISR_EntryCallback();
    #endif /* (CNSL_EP_1_ISR_ENTRY_CALLBACK) */

        /* `#START EP1_USER_CODE` Place your code here */

        /* `#END` */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        {
            uint8 intEn = EA;
            CyGlobalIntEnable;  /* Enable nested interrupts. */
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */
    
        CNSL_ClearSieEpInterruptSource(CNSL_SIE_INT_EP1_INTR);
            
        /* Notifies user that transfer IN or OUT transfer is completed.
        * IN endpoint: endpoint buffer can be reloaded, Host is read data.
        * OUT endpoint: data is ready to be read from endpoint buffer. 
        */
    #if (CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)
        if (0u != (CNSL_EP[CNSL_EP1].addr & CNSL_DIR_IN))
    #endif /* (CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO) */
        {
            /* Read CR0 register to clear SIE lock. */
            (void) CNSL_SIE_EP_BASE.sieEp[CNSL_EP1].epCr0;
            
            /* Toggle all endpoint types except ISOC. */
            if (CNSL_GET_EP_TYPE(CNSL_EP1) != CNSL_EP_TYPE_ISOC)
            {
                CNSL_EP[CNSL_EP1].epToggle ^= CNSL_EPX_CNT_DATA_TOGGLE;
            }

            /* EP_MANAGEMENT_DMA_AUTO (Ticket ID# 214187): For OUT endpoint this event is used to notify
            * user that DMA has completed copying data from OUT endpoint which is not completely true.
            * Because last chunk of data is being copied.
            * For CY_PSOC 3/5LP: it is acceptable as DMA is really fast.
            * For CY_PSOC4: this event is set in Arbiter interrupt (source is DMA_TERMIN).
            */
            CNSL_EP[CNSL_EP1].apiEpState = CNSL_EVENT_PENDING;
        }

    #if (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO))
        #if (defined(CNSL_ENABLE_MIDI_STREAMING) && \
            !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
            if (CNSL_midi_out_ep == CNSL_EP1)
            {
                CNSL_MIDI_OUT_Service();
            }
        #endif /* (CNSL_ISR_SERVICE_MIDI_OUT) */
    #endif /* (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)) */
    
        /* `#START EP1_END_USER_CODE` Place your code here */

        /* `#END` */

    #ifdef CNSL_EP_1_ISR_EXIT_CALLBACK
        CNSL_EP_1_ISR_ExitCallback();
    #endif /* (CNSL_EP_1_ISR_EXIT_CALLBACK) */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        
            EA = intEn; /* Restore nested interrupt configuration. */
        }
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */
    }

#endif /* (CNSL_EP1_ISR_ACTIVE) */


#if (CNSL_EP2_ISR_ACTIVE)
    /*******************************************************************************
    * Function Name: CNSL_EP_2_ISR
    ****************************************************************************//**
    *
    *  Endpoint 2 Interrupt Service Routine.
    *
    *******************************************************************************/
    CY_ISR(CNSL_EP_2_ISR)
    {
    #ifdef CNSL_EP_2_ISR_ENTRY_CALLBACK
        CNSL_EP_2_ISR_EntryCallback();
    #endif /* (CNSL_EP_2_ISR_ENTRY_CALLBACK) */

        /* `#START EP2_USER_CODE` Place your code here */

        /* `#END` */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        {
            uint8 intEn = EA;
            CyGlobalIntEnable;  /* Enable nested interrupts. */
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */

        CNSL_ClearSieEpInterruptSource(CNSL_SIE_INT_EP2_INTR);

        /* Notifies user that transfer IN or OUT transfer is completed.
        * IN endpoint: endpoint buffer can be reloaded, Host is read data.
        * OUT endpoint: data is ready to be read from endpoint buffer. 
        */
    #if (CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)
        if (0u != (CNSL_EP[CNSL_EP2].addr & CNSL_DIR_IN))
    #endif /* (CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO) */
        {            
            /* Read CR0 register to clear SIE lock. */
            (void) CNSL_SIE_EP_BASE.sieEp[CNSL_EP2].epCr0;
            
            /* Toggle all endpoint types except ISOC. */
            if (CNSL_GET_EP_TYPE(CNSL_EP2) != CNSL_EP_TYPE_ISOC)
            {
                CNSL_EP[CNSL_EP2].epToggle ^= CNSL_EPX_CNT_DATA_TOGGLE;
            }

            /* EP_MANAGEMENT_DMA_AUTO (Ticket ID# 214187): For OUT endpoint this event is used to notify
            * user that DMA has completed copying data from OUT endpoint which is not completely true.
            * Because last chunk of data is being copied.
            * For CY_PSOC 3/5LP: it is acceptable as DMA is really fast.
            * For CY_PSOC4: this event is set in Arbiter interrupt (source is DMA_TERMIN).
            */
            CNSL_EP[CNSL_EP2].apiEpState = CNSL_EVENT_PENDING;
        }

    #if (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO))
        #if (defined(CNSL_ENABLE_MIDI_STREAMING) && \
            !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
            if (CNSL_midi_out_ep == CNSL_EP2)
            {
                CNSL_MIDI_OUT_Service();
            }
        #endif /* (CNSL_ISR_SERVICE_MIDI_OUT) */
    #endif /* (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)) */        
    
        /* `#START EP2_END_USER_CODE` Place your code here */

        /* `#END` */

    #ifdef CNSL_EP_2_ISR_EXIT_CALLBACK
        CNSL_EP_2_ISR_ExitCallback();
    #endif /* (CNSL_EP_2_ISR_EXIT_CALLBACK) */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        
            EA = intEn; /* Restore nested interrupt configuration. */
        }
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */
    }
#endif /* (CNSL_EP2_ISR_ACTIVE) */


#if (CNSL_EP3_ISR_ACTIVE)
    /*******************************************************************************
    * Function Name: CNSL_EP_3_ISR
    ****************************************************************************//**
    *
    *  Endpoint 3 Interrupt Service Routine.
    *
    *******************************************************************************/
    CY_ISR(CNSL_EP_3_ISR)
    {
    #ifdef CNSL_EP_3_ISR_ENTRY_CALLBACK
        CNSL_EP_3_ISR_EntryCallback();
    #endif /* (CNSL_EP_3_ISR_ENTRY_CALLBACK) */

        /* `#START EP3_USER_CODE` Place your code here */

        /* `#END` */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        {
            uint8 intEn = EA;
            CyGlobalIntEnable;  /* Enable nested interrupts. */
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */

        CNSL_ClearSieEpInterruptSource(CNSL_SIE_INT_EP3_INTR);    

        /* Notifies user that transfer IN or OUT transfer is completed.
        * IN endpoint: endpoint buffer can be reloaded, Host is read data.
        * OUT endpoint: data is ready to be read from endpoint buffer. 
        */
    #if (CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)
        if (0u != (CNSL_EP[CNSL_EP3].addr & CNSL_DIR_IN))
    #endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO) */
        {            
            /* Read CR0 register to clear SIE lock. */
            (void) CNSL_SIE_EP_BASE.sieEp[CNSL_EP3].epCr0;

            /* Toggle all endpoint types except ISOC. */
            if (CNSL_GET_EP_TYPE(CNSL_EP3) != CNSL_EP_TYPE_ISOC)
            {
                CNSL_EP[CNSL_EP3].epToggle ^= CNSL_EPX_CNT_DATA_TOGGLE;
            }

            /* EP_MANAGEMENT_DMA_AUTO (Ticket ID# 214187): For OUT endpoint this event is used to notify
            * user that DMA has completed copying data from OUT endpoint which is not completely true.
            * Because last chunk of data is being copied.
            * For CY_PSOC 3/5LP: it is acceptable as DMA is really fast.
            * For CY_PSOC4: this event is set in Arbiter interrupt (source is DMA_TERMIN).
            */
            CNSL_EP[CNSL_EP3].apiEpState = CNSL_EVENT_PENDING;
        }

    #if (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO))
        #if (defined(CNSL_ENABLE_MIDI_STREAMING) && \
            !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
            if (CNSL_midi_out_ep == CNSL_EP3)
            {
                CNSL_MIDI_OUT_Service();
            }
        #endif /* (CNSL_ISR_SERVICE_MIDI_OUT) */
    #endif /* (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)) */        

        /* `#START EP3_END_USER_CODE` Place your code here */

        /* `#END` */

    #ifdef CNSL_EP_3_ISR_EXIT_CALLBACK
        CNSL_EP_3_ISR_ExitCallback();
    #endif /* (CNSL_EP_3_ISR_EXIT_CALLBACK) */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        
            EA = intEn; /* Restore nested interrupt configuration. */
        }
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */
    }
#endif /* (CNSL_EP3_ISR_ACTIVE) */


#if (CNSL_EP4_ISR_ACTIVE)
    /*******************************************************************************
    * Function Name: CNSL_EP_4_ISR
    ****************************************************************************//**
    *
    *  Endpoint 4 Interrupt Service Routine.
    *
    *******************************************************************************/
    CY_ISR(CNSL_EP_4_ISR)
    {
    #ifdef CNSL_EP_4_ISR_ENTRY_CALLBACK
        CNSL_EP_4_ISR_EntryCallback();
    #endif /* (CNSL_EP_4_ISR_ENTRY_CALLBACK) */

        /* `#START EP4_USER_CODE` Place your code here */

        /* `#END` */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        {
            uint8 intEn = EA;
            CyGlobalIntEnable;  /* Enable nested interrupts. */
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */

        CNSL_ClearSieEpInterruptSource(CNSL_SIE_INT_EP4_INTR);
        
        /* Notifies user that transfer IN or OUT transfer is completed.
        * IN endpoint: endpoint buffer can be reloaded, Host is read data.
        * OUT endpoint: data is ready to read from endpoint buffer. 
        */
    #if (CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)
        if (0u != (CNSL_EP[CNSL_EP4].addr & CNSL_DIR_IN))
    #endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO) */
        {
            /* Read CR0 register to clear SIE lock. */
            (void) CNSL_SIE_EP_BASE.sieEp[CNSL_EP4].epCr0;

            /* Toggle all endpoint types except ISOC. */
            if (CNSL_GET_EP_TYPE(CNSL_EP4) != CNSL_EP_TYPE_ISOC)
            {
                CNSL_EP[CNSL_EP4].epToggle ^= CNSL_EPX_CNT_DATA_TOGGLE;
            }

            /* EP_MANAGEMENT_DMA_AUTO (Ticket ID# 214187): For OUT endpoint this event is used to notify
            * user that DMA has completed copying data from OUT endpoint which is not completely true.
            * Because last chunk of data is being copied.
            * For CY_PSOC 3/5LP: it is acceptable as DMA is really fast.
            * For CY_PSOC4: this event is set in Arbiter interrupt (source is DMA_TERMIN).
            */
            CNSL_EP[CNSL_EP4].apiEpState = CNSL_EVENT_PENDING;
        }

    #if (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO))
        #if (defined(CNSL_ENABLE_MIDI_STREAMING) && \
            !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
            if(CNSL_midi_out_ep == CNSL_EP4)
            {
                CNSL_MIDI_OUT_Service();
            }
        #endif /* (CNSL_ISR_SERVICE_MIDI_OUT) */
    #endif /* (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)) */        

        /* `#START EP4_END_USER_CODE` Place your code here */

        /* `#END` */

    #ifdef CNSL_EP_4_ISR_EXIT_CALLBACK
        CNSL_EP_4_ISR_ExitCallback();
    #endif /* (CNSL_EP_4_ISR_EXIT_CALLBACK) */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        
            EA = intEn; /* Restore nested interrupt configuration. */
        }
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */
    }
#endif /* (CNSL_EP4_ISR_ACTIVE) */


#if (CNSL_EP5_ISR_ACTIVE)
    /*******************************************************************************
    * Function Name: CNSL_EP_5_ISR
    ****************************************************************************//**
    *
    *  Endpoint 5 Interrupt Service Routine
    *
    *
    *******************************************************************************/
    CY_ISR(CNSL_EP_5_ISR)
    {
    #ifdef CNSL_EP_5_ISR_ENTRY_CALLBACK
        CNSL_EP_5_ISR_EntryCallback();
    #endif /* (CNSL_EP_5_ISR_ENTRY_CALLBACK) */

        /* `#START EP5_USER_CODE` Place your code here */

        /* `#END` */

    #if (defined(CNSL_ENABLE_MIDI_STREAMING) && !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && \
                 CNSL_ISR_SERVICE_MIDI_OUT && CY_PSOC3)
        {
            uint8 intEn = EA;
            CyGlobalIntEnable;  /* Enable nested interrupts. */
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */

        CNSL_ClearSieEpInterruptSource(CNSL_SIE_INT_EP5_INTR);
    
        /* Notifies user that transfer IN or OUT transfer is completed.
        * IN endpoint: endpoint buffer can be reloaded, Host is read data.
        * OUT endpoint: data is ready to read from endpoint buffer. 
        */
    #if (CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)
        if (0u != (CNSL_EP[CNSL_EP5].addr & CNSL_DIR_IN))
    #endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO) */
        {            
            /* Read CR0 register to clear SIE lock. */
            (void) CNSL_SIE_EP_BASE.sieEp[CNSL_EP5].epCr0;

            /* Toggle all endpoint types except ISOC. */
            if (CNSL_GET_EP_TYPE(CNSL_EP5) != CNSL_EP_TYPE_ISOC)
            {
                CNSL_EP[CNSL_EP5].epToggle ^= CNSL_EPX_CNT_DATA_TOGGLE;
            }

            /* EP_MANAGEMENT_DMA_AUTO (Ticket ID# 214187): For OUT endpoint this event is used to notify
            * user that DMA has completed copying data from OUT endpoint which is not completely true.
            * Because last chunk of data is being copied.
            * For CY_PSOC 3/5LP: it is acceptable as DMA is really fast.
            * For CY_PSOC4: this event is set in Arbiter interrupt (source is DMA_TERMIN).
            */
            CNSL_EP[CNSL_EP5].apiEpState = CNSL_EVENT_PENDING;
        }

    #if (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO))        
        #if (defined(CNSL_ENABLE_MIDI_STREAMING) && \
            !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
            if (CNSL_midi_out_ep == CNSL_EP5)
            {
                CNSL_MIDI_OUT_Service();
            }
        #endif /* (CNSL_ISR_SERVICE_MIDI_OUT) */
    #endif /* (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)) */

        /* `#START EP5_END_USER_CODE` Place your code here */

        /* `#END` */

    #ifdef CNSL_EP_5_ISR_EXIT_CALLBACK
        CNSL_EP_5_ISR_ExitCallback();
    #endif /* (CNSL_EP_5_ISR_EXIT_CALLBACK) */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        
            EA = intEn; /* Restore nested interrupt configuration. */
        }
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */
    }
#endif /* (CNSL_EP5_ISR_ACTIVE) */


#if (CNSL_EP6_ISR_ACTIVE)
    /*******************************************************************************
    * Function Name: CNSL_EP_6_ISR
    ****************************************************************************//**
    *
    *  Endpoint 6 Interrupt Service Routine.
    *
    *
    *******************************************************************************/
    CY_ISR(CNSL_EP_6_ISR)
    {
    #ifdef CNSL_EP_6_ISR_ENTRY_CALLBACK
        CNSL_EP_6_ISR_EntryCallback();
    #endif /* (CNSL_EP_6_ISR_ENTRY_CALLBACK) */

        /* `#START EP6_USER_CODE` Place your code here */

        /* `#END` */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        {
            uint8 intEn = EA;
            CyGlobalIntEnable;  /* Enable nested interrupts. */
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */

        CNSL_ClearSieEpInterruptSource(CNSL_SIE_INT_EP6_INTR);
        
        /* Notifies user that transfer IN or OUT transfer is completed.
        * IN endpoint: endpoint buffer can be reloaded, Host is read data.
        * OUT endpoint: data is ready to read from endpoint buffer. 
        */
    #if (CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)
        if (0u != (CNSL_EP[CNSL_EP6].addr & CNSL_DIR_IN))
    #endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO) */
        {
            /* Read CR0 register to clear SIE lock. */
            (void) CNSL_SIE_EP_BASE.sieEp[CNSL_EP6].epCr0;

            /* Toggle all endpoint types except ISOC. */
            if (CNSL_GET_EP_TYPE(CNSL_EP6) != CNSL_EP_TYPE_ISOC)
            {
                CNSL_EP[CNSL_EP6].epToggle ^= CNSL_EPX_CNT_DATA_TOGGLE;
            }
            
            /* EP_MANAGEMENT_DMA_AUTO (Ticket ID# 214187): For OUT endpoint this event is used to notify
            * user that DMA has completed copying data from OUT endpoint which is not completely true.
            * Because last chunk of data is being copied.
            * For CY_PSOC 3/5LP: it is acceptable as DMA is really fast.
            * For CY_PSOC4: this event is set in Arbiter interrupt (source is DMA_TERMIN).
            */
            CNSL_EP[CNSL_EP6].apiEpState = CNSL_EVENT_PENDING;
        }

    #if (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO))
        #if (defined(CNSL_ENABLE_MIDI_STREAMING) && \
            !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
            if (CNSL_midi_out_ep == CNSL_EP6)
            {
                CNSL_MIDI_OUT_Service();
            }
        #endif /* (CNSL_ISR_SERVICE_MIDI_OUT) */
    #endif /* (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)) */

        /* `#START EP6_END_USER_CODE` Place your code here */

        /* `#END` */

    #ifdef CNSL_EP_6_ISR_EXIT_CALLBACK
        CNSL_EP_6_ISR_ExitCallback();
    #endif /* (CNSL_EP_6_ISR_EXIT_CALLBACK) */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        
            EA = intEn; /* Restore nested interrupt configuration. */
        }
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */
    }
#endif /* (CNSL_EP6_ISR_ACTIVE) */


#if (CNSL_EP7_ISR_ACTIVE)
    /*******************************************************************************
    * Function Name: CNSL_EP_7_ISR
    ****************************************************************************//**
    *
    *  Endpoint 7 Interrupt Service Routine.
    *
    *
    *******************************************************************************/
    CY_ISR(CNSL_EP_7_ISR)
    {
    #ifdef CNSL_EP_7_ISR_ENTRY_CALLBACK
        CNSL_EP_7_ISR_EntryCallback();
    #endif /* (CNSL_EP_7_ISR_ENTRY_CALLBACK) */

        /* `#START EP7_USER_CODE` Place your code here */

        /* `#END` */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        {
            uint8 intEn = EA;
            CyGlobalIntEnable;  /* Enable nested interrupts. */
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */
    
        CNSL_ClearSieEpInterruptSource(CNSL_SIE_INT_EP7_INTR);
        
        /* Notifies user that transfer IN or OUT transfer is completed.
        * IN endpoint: endpoint buffer can be reloaded, Host is read data.
        * OUT endpoint: data is ready to read from endpoint buffer. 
        */
    #if (CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)
        if (0u != (CNSL_EP[CNSL_EP7].addr & CNSL_DIR_IN))
    #endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO) */
        {           
            /* Read CR0 register to clear SIE lock. */
            (void) CNSL_SIE_EP_BASE.sieEp[CNSL_EP7].epCr0;

            /* Toggle all endpoint types except ISOC. */
            if (CNSL_GET_EP_TYPE(CNSL_EP7) != CNSL_EP_TYPE_ISOC)
            {
                CNSL_EP[CNSL_EP7].epToggle ^= CNSL_EPX_CNT_DATA_TOGGLE;
            }
            
            /* EP_MANAGEMENT_DMA_AUTO (Ticket ID# 214187): For OUT endpoint this event is used to notify
            * user that DMA has completed copying data from OUT endpoint which is not completely true.
            * Because last chunk of data is being copied.
            * For CY_PSOC 3/5LP: it is acceptable as DMA is really fast.
            * For CY_PSOC4: this event is set in Arbiter interrupt (source is DMA_TERMIN).
            */
            CNSL_EP[CNSL_EP7].apiEpState = CNSL_EVENT_PENDING;
        }


    #if (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO))
        #if (defined(CNSL_ENABLE_MIDI_STREAMING) && \
            !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
            if(CNSL_midi_out_ep == CNSL_EP7)
            {
                CNSL_MIDI_OUT_Service();
            }
        #endif /* (CNSL_ISR_SERVICE_MIDI_OUT) */
    #endif /* (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)) */

        /* `#START EP7_END_USER_CODE` Place your code here */

        /* `#END` */

    #ifdef CNSL_EP_7_ISR_EXIT_CALLBACK
        CNSL_EP_7_ISR_ExitCallback();
    #endif /* (CNSL_EP_7_ISR_EXIT_CALLBACK) */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        
            EA = intEn; /* Restore nested interrupt configuration. */
        }
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */
    }
#endif /* (CNSL_EP7_ISR_ACTIVE) */


#if (CNSL_EP8_ISR_ACTIVE)
    /*******************************************************************************
    * Function Name: CNSL_EP_8_ISR
    ****************************************************************************//**
    *
    *  Endpoint 8 Interrupt Service Routine
    *
    *
    *******************************************************************************/
    CY_ISR(CNSL_EP_8_ISR)
    {
    #ifdef CNSL_EP_8_ISR_ENTRY_CALLBACK
        CNSL_EP_8_ISR_EntryCallback();
    #endif /* (CNSL_EP_8_ISR_ENTRY_CALLBACK) */

        /* `#START EP8_USER_CODE` Place your code here */

        /* `#END` */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        {
            uint8 intEn = EA;
            CyGlobalIntEnable;  /* Enable nested interrupts. */
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */

        CNSL_ClearSieEpInterruptSource(CNSL_SIE_INT_EP8_INTR);
        
        /* Notifies user that transfer IN or OUT transfer is completed.
        * IN endpoint: endpoint buffer can be reloaded, Host is read data.
        * OUT endpoint: data is ready to read from endpoint buffer. 
        */
    #if (CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)
        if (0u != (CNSL_EP[CNSL_EP8].addr & CNSL_DIR_IN))
    #endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO) */
        {
            /* Read CR0 register to clear SIE lock. */
            (void) CNSL_SIE_EP_BASE.sieEp[CNSL_EP8].epCr0;

            /* Toggle all endpoint types except ISOC. */
            if (CNSL_GET_EP_TYPE(CNSL_EP8) != CNSL_EP_TYPE_ISOC)
            {
                CNSL_EP[CNSL_EP8].epToggle ^= CNSL_EPX_CNT_DATA_TOGGLE;
            }

            /* EP_MANAGEMENT_DMA_AUTO (Ticket ID# 214187): For OUT endpoint this event is used to notify
            * user that DMA has completed copying data from OUT endpoint which is not completely true.
            * Because last chunk of data is being copied.
            * For CY_PSOC 3/5LP: it is acceptable as DMA is really fast.
            * For CY_PSOC4: this event is set in Arbiter interrupt (source is DMA_TERMIN).
            */
            CNSL_EP[CNSL_EP8].apiEpState = CNSL_EVENT_PENDING;
        }

    #if (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO))
        #if (defined(CNSL_ENABLE_MIDI_STREAMING) && \
            !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
            if (CNSL_midi_out_ep == CNSL_EP8)
            {
                CNSL_MIDI_OUT_Service();
            }
        #endif /* (CNSL_ISR_SERVICE_MIDI_OUT) */
    #endif /* (!(CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)) */

        /* `#START EP8_END_USER_CODE` Place your code here */

        /* `#END` */

    #ifdef CNSL_EP_8_ISR_EXIT_CALLBACK
        CNSL_EP_8_ISR_ExitCallback();
    #endif /* (CNSL_EP_8_ISR_EXIT_CALLBACK) */

    #if (CY_PSOC3 && defined(CNSL_ENABLE_MIDI_STREAMING) && \
        !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
        
            EA = intEn; /* Restore nested interrupt configuration. */
        }
    #endif /* (CY_PSOC3 && CNSL_ISR_SERVICE_MIDI_OUT) */
    }
#endif /* (CNSL_EP8_ISR_ACTIVE) */


#if (CNSL_SOF_ISR_ACTIVE)
    /*******************************************************************************
    * Function Name: CNSL_SOF_ISR
    ****************************************************************************//**
    *
    *  Start of Frame Interrupt Service Routine.
    *
    *
    *******************************************************************************/
    CY_ISR(CNSL_SOF_ISR)
    {
    #ifdef CNSL_SOF_ISR_ENTRY_CALLBACK
        CNSL_SOF_ISR_EntryCallback();
    #endif /* (CNSL_SOF_ISR_ENTRY_CALLBACK) */

        /* `#START SOF_USER_CODE` Place your code here */

        /* `#END` */

        CNSL_ClearSieInterruptSource(CNSL_INTR_SIE_SOF_INTR);

    #ifdef CNSL_SOF_ISR_EXIT_CALLBACK
        CNSL_SOF_ISR_ExitCallback();
    #endif /* (CNSL_SOF_ISR_EXIT_CALLBACK) */
    }
#endif /* (CNSL_SOF_ISR_ACTIVE) */


#if (CNSL_BUS_RESET_ISR_ACTIVE)
/*******************************************************************************
* Function Name: CNSL_BUS_RESET_ISR
****************************************************************************//**
*
*  USB Bus Reset Interrupt Service Routine.  Calls _Start with the same
*  parameters as the last USER call to _Start
*
*
*******************************************************************************/
CY_ISR(CNSL_BUS_RESET_ISR)
{
#ifdef CNSL_BUS_RESET_ISR_ENTRY_CALLBACK
    CNSL_BUS_RESET_ISR_EntryCallback();
#endif /* (CNSL_BUS_RESET_ISR_ENTRY_CALLBACK) */

    /* `#START BUS_RESET_USER_CODE` Place your code here */

    /* `#END` */

    CNSL_ClearSieInterruptSource(CNSL_INTR_SIE_BUS_RESET_INTR);

    CNSL_ReInitComponent();

#ifdef CNSL_BUS_RESET_ISR_EXIT_CALLBACK
    CNSL_BUS_RESET_ISR_ExitCallback();
#endif /* (CNSL_BUS_RESET_ISR_EXIT_CALLBACK) */
}
#endif /* (CNSL_BUS_RESET_ISR_ACTIVE) */


#if (CNSL_LPM_ACTIVE)
/***************************************************************************
* Function Name: CNSL_INTR_LPM_ISR
************************************************************************//**
*
*   Interrupt Service Routine for LPM of the interrupt sources.
*
*
***************************************************************************/
CY_ISR(CNSL_LPM_ISR)
{
#ifdef CNSL_LPM_ISR_ENTRY_CALLBACK
    CNSL_LPM_ISR_EntryCallback();
#endif /* (CNSL_LPM_ISR_ENTRY_CALLBACK) */

    /* `#START LPM_BEGIN_USER_CODE` Place your code here */

    /* `#END` */

    CNSL_ClearSieInterruptSource(CNSL_INTR_SIE_LPM_INTR);

    /* `#START LPM_END_USER_CODE` Place your code here */

    /* `#END` */

#ifdef CNSL_LPM_ISR_EXIT_CALLBACK
    CNSL_LPM_ISR_ExitCallback();
#endif /* (CNSL_LPM_ISR_EXIT_CALLBACK) */
}
#endif /* (CNSL_LPM_ACTIVE) */


#if (CNSL_EP_MANAGEMENT_DMA && CNSL_ARB_ISR_ACTIVE)
    /***************************************************************************
    * Function Name: CNSL_ARB_ISR
    ************************************************************************//**
    *
    *  Arbiter Interrupt Service Routine.
    *
    *
    ***************************************************************************/
    CY_ISR(CNSL_ARB_ISR)
    {
        uint8 arbIntrStatus;
        uint8 epStatus;
        uint8 ep = CNSL_EP1;

    #ifdef CNSL_ARB_ISR_ENTRY_CALLBACK
        CNSL_ARB_ISR_EntryCallback();
    #endif /* (CNSL_ARB_ISR_ENTRY_CALLBACK) */

        /* `#START ARB_BEGIN_USER_CODE` Place your code here */

        /* `#END` */

        /* Get pending ARB interrupt sources. */
        arbIntrStatus = CNSL_ARB_INT_SR_REG;

        while (0u != arbIntrStatus)
        {
            /* Check which EP is interrupt source. */
            if (0u != (arbIntrStatus & 0x01u))
            {
                /* Get endpoint enable interrupt sources. */
                epStatus = (CNSL_ARB_EP_BASE.arbEp[ep].epSr & CNSL_ARB_EP_BASE.arbEp[ep].epIntEn);

                /* Handle IN endpoint buffer full event: happens only once when endpoint buffer is loaded. */
                if (0u != (epStatus & CNSL_ARB_EPX_INT_IN_BUF_FULL))
                {
                    if (0u != (CNSL_EP[ep].addr & CNSL_DIR_IN))
                    {
                        /* Clear data ready status. */
                        CNSL_ARB_EP_BASE.arbEp[ep].epCfg &= (uint8) ~CNSL_ARB_EPX_CFG_IN_DATA_RDY;

                    #if (CY_PSOC3 || CY_PSOC5LP)
                        #if (CNSL_EP_MANAGEMENT_DMA_AUTO && (CNSL_EP_DMA_AUTO_OPT == 0u))
                            /* Set up common area DMA with rest of data. */
                            if(CNSL_inLength[ep] > CNSL_DMA_BYTES_PER_BURST)
                            {
                                CNSL_LoadNextInEP(ep, 0u);
                            }
                            else
                            {
                                CNSL_inBufFull[ep] = 1u;
                            }
                        #endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO && (CNSL_EP_DMA_AUTO_OPT == 0u)) */
                    #endif /* (CY_PSOC3 || CY_PSOC5LP) */

                        /* Arm IN endpoint. */
                        CNSL_SIE_EP_BASE.sieEp[ep].epCr0 = CNSL_EP[ep].epMode;

                    #if (defined(CNSL_ENABLE_MIDI_STREAMING) && CNSL_ISR_SERVICE_MIDI_IN)
                        if (ep == CNSL_midi_in_ep)
                        {
                            /* Clear MIDI input pointer. */
                            CNSL_midiInPointer = 0u;
                        }
                    #endif /* (CNSL_ENABLE_MIDI_STREAMING) */
                    }
                }

            #if (CNSL_EP_MANAGEMENT_DMA_MANUAL)
                /* Handle DMA completion event for OUT endpoints. */
                if (0u != (epStatus & CNSL_ARB_EPX_SR_DMA_GNT))
                {
                    if (0u == (CNSL_EP[ep].addr & CNSL_DIR_IN))
                    {
                        /* Notify user that data has been copied from endpoint buffer. */
                        CNSL_EP[ep].apiEpState = CNSL_NO_EVENT_PENDING;

                        /* DMA done coping data: OUT endpoint has to be re-armed by user. */
                    }
                }
            #endif /* (CNSL_EP_MANAGEMENT_DMA_MANUAL) */

            #if (CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO)
                /* Handle DMA completion event for OUT endpoints. */
                if (0u != (epStatus & CNSL_ARB_EPX_INT_DMA_TERMIN))
                {
                    uint32 channelNum = CNSL_DmaChan[ep];

                    /* Restore burst counter for endpoint. */
                    CNSL_DmaEpBurstCnt[ep] = CNSL_DMA_GET_BURST_CNT(CNSL_DmaEpBurstCntBackup[ep]);

                    /* Disable DMA channel to restore descriptor configuration. The on-going transfer is aborted. */
                    CNSL_CyDmaChDisable(channelNum);

                    /* Generate DMA tr_out signal to notify USB IP that DMA is done. This signal is not generated
                    * when transfer was aborted (it occurs when host writes less bytes than buffer size).
                    */
                    CNSL_CyDmaTriggerOut(CNSL_DmaBurstEndOut[ep]);

                    /* Restore destination address for output endpoint. */
                    CNSL_CyDmaSetDstAddress(channelNum, CNSL_DMA_DESCR0, (void*) ((uint32) CNSL_DmaEpBufferAddrBackup[ep]));
                    CNSL_CyDmaSetDstAddress(channelNum, CNSL_DMA_DESCR1, (void*) ((uint32) CNSL_DmaEpBufferAddrBackup[ep] +
                                                                                                                   CNSL_DMA_BYTES_PER_BURST));

                    /* Restore number of data elements to transfer which was adjusted for last burst. */
                    if (0u != (CNSL_DmaEpLastBurstEl[ep] & CNSL_DMA_DESCR_REVERT))
                    {
                        CNSL_CyDmaSetNumDataElements(channelNum, (CNSL_DmaEpLastBurstEl[ep] >> CNSL_DMA_DESCR_SHIFT),
                                                                             CNSL_DMA_GET_MAX_ELEM_PER_BURST(CNSL_DmaEpLastBurstEl[ep]));
                    }

                    /* Validate descriptor 0 and 1 (also reset current state). Command to start with descriptor 0. */
                    CNSL_CyDmaValidateDescriptor(channelNum, CNSL_DMA_DESCR0);
                    if (CNSL_DmaEpBurstCntBackup[ep] > 1u)
                    {
                        CNSL_CyDmaValidateDescriptor(channelNum, CNSL_DMA_DESCR1);
                    }
                    CNSL_CyDmaSetDescriptor0Next(channelNum);

                    /* Enable DMA channel: configuration complete. */
                    CNSL_CyDmaChEnable(channelNum);
                    
                    
                    /* Read CR0 register to clear SIE lock. */
                    (void) CNSL_SIE_EP_BASE.sieEp[ep].epCr0;
                    
                    /* Toggle all endpoint types except ISOC. */
                    if (CNSL_GET_EP_TYPE(ep) != CNSL_EP_TYPE_ISOC)
                    {
                        CNSL_EP[ep].epToggle ^= CNSL_EPX_CNT_DATA_TOGGLE;
                    }
            
                    /* Notify user that data has been copied from endpoint buffer. */
                    CNSL_EP[ep].apiEpState = CNSL_EVENT_PENDING;
                    
                #if (defined(CNSL_ENABLE_MIDI_STREAMING) && \
                    !defined(CNSL_MAIN_SERVICE_MIDI_OUT) && CNSL_ISR_SERVICE_MIDI_OUT)
                    if (CNSL_midi_out_ep == ep)
                    {
                        CNSL_MIDI_OUT_Service();
                    }
                #endif /* (CNSL_ISR_SERVICE_MIDI_OUT) */
                }
            #endif /* (CY_PSOC4 && CNSL_EP_MANAGEMENT_DMA_AUTO) */


                /* `#START ARB_USER_CODE` Place your code here for handle Buffer Underflow/Overflow */

                /* `#END` */

            #ifdef CNSL_ARB_ISR_CALLBACK
                CNSL_ARB_ISR_Callback(ep, epStatus);
            #endif /* (CNSL_ARB_ISR_CALLBACK) */

                /* Clear serviced endpoint interrupt sources. */
                CNSL_ARB_EP_BASE.arbEp[ep].epSr = epStatus;
            }

            ++ep;
            arbIntrStatus >>= 1u;
        }

        /* `#START ARB_END_USER_CODE` Place your code here */

        /* `#END` */

    #ifdef CNSL_ARB_ISR_EXIT_CALLBACK
        CNSL_ARB_ISR_ExitCallback();
    #endif /* (CNSL_ARB_ISR_EXIT_CALLBACK) */
    }

#endif /*  (CNSL_ARB_ISR_ACTIVE && CNSL_EP_MANAGEMENT_DMA) */


#if (CNSL_EP_MANAGEMENT_DMA_AUTO)
#if (CY_PSOC4)

    /******************************************************************************
    * Function Name: CNSL_EPxDmaDone
    ***************************************************************************//**
    *
    * \internal
    *  Endpoint  DMA Done Interrupt Service Routine basic function .
    *  
    *  \param dmaCh
    *  number of DMA channel
    *  
    *  \param ep
    *  number of USB end point
    *  
    *  \param dmaDone
    *  transfer completion flag
    *  
    *  \return
    *   updated transfer completion flag
    *
    ******************************************************************************/
    CY_INLINE static void CNSL_EPxDmaDone(uint8 dmaCh, uint8 ep)
    {
        uint32 nextAddr;

        /* Manage data elements which remain to transfer. */
        if (0u != CNSL_DmaEpBurstCnt[ep])
        {
            if(CNSL_DmaEpBurstCnt[ep] <= 2u)
            {
                /* Adjust length of last burst. */
                CNSL_CyDmaSetNumDataElements(dmaCh,
                                                    ((uint32) CNSL_DmaEpLastBurstEl[ep] >> CNSL_DMA_DESCR_SHIFT),
                                                    ((uint32) CNSL_DmaEpLastBurstEl[ep] &  CNSL_DMA_BURST_BYTES_MASK));
            }
            

            /* Advance source for input endpoint or destination for output endpoint. */
            if (0u != (CNSL_EP[ep].addr & CNSL_DIR_IN))
            {
                /* Change source for descriptor 0. */
                nextAddr = (uint32) CNSL_CyDmaGetSrcAddress(dmaCh, CNSL_DMA_DESCR0);
                nextAddr += (2u * CNSL_DMA_BYTES_PER_BURST);
                CNSL_CyDmaSetSrcAddress(dmaCh, CNSL_DMA_DESCR0, (void *) nextAddr);

                /* Change source for descriptor 1. */
                nextAddr += CNSL_DMA_BYTES_PER_BURST;
                CNSL_CyDmaSetSrcAddress(dmaCh, CNSL_DMA_DESCR1, (void *) nextAddr);
            }
            else
            {
                /* Change destination for descriptor 0. */
                nextAddr  = (uint32) CNSL_CyDmaGetDstAddress(dmaCh, CNSL_DMA_DESCR0);
                nextAddr += (2u * CNSL_DMA_BYTES_PER_BURST);
                CNSL_CyDmaSetDstAddress(dmaCh, CNSL_DMA_DESCR0, (void *) nextAddr);

                /* Change destination for descriptor 1. */
                nextAddr += CNSL_DMA_BYTES_PER_BURST;
                CNSL_CyDmaSetDstAddress(dmaCh, CNSL_DMA_DESCR1, (void *) nextAddr);
            }

            /* Enable DMA to execute transfer as it was disabled because there were no valid descriptor. */
            CNSL_CyDmaValidateDescriptor(dmaCh, CNSL_DMA_DESCR0);
            
            --CNSL_DmaEpBurstCnt[ep];
            if (0u != CNSL_DmaEpBurstCnt[ep])
            {
                CNSL_CyDmaValidateDescriptor(dmaCh, CNSL_DMA_DESCR1);
                --CNSL_DmaEpBurstCnt[ep];
            }
            
            CNSL_CyDmaChEnable (dmaCh);
            CNSL_CyDmaTriggerIn(CNSL_DmaReqOut[ep]);
        }
        else
        {
            /* No data to transfer. False DMA trig. Ignore.  */
        }

    }

    #if (CNSL_DMA1_ACTIVE)
        /******************************************************************************
        * Function Name: CNSL_EP1_DMA_DONE_ISR
        ***************************************************************************//**
        *
        *  Endpoint 1 DMA Done Interrupt Service Routine.
        *
        *
        ******************************************************************************/
        void CNSL_EP1_DMA_DONE_ISR(void)
        {

            CNSL_EPxDmaDone((uint8)CNSL_EP1_DMA_CH,
                                                  CNSL_EP1);
                
        }
    #endif /* (CNSL_DMA1_ACTIVE) */


    #if (CNSL_DMA2_ACTIVE)
        /******************************************************************************
        * Function Name: CNSL_EP2_DMA_DONE_ISR
        ***************************************************************************//**
        *
        *  Endpoint 2 DMA Done Interrupt Service Routine.
        *
        *
        ******************************************************************************/
        void CNSL_EP2_DMA_DONE_ISR(void)
        {

            CNSL_EPxDmaDone((uint8)CNSL_EP2_DMA_CH,
                                                  CNSL_EP2);
        }
    #endif /* (CNSL_DMA2_ACTIVE) */


    #if (CNSL_DMA3_ACTIVE)
        /******************************************************************************
        * Function Name: CNSL_EP3_DMA_DONE_ISR
        ***************************************************************************//**
        *
        *  Endpoint 3 DMA Done Interrupt Service Routine.
        *
        *
        ******************************************************************************/
        void CNSL_EP3_DMA_DONE_ISR(void)
        {

            CNSL_EPxDmaDone((uint8)CNSL_EP3_DMA_CH,
                                                  CNSL_EP3);
        }
    #endif /* (CNSL_DMA3_ACTIVE) */


    #if (CNSL_DMA4_ACTIVE)
        /******************************************************************************
        * Function Name: CNSL_EP4_DMA_DONE_ISR
        ***************************************************************************//**
        *
        *  Endpoint 4 DMA Done Interrupt Service Routine.
        *
        *
        ******************************************************************************/
        void CNSL_EP4_DMA_DONE_ISR(void)
        {

            CNSL_EPxDmaDone((uint8)CNSL_EP4_DMA_CH,
                                                  CNSL_EP4);
        }
    #endif /* (CNSL_DMA4_ACTIVE) */


    #if (CNSL_DMA5_ACTIVE)
        /******************************************************************************
        * Function Name: CNSL_EP5_DMA_DONE_ISR
        ***************************************************************************//**
        *
        *  Endpoint 5 DMA Done Interrupt Service Routine.
        *
        *
        ******************************************************************************/
        void CNSL_EP5_DMA_DONE_ISR(void)
        {

            CNSL_EPxDmaDone((uint8)CNSL_EP5_DMA_CH,
                                                  CNSL_EP5);
        }
    #endif /* (CNSL_DMA5_ACTIVE) */


    #if (CNSL_DMA6_ACTIVE)
        /******************************************************************************
        * Function Name: CNSL_EP6_DMA_DONE_ISR
        ***************************************************************************//**
        *
        *  Endpoint 6 DMA Done Interrupt Service Routine.
        *
        *
        ******************************************************************************/
        void CNSL_EP6_DMA_DONE_ISR(void)
        {

            CNSL_EPxDmaDone((uint8)CNSL_EP6_DMA_CH,
                                                  CNSL_EP6);
        }
    #endif /* (CNSL_DMA6_ACTIVE) */


    #if (CNSL_DMA7_ACTIVE)
        /******************************************************************************
        * Function Name: CNSL_EP7_DMA_DONE_ISR
        ***************************************************************************//**
        *
        *  Endpoint 7 DMA Done Interrupt Service Routine.
        *
        *
        ******************************************************************************/
        void CNSL_EP7_DMA_DONE_ISR(void)
        {

            CNSL_EPxDmaDone((uint8)CNSL_EP7_DMA_CH,
                                                  CNSL_EP7);
        }
    #endif /* (CNSL_DMA7_ACTIVE) */


    #if (CNSL_DMA8_ACTIVE)
        /******************************************************************************
        * Function Name: CNSL_EP8_DMA_DONE_ISR
        ***************************************************************************//**
        *
        *  Endpoint 8 DMA Done Interrupt Service Routine.
        *
        *
        ******************************************************************************/
        void CNSL_EP8_DMA_DONE_ISR(void)
        {

            CNSL_EPxDmaDone((uint8)CNSL_EP8_DMA_CH,
                                                  CNSL_EP8);
        }
    #endif /* (CNSL_DMA8_ACTIVE) */


#else
    #if (CNSL_EP_DMA_AUTO_OPT == 0u)
        /******************************************************************************
        * Function Name: CNSL_EP_DMA_DONE_ISR
        ***************************************************************************//**
        *
        *  DMA Done Interrupt Service Routine.
        *
        *
        ******************************************************************************/
        CY_ISR(CNSL_EP_DMA_DONE_ISR)
        {
            uint8 int8Status;
            uint8 int17Status;
            uint8 ep_status;
            uint8 ep = CNSL_EP1;

        #ifdef CNSL_EP_DMA_DONE_ISR_ENTRY_CALLBACK
            CNSL_EP_DMA_DONE_ISR_EntryCallback();
        #endif /* (CNSL_EP_DMA_DONE_ISR_ENTRY_CALLBACK) */

            /* `#START EP_DMA_DONE_BEGIN_USER_CODE` Place your code here */

            /* `#END` */

            /* Read clear on read status register with EP source of interrupt. */
            int17Status = CNSL_EP17_DMA_Done_SR_Read() & CNSL_EP17_SR_MASK;
            int8Status  = CNSL_EP8_DMA_Done_SR_Read()  & CNSL_EP8_SR_MASK;

            while (int8Status != 0u)
            {
                while (int17Status != 0u)
                {
                    if ((int17Status & 1u) != 0u)  /* If EpX interrupt present. */
                    {
                        /* Read Endpoint Status Register. */
                        ep_status = CNSL_ARB_EP_BASE.arbEp[ep].epSr;

                        if ((0u == (ep_status & CNSL_ARB_EPX_SR_IN_BUF_FULL)) &&
                            (0u ==CNSL_inBufFull[ep]))
                        {
                            /* `#START EP_DMA_DONE_USER_CODE` Place your code here */

                            /* `#END` */

                        #ifdef CNSL_EP_DMA_DONE_ISR_CALLBACK
                            CNSL_EP_DMA_DONE_ISR_Callback();
                        #endif /* (CNSL_EP_DMA_DONE_ISR_CALLBACK) */

                            /* Transfer again 2 last bytes into pre-fetch endpoint area. */
                            CNSL_ARB_EP_BASE.arbEp[ep].rwWaMsb = 0u;
                            CNSL_ARB_EP_BASE.arbEp[ep].rwWa = (CNSL_DMA_BYTES_PER_BURST * ep) - CNSL_DMA_BYTES_REPEAT;
                            CNSL_LoadNextInEP(ep, 1u);

                            /* Set Data ready status to generate DMA request. */
                            CNSL_ARB_EP_BASE.arbEp[ep].epCfg |= CNSL_ARB_EPX_CFG_IN_DATA_RDY;
                        }
                    }

                    ep++;
                    int17Status >>= 1u;
                }

                int8Status >>= 1u;

                if (int8Status != 0u)
                {
                    /* Prepare pointer for EP8. */
                    ep = CNSL_EP8;
                    int17Status = int8Status & 0x01u;
                }
            }

            /* `#START EP_DMA_DONE_END_USER_CODE` Place your code here */

            /* `#END` */

    #ifdef CNSL_EP_DMA_DONE_ISR_EXIT_CALLBACK
        CNSL_EP_DMA_DONE_ISR_ExitCallback();
    #endif /* (CNSL_EP_DMA_DONE_ISR_EXIT_CALLBACK) */
        }
    #endif /* (CNSL_EP_DMA_AUTO_OPT == 0u) */
#endif /* (CY_PSOC4) */
#endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO) */


#if (CY_PSOC4)
    /***************************************************************************
    * Function Name: CNSL_IntrHandler
    ************************************************************************//**
    *
    *   Interrupt handler for Hi/Mid/Low ISRs.
    *
    *  regCause - The cause register of interrupt. One of the three variants:
    *       CNSL_INTR_CAUSE_LO_REG - Low interrupts.
    *       CNSL_INTR_CAUSE_MED_REG - Med interrupts.
    *       CNSL_INTR_CAUSE_HI_REG - - High interrupts.
    *
    *
    ***************************************************************************/
    CY_INLINE static void CNSL_IntrHandler(uint32 intrCause)
    {
        /* Array of pointers to component interrupt handlers. */
        static const cyisraddress CNSL_isrCallbacks[] =
        {

        };

        uint32 cbIdx = 0u;

        /* Check arbiter interrupt source first. */
        if (0u != (intrCause & CNSL_INTR_CAUSE_ARB_INTR))
        {
            CNSL_isrCallbacks[CNSL_ARB_EP_INTR_NUM]();
        }

        /* Check all other interrupt sources (except arbiter and resume). */
        intrCause = (intrCause  & CNSL_INTR_CAUSE_CTRL_INTR_MASK) |
                    ((intrCause & CNSL_INTR_CAUSE_EP1_8_INTR_MASK) >>
                                  CNSL_INTR_CAUSE_EP_INTR_SHIFT);

        /* Call interrupt handlers for active interrupt sources. */
        while (0u != intrCause)
        {
            if (0u != (intrCause & 0x1u))
            {
                 CNSL_isrCallbacks[cbIdx]();
            }

            intrCause >>= 1u;
            ++cbIdx;
        }
    }


    /***************************************************************************
    * Function Name: CNSL_INTR_HI_ISR
    ************************************************************************//**
    *
    *   Interrupt Service Routine for the high group of the interrupt sources.
    *
    *
    ***************************************************************************/
    CY_ISR(CNSL_INTR_HI_ISR)
    {
        CNSL_IntrHandler(CNSL_INTR_CAUSE_HI_REG);
    }

    /***************************************************************************
    * Function Name: CNSL_INTR_MED_ISR
    ************************************************************************//**
    *
    *   Interrupt Service Routine for the medium group of the interrupt sources.
    *
    *
    ***************************************************************************/
    CY_ISR(CNSL_INTR_MED_ISR)
    {
       CNSL_IntrHandler(CNSL_INTR_CAUSE_MED_REG);
    }

    /***************************************************************************
    * Function Name: CNSL_INTR_LO_ISR
    ************************************************************************//**
    *
    *   Interrupt Service Routine for the low group of the interrupt sources.
    *
    *
    ***************************************************************************/
    CY_ISR(CNSL_INTR_LO_ISR)
    {
        CNSL_IntrHandler(CNSL_INTR_CAUSE_LO_REG);
    }
#endif /* (CY_PSOC4) */


/* [] END OF FILE */
