/***************************************************************************//**
* \file .h
* \version 3.20
*
* \brief
*  This file provides private function prototypes and constants for the 
*  USBFS component. It is not intended to be used in the user project.
*
********************************************************************************
* \copyright
* Copyright 2013-2016, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_USBFS_CNSL_pvt_H)
#define CY_USBFS_CNSL_pvt_H

#include "CNSL.h"
   
#ifdef CNSL_ENABLE_AUDIO_CLASS
    #include "CNSL_audio.h"
#endif /* CNSL_ENABLE_AUDIO_CLASS */

#ifdef CNSL_ENABLE_CDC_CLASS
    #include "CNSL_cdc.h"
#endif /* CNSL_ENABLE_CDC_CLASS */

#if (CNSL_ENABLE_MIDI_CLASS)
    #include "CNSL_midi.h"
#endif /* (CNSL_ENABLE_MIDI_CLASS) */

#if (CNSL_ENABLE_MSC_CLASS)
    #include "CNSL_msc.h"
#endif /* (CNSL_ENABLE_MSC_CLASS) */

#if (CNSL_EP_MANAGEMENT_DMA)
    #if (CY_PSOC4)
        #include <CyDMA.h>
    #else
        #include <CyDmac.h>
        #if ((CNSL_EP_MANAGEMENT_DMA_AUTO) && (CNSL_EP_DMA_AUTO_OPT == 0u))
            #include "CNSL_EP_DMA_Done_isr.h"
            #include "CNSL_EP8_DMA_Done_SR.h"
            #include "CNSL_EP17_DMA_Done_SR.h"
        #endif /* ((CNSL_EP_MANAGEMENT_DMA_AUTO) && (CNSL_EP_DMA_AUTO_OPT == 0u)) */
    #endif /* (CY_PSOC4) */
#endif /* (CNSL_EP_MANAGEMENT_DMA) */

#if (CNSL_DMA1_ACTIVE)
    #include "CNSL_ep1_dma.h"
    #define CNSL_EP1_DMA_CH     (CNSL_ep1_dma_CHANNEL)
#endif /* (CNSL_DMA1_ACTIVE) */

#if (CNSL_DMA2_ACTIVE)
    #include "CNSL_ep2_dma.h"
    #define CNSL_EP2_DMA_CH     (CNSL_ep2_dma_CHANNEL)
#endif /* (CNSL_DMA2_ACTIVE) */

#if (CNSL_DMA3_ACTIVE)
    #include "CNSL_ep3_dma.h"
    #define CNSL_EP3_DMA_CH     (CNSL_ep3_dma_CHANNEL)
#endif /* (CNSL_DMA3_ACTIVE) */

#if (CNSL_DMA4_ACTIVE)
    #include "CNSL_ep4_dma.h"
    #define CNSL_EP4_DMA_CH     (CNSL_ep4_dma_CHANNEL)
#endif /* (CNSL_DMA4_ACTIVE) */

#if (CNSL_DMA5_ACTIVE)
    #include "CNSL_ep5_dma.h"
    #define CNSL_EP5_DMA_CH     (CNSL_ep5_dma_CHANNEL)
#endif /* (CNSL_DMA5_ACTIVE) */

#if (CNSL_DMA6_ACTIVE)
    #include "CNSL_ep6_dma.h"
    #define CNSL_EP6_DMA_CH     (CNSL_ep6_dma_CHANNEL)
#endif /* (CNSL_DMA6_ACTIVE) */

#if (CNSL_DMA7_ACTIVE)
    #include "CNSL_ep7_dma.h"
    #define CNSL_EP7_DMA_CH     (CNSL_ep7_dma_CHANNEL)
#endif /* (CNSL_DMA7_ACTIVE) */

#if (CNSL_DMA8_ACTIVE)
    #include "CNSL_ep8_dma.h"
    #define CNSL_EP8_DMA_CH     (CNSL_ep8_dma_CHANNEL)
#endif /* (CNSL_DMA8_ACTIVE) */


/***************************************
*     Private Variables
***************************************/

/* Generated external references for descriptors. */
extern const uint8 CYCODE CNSL_DEVICE0_DESCR[18u];
extern const uint8 CYCODE CNSL_DEVICE0_CONFIGURATION0_DESCR[67u];
extern const T_CNSL_EP_SETTINGS_BLOCK CYCODE CNSL_DEVICE0_CONFIGURATION0_EP_SETTINGS_TABLE[3u];
extern const uint8 CYCODE CNSL_DEVICE0_CONFIGURATION0_INTERFACE_CLASS[2u];
extern const T_CNSL_LUT CYCODE CNSL_DEVICE0_CONFIGURATION0_TABLE[5u];
extern const T_CNSL_LUT CYCODE CNSL_DEVICE0_TABLE[3u];
extern const T_CNSL_LUT CYCODE CNSL_TABLE[1u];
extern const uint8 CYCODE CNSL_SN_STRING_DESCRIPTOR[2];
extern const uint8 CYCODE CNSL_STRING_DESCRIPTORS[159u];


extern const uint8 CYCODE CNSL_MSOS_DESCRIPTOR[CNSL_MSOS_DESCRIPTOR_LENGTH];
extern const uint8 CYCODE CNSL_MSOS_CONFIGURATION_DESCR[CNSL_MSOS_CONF_DESCR_LENGTH];
#if defined(CNSL_ENABLE_IDSN_STRING)
    extern uint8 CNSL_idSerialNumberStringDescriptor[CNSL_IDSN_DESCR_LENGTH];
#endif /* (CNSL_ENABLE_IDSN_STRING) */

extern volatile uint8 CNSL_interfaceNumber;
extern volatile uint8 CNSL_interfaceSetting[CNSL_MAX_INTERFACES_NUMBER];
extern volatile uint8 CNSL_interfaceSettingLast[CNSL_MAX_INTERFACES_NUMBER];
extern volatile uint8 CNSL_deviceAddress;
extern volatile uint8 CNSL_interfaceStatus[CNSL_MAX_INTERFACES_NUMBER];
extern const uint8 CYCODE *CNSL_interfaceClass;

extern volatile T_CNSL_EP_CTL_BLOCK CNSL_EP[CNSL_MAX_EP];
extern volatile T_CNSL_TD CNSL_currentTD;

#if (CNSL_EP_MANAGEMENT_DMA)
    #if (CY_PSOC4)
        extern const uint8 CNSL_DmaChan[CNSL_MAX_EP];
    #else
        extern uint8 CNSL_DmaChan[CNSL_MAX_EP];
        extern uint8 CNSL_DmaTd  [CNSL_MAX_EP];
    #endif /* (CY_PSOC4) */
#endif /* (CNSL_EP_MANAGEMENT_DMA) */

#if (CNSL_EP_MANAGEMENT_DMA_AUTO)
#if (CY_PSOC4)
    extern uint8  CNSL_DmaEpBurstCnt   [CNSL_MAX_EP];
    extern uint8  CNSL_DmaEpLastBurstEl[CNSL_MAX_EP];

    extern uint8  CNSL_DmaEpBurstCntBackup  [CNSL_MAX_EP];
    extern uint32 CNSL_DmaEpBufferAddrBackup[CNSL_MAX_EP];
    
    extern const uint8 CNSL_DmaReqOut     [CNSL_MAX_EP];    
    extern const uint8 CNSL_DmaBurstEndOut[CNSL_MAX_EP];
#else
    #if (CNSL_EP_DMA_AUTO_OPT == 0u)
        extern uint8 CNSL_DmaNextTd[CNSL_MAX_EP];
        extern volatile uint16 CNSL_inLength [CNSL_MAX_EP];
        extern volatile uint8  CNSL_inBufFull[CNSL_MAX_EP];
        extern const uint8 CNSL_epX_TD_TERMOUT_EN[CNSL_MAX_EP];
        extern const uint8 *CNSL_inDataPointer[CNSL_MAX_EP];
    #endif /* (CNSL_EP_DMA_AUTO_OPT == 0u) */
#endif /* CY_PSOC4 */
#endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO) */

extern volatile uint8 CNSL_ep0Toggle;
extern volatile uint8 CNSL_lastPacketSize;
extern volatile uint8 CNSL_ep0Mode;
extern volatile uint8 CNSL_ep0Count;
extern volatile uint16 CNSL_transferByteCount;


/***************************************
*     Private Function Prototypes
***************************************/
void  CNSL_ReInitComponent(void)            ;
void  CNSL_HandleSetup(void)                ;
void  CNSL_HandleIN(void)                   ;
void  CNSL_HandleOUT(void)                  ;
void  CNSL_LoadEP0(void)                    ;
uint8 CNSL_InitControlRead(void)            ;
uint8 CNSL_InitControlWrite(void)           ;
void  CNSL_ControlReadDataStage(void)       ;
void  CNSL_ControlReadStatusStage(void)     ;
void  CNSL_ControlReadPrematureStatus(void) ;
uint8 CNSL_InitControlWrite(void)           ;
uint8 CNSL_InitZeroLengthControlTransfer(void) ;
void  CNSL_ControlWriteDataStage(void)      ;
void  CNSL_ControlWriteStatusStage(void)    ;
void  CNSL_ControlWritePrematureStatus(void);
uint8 CNSL_InitNoDataControlTransfer(void)  ;
void  CNSL_NoDataControlStatusStage(void)   ;
void  CNSL_InitializeStatusBlock(void)      ;
void  CNSL_UpdateStatusBlock(uint8 completionCode) ;
uint8 CNSL_DispatchClassRqst(void)          ;

void CNSL_Config(uint8 clearAltSetting) ;
void CNSL_ConfigAltChanged(void)        ;
void CNSL_ConfigReg(void)               ;
void CNSL_EpStateInit(void)             ;


const T_CNSL_LUT CYCODE *CNSL_GetConfigTablePtr(uint8 confIndex);
const T_CNSL_LUT CYCODE *CNSL_GetDeviceTablePtr(void)           ;
#if (CNSL_BOS_ENABLE)
    const T_CNSL_LUT CYCODE *CNSL_GetBOSPtr(void)               ;
#endif /* (CNSL_BOS_ENABLE) */
const uint8 CYCODE *CNSL_GetInterfaceClassTablePtr(void)                    ;
uint8 CNSL_ClearEndpointHalt(void)                                          ;
uint8 CNSL_SetEndpointHalt(void)                                            ;
uint8 CNSL_ValidateAlternateSetting(void)                                   ;

void CNSL_SaveConfig(void)      ;
void CNSL_RestoreConfig(void)   ;

#if (CY_PSOC3 || CY_PSOC5LP)
    #if (CNSL_EP_MANAGEMENT_DMA_AUTO && (CNSL_EP_DMA_AUTO_OPT == 0u))
        void CNSL_LoadNextInEP(uint8 epNumber, uint8 mode)  ;
    #endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO && (CNSL_EP_DMA_AUTO_OPT == 0u)) */
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

#if defined(CNSL_ENABLE_IDSN_STRING)
    void CNSL_ReadDieID(uint8 descr[])  ;
#endif /* CNSL_ENABLE_IDSN_STRING */

#if defined(CNSL_ENABLE_HID_CLASS)
    uint8 CNSL_DispatchHIDClassRqst(void) ;
#endif /* (CNSL_ENABLE_HID_CLASS) */

#if defined(CNSL_ENABLE_AUDIO_CLASS)
    uint8 CNSL_DispatchAUDIOClassRqst(void) ;
#endif /* (CNSL_ENABLE_AUDIO_CLASS) */

#if defined(CNSL_ENABLE_CDC_CLASS)
    uint8 CNSL_DispatchCDCClassRqst(void) ;
#endif /* (CNSL_ENABLE_CDC_CLASS) */

#if (CNSL_ENABLE_MSC_CLASS)
    #if (CNSL_HANDLE_MSC_REQUESTS)
        uint8 CNSL_DispatchMSCClassRqst(void) ;
    #endif /* (CNSL_HANDLE_MSC_REQUESTS) */
#endif /* (CNSL_ENABLE_MSC_CLASS */

CY_ISR_PROTO(CNSL_EP_0_ISR);
CY_ISR_PROTO(CNSL_BUS_RESET_ISR);

#if (CNSL_SOF_ISR_ACTIVE)
    CY_ISR_PROTO(CNSL_SOF_ISR);
#endif /* (CNSL_SOF_ISR_ACTIVE) */

#if (CNSL_EP1_ISR_ACTIVE)
    CY_ISR_PROTO(CNSL_EP_1_ISR);
#endif /* (CNSL_EP1_ISR_ACTIVE) */

#if (CNSL_EP2_ISR_ACTIVE)
    CY_ISR_PROTO(CNSL_EP_2_ISR);
#endif /* (CNSL_EP2_ISR_ACTIVE) */

#if (CNSL_EP3_ISR_ACTIVE)
    CY_ISR_PROTO(CNSL_EP_3_ISR);
#endif /* (CNSL_EP3_ISR_ACTIVE) */

#if (CNSL_EP4_ISR_ACTIVE)
    CY_ISR_PROTO(CNSL_EP_4_ISR);
#endif /* (CNSL_EP4_ISR_ACTIVE) */

#if (CNSL_EP5_ISR_ACTIVE)
    CY_ISR_PROTO(CNSL_EP_5_ISR);
#endif /* (CNSL_EP5_ISR_ACTIVE) */

#if (CNSL_EP6_ISR_ACTIVE)
    CY_ISR_PROTO(CNSL_EP_6_ISR);
#endif /* (CNSL_EP6_ISR_ACTIVE) */

#if (CNSL_EP7_ISR_ACTIVE)
    CY_ISR_PROTO(CNSL_EP_7_ISR);
#endif /* (CNSL_EP7_ISR_ACTIVE) */

#if (CNSL_EP8_ISR_ACTIVE)
    CY_ISR_PROTO(CNSL_EP_8_ISR);
#endif /* (CNSL_EP8_ISR_ACTIVE) */

#if (CNSL_EP_MANAGEMENT_DMA)
    CY_ISR_PROTO(CNSL_ARB_ISR);
#endif /* (CNSL_EP_MANAGEMENT_DMA) */

#if (CNSL_DP_ISR_ACTIVE)
    CY_ISR_PROTO(CNSL_DP_ISR);
#endif /* (CNSL_DP_ISR_ACTIVE) */

#if (CY_PSOC4)
    CY_ISR_PROTO(CNSL_INTR_HI_ISR);
    CY_ISR_PROTO(CNSL_INTR_MED_ISR);
    CY_ISR_PROTO(CNSL_INTR_LO_ISR);
    #if (CNSL_LPM_ACTIVE)
        CY_ISR_PROTO(CNSL_LPM_ISR);
    #endif /* (CNSL_LPM_ACTIVE) */
#endif /* (CY_PSOC4) */

#if (CNSL_EP_MANAGEMENT_DMA_AUTO)
#if (CY_PSOC4)
    #if (CNSL_DMA1_ACTIVE)
        void CNSL_EP1_DMA_DONE_ISR(void);
    #endif /* (CNSL_DMA1_ACTIVE) */

    #if (CNSL_DMA2_ACTIVE)
        void CNSL_EP2_DMA_DONE_ISR(void);
    #endif /* (CNSL_DMA2_ACTIVE) */

    #if (CNSL_DMA3_ACTIVE)
        void CNSL_EP3_DMA_DONE_ISR(void);
    #endif /* (CNSL_DMA3_ACTIVE) */

    #if (CNSL_DMA4_ACTIVE)
        void CNSL_EP4_DMA_DONE_ISR(void);
    #endif /* (CNSL_DMA4_ACTIVE) */

    #if (CNSL_DMA5_ACTIVE)
        void CNSL_EP5_DMA_DONE_ISR(void);
    #endif /* (CNSL_DMA5_ACTIVE) */

    #if (CNSL_DMA6_ACTIVE)
        void CNSL_EP6_DMA_DONE_ISR(void);
    #endif /* (CNSL_DMA6_ACTIVE) */

    #if (CNSL_DMA7_ACTIVE)
        void CNSL_EP7_DMA_DONE_ISR(void);
    #endif /* (CNSL_DMA7_ACTIVE) */

    #if (CNSL_DMA8_ACTIVE)
        void CNSL_EP8_DMA_DONE_ISR(void);
    #endif /* (CNSL_DMA8_ACTIVE) */

#else
    #if (CNSL_EP_DMA_AUTO_OPT == 0u)
        CY_ISR_PROTO(CNSL_EP_DMA_DONE_ISR);
    #endif /* (CNSL_EP_DMA_AUTO_OPT == 0u) */
#endif /* (CY_PSOC4) */
#endif /* (CNSL_EP_MANAGEMENT_DMA_AUTO) */


/***************************************
*         Request Handlers
***************************************/

uint8 CNSL_HandleStandardRqst(void) ;
uint8 CNSL_DispatchClassRqst(void)  ;
uint8 CNSL_HandleVendorRqst(void)   ;


/***************************************
*    HID Internal references
***************************************/

#if defined(CNSL_ENABLE_HID_CLASS)
    void CNSL_FindReport(void)            ;
    void CNSL_FindReportDescriptor(void)  ;
    void CNSL_FindHidClassDecriptor(void) ;
#endif /* CNSL_ENABLE_HID_CLASS */


/***************************************
*    MIDI Internal references
***************************************/

#if defined(CNSL_ENABLE_MIDI_STREAMING)
    void CNSL_MIDI_IN_EP_Service(void)  ;
#endif /* (CNSL_ENABLE_MIDI_STREAMING) */


/***************************************
*    CDC Internal references
***************************************/

#if defined(CNSL_ENABLE_CDC_CLASS)

    typedef struct
    {
        uint8  bRequestType;
        uint8  bNotification;
        uint8  wValue;
        uint8  wValueMSB;
        uint8  wIndex;
        uint8  wIndexMSB;
        uint8  wLength;
        uint8  wLengthMSB;
        uint8  wSerialState;
        uint8  wSerialStateMSB;
    } t_CNSL_cdc_notification;

    uint8 CNSL_GetInterfaceComPort(uint8 interface) ;
    uint8 CNSL_Cdc_EpInit( const T_CNSL_EP_SETTINGS_BLOCK CYCODE *pEP, uint8 epNum, uint8 cdcComNums) ;

    extern volatile uint8  CNSL_cdc_dataInEpList[CNSL_MAX_MULTI_COM_NUM];
    extern volatile uint8  CNSL_cdc_dataOutEpList[CNSL_MAX_MULTI_COM_NUM];
    extern volatile uint8  CNSL_cdc_commInEpList[CNSL_MAX_MULTI_COM_NUM];
#endif /* (CNSL_ENABLE_CDC_CLASS) */


#endif /* CY_USBFS_CNSL_pvt_H */


/* [] END OF FILE */
