/***************************************************************************//**
* \file CNSL_vnd.c
* \version 3.20
*
* \brief
*  This file contains the  USB vendor request handler.
*
********************************************************************************
* \copyright
* Copyright 2008-2016, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "CNSL_pvt.h"


#if(CNSL_EXTERN_VND == CNSL_FALSE)

/***************************************
* Vendor Specific Declarations
***************************************/

/* `#START VENDOR_SPECIFIC_DECLARATIONS` Place your declaration here */

/* `#END` */


/*******************************************************************************
* Function Name: CNSL_HandleVendorRqst
****************************************************************************//**
*
*  This routine provide users with a method to implement vendor specific
*  requests.
*
*  To implement vendor specific requests, add your code in this function to
*  decode and disposition the request.  If the request is handled, your code
*  must set the variable "requestHandled" to TRUE, indicating that the
*  request has been handled.
*
* \return
*  requestHandled.
*
* \reentrant
*  No.
*
*******************************************************************************/
uint8 CNSL_HandleVendorRqst(void) 
{
    uint8 requestHandled = CNSL_FALSE;

    /* Check request direction: D2H or H2D. */
    if (0u != (CNSL_bmRequestTypeReg & CNSL_RQST_DIR_D2H))
    {
        /* Handle direction from device to host. */
        
        switch (CNSL_bRequestReg)
        {
            case CNSL_GET_EXTENDED_CONFIG_DESCRIPTOR:
            #if defined(CNSL_ENABLE_MSOS_STRING)
                CNSL_currentTD.pData = (volatile uint8 *) &CNSL_MSOS_CONFIGURATION_DESCR[0u];
                CNSL_currentTD.count = CNSL_MSOS_CONFIGURATION_DESCR[0u];
                requestHandled  = CNSL_InitControlRead();
            #endif /* (CNSL_ENABLE_MSOS_STRING) */
                break;
            
            default:
                break;
        }
    }

    /* `#START VENDOR_SPECIFIC_CODE` Place your vendor specific request here */

    /* `#END` */

#ifdef CNSL_HANDLE_VENDOR_RQST_CALLBACK
    if (CNSL_FALSE == requestHandled)
    {
        requestHandled = CNSL_HandleVendorRqst_Callback();
    }
#endif /* (CNSL_HANDLE_VENDOR_RQST_CALLBACK) */

    return (requestHandled);
}


/*******************************************************************************
* Additional user functions supporting Vendor Specific Requests
********************************************************************************/

/* `#START VENDOR_SPECIFIC_FUNCTIONS` Place any additional functions here */

/* `#END` */


#endif /* CNSL_EXTERN_VND */


/* [] END OF FILE */
