/*******************************************************************************
* File Name: NON_VOL.h
* Version 3.0
*
*  Description:
*   Provides the function definitions for the EEPROM APIs.
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_EEPROM_NON_VOL_H)
#define CY_EEPROM_NON_VOL_H

#include "cydevice_trm.h"
#include "CyFlash.h"

#if !defined(CY_PSOC5LP)
    #error Component EEPROM_v3_0 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void NON_VOL_Enable(void) ;
void NON_VOL_Start(void) ;
void NON_VOL_Stop (void) ;
cystatus NON_VOL_WriteByte(uint8 dataByte, uint16 address) \
                                            ;
uint8 NON_VOL_ReadByte(uint16 address) ;
uint8 NON_VOL_UpdateTemperature(void) ;
cystatus NON_VOL_EraseSector(uint8 sectorNumber) ;
cystatus NON_VOL_Write(const uint8 * rowData, uint8 rowNumber) ;
cystatus NON_VOL_StartWrite(const uint8 * rowData, uint8 rowNumber) \
                                                ;
cystatus NON_VOL_StartErase(uint8 sectorNumber) ;
cystatus NON_VOL_Query(void) ;
cystatus NON_VOL_ByteWritePos(uint8 dataByte, uint8 rowNumber, uint8 byteNumber) \
                                                ;


/****************************************
*           API Constants
****************************************/

#define NON_VOL_EEPROM_SIZE            CYDEV_EE_SIZE
#define NON_VOL_SPC_BYTE_WRITE_SIZE    (0x01u)

#define NON_VOL_SECTORS_NUMBER         (CYDEV_EE_SIZE / CYDEV_EEPROM_SECTOR_SIZE)

#define NON_VOL_AHB_REQ_SHIFT          (0x00u)
#define NON_VOL_AHB_REQ                ((uint8)(0x01u << NON_VOL_AHB_REQ_SHIFT))
#define NON_VOL_AHB_ACK_SHIFT          (0x01u)
#define NON_VOL_AHB_ACK_MASK           ((uint8)(0x01u << NON_VOL_AHB_ACK_SHIFT))


/***************************************
* Registers
***************************************/
#define NON_VOL_SPC_EE_SCR_REG                 (*(reg8 *) CYREG_SPC_EE_SCR)
#define NON_VOL_SPC_EE_SCR_PTR                 ( (reg8 *) CYREG_SPC_EE_SCR)



/***************************************
* The following code is DEPRECATED and
* should not be used in new projects.
***************************************/
#define NON_VOL_ByteWrite                  NON_VOL_ByteWritePos
#define NON_VOL_QueryWrite                 NON_VOL_Query

#endif /* CY_EEPROM_NON_VOL_H */

/* [] END OF FILE */
