/*******************************************************************************
* File Name: TICK_TOCK.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_TICK_TOCK_H)
#define CY_CLOCK_TICK_TOCK_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_20 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void TICK_TOCK_Start(void) ;
void TICK_TOCK_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void TICK_TOCK_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void TICK_TOCK_StandbyPower(uint8 state) ;
void TICK_TOCK_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 TICK_TOCK_GetDividerRegister(void) ;
void TICK_TOCK_SetModeRegister(uint8 modeBitMask) ;
void TICK_TOCK_ClearModeRegister(uint8 modeBitMask) ;
uint8 TICK_TOCK_GetModeRegister(void) ;
void TICK_TOCK_SetSourceRegister(uint8 clkSource) ;
uint8 TICK_TOCK_GetSourceRegister(void) ;
#if defined(TICK_TOCK__CFG3)
void TICK_TOCK_SetPhaseRegister(uint8 clkPhase) ;
uint8 TICK_TOCK_GetPhaseRegister(void) ;
#endif /* defined(TICK_TOCK__CFG3) */

#define TICK_TOCK_Enable()                       TICK_TOCK_Start()
#define TICK_TOCK_Disable()                      TICK_TOCK_Stop()
#define TICK_TOCK_SetDivider(clkDivider)         TICK_TOCK_SetDividerRegister(clkDivider, 1u)
#define TICK_TOCK_SetDividerValue(clkDivider)    TICK_TOCK_SetDividerRegister((clkDivider) - 1u, 1u)
#define TICK_TOCK_SetMode(clkMode)               TICK_TOCK_SetModeRegister(clkMode)
#define TICK_TOCK_SetSource(clkSource)           TICK_TOCK_SetSourceRegister(clkSource)
#if defined(TICK_TOCK__CFG3)
#define TICK_TOCK_SetPhase(clkPhase)             TICK_TOCK_SetPhaseRegister(clkPhase)
#define TICK_TOCK_SetPhaseValue(clkPhase)        TICK_TOCK_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(TICK_TOCK__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define TICK_TOCK_CLKEN              (* (reg8 *) TICK_TOCK__PM_ACT_CFG)
#define TICK_TOCK_CLKEN_PTR          ((reg8 *) TICK_TOCK__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define TICK_TOCK_CLKSTBY            (* (reg8 *) TICK_TOCK__PM_STBY_CFG)
#define TICK_TOCK_CLKSTBY_PTR        ((reg8 *) TICK_TOCK__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define TICK_TOCK_DIV_LSB            (* (reg8 *) TICK_TOCK__CFG0)
#define TICK_TOCK_DIV_LSB_PTR        ((reg8 *) TICK_TOCK__CFG0)
#define TICK_TOCK_DIV_PTR            ((reg16 *) TICK_TOCK__CFG0)

/* Clock MSB divider configuration register. */
#define TICK_TOCK_DIV_MSB            (* (reg8 *) TICK_TOCK__CFG1)
#define TICK_TOCK_DIV_MSB_PTR        ((reg8 *) TICK_TOCK__CFG1)

/* Mode and source configuration register */
#define TICK_TOCK_MOD_SRC            (* (reg8 *) TICK_TOCK__CFG2)
#define TICK_TOCK_MOD_SRC_PTR        ((reg8 *) TICK_TOCK__CFG2)

#if defined(TICK_TOCK__CFG3)
/* Analog clock phase configuration register */
#define TICK_TOCK_PHASE              (* (reg8 *) TICK_TOCK__CFG3)
#define TICK_TOCK_PHASE_PTR          ((reg8 *) TICK_TOCK__CFG3)
#endif /* defined(TICK_TOCK__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define TICK_TOCK_CLKEN_MASK         TICK_TOCK__PM_ACT_MSK
#define TICK_TOCK_CLKSTBY_MASK       TICK_TOCK__PM_STBY_MSK

/* CFG2 field masks */
#define TICK_TOCK_SRC_SEL_MSK        TICK_TOCK__CFG2_SRC_SEL_MASK
#define TICK_TOCK_MODE_MASK          (~(TICK_TOCK_SRC_SEL_MSK))

#if defined(TICK_TOCK__CFG3)
/* CFG3 phase mask */
#define TICK_TOCK_PHASE_MASK         TICK_TOCK__CFG3_PHASE_DLY_MASK
#endif /* defined(TICK_TOCK__CFG3) */

#endif /* CY_CLOCK_TICK_TOCK_H */


/* [] END OF FILE */
