
//`#start header` -- edit after this line, do not edit this line
// ================================================================================
//
// Copyright (C) 2013 Stomping Ground Forum (sgforum.info)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//
// ================================================================================

`include "cypress.v"
//`#end` -- edit above this line, do not edit this line

module PWM24DP (
	input   wire CLK,
	input   wire RST,
    output  wire PWM_OUT
);

//`#start body` -- edit after this line, do not edit this line

localparam PHASE_LD  = 3'h0;  // Load A0 with D0        (step 1)
localparam PHASE_CNT = 3'h1;  // Count A0 down to zero  (step 2)

localparam PULSE_LD  = 3'h4;  // Load A1 with D1        (step 3)
localparam PULSE_CNT = 3'h5;  // Count A1 down to zero  (step 4)

localparam WAIT_LD   = 3'h2;  // Load A0 with F0        (step 5)
localparam WAIT_CNT  = 3'h3;  // Count A0 down to zero  (step 6)

reg [2:0] state;
wire [2:0] tc0;
wire [2:0] tc1;

assign PWM_OUT = state[2];

always @ (posedge CLK)
begin
	if (RST == 1'b1)
	begin
		state <= PHASE_LD;
	end
	else
	begin
		case(state)
		
			PHASE_LD:       // Load A0 with D0
			begin
				state <= PHASE_CNT;
			end
			
			PHASE_CNT:      // Count A0 down to zero
			begin
                if (tc0[2] == 1'b1)
                begin
				    state <= PULSE_LD;
                end
			end
			
			PULSE_LD:       // Load A1 with D1
			begin
				state <= PULSE_CNT;
			end
			
			PULSE_CNT:      // Count A1 down to zero
			begin
                if (tc1[2] == 1'b1)
                begin
				    state <= WAIT_LD;
                end
			end
			
			WAIT_LD:        // Load A0 with F0
			begin
				state <= WAIT_CNT;
			end
			
			WAIT_CNT:       // Count A0 down to zero
			begin
                if (tc0[2] == 1'b1)
                begin
				    state <= PHASE_LD;
                end
			end
		endcase
	end
end


//`#end` -- edit above this line, do not edit this line
cy_psoc3_dp24 #(.a0_init_a(0), .a1_init_a(0), .d0_init_a(0), 
.d1_init_a(0), .a0_init_b(0), .a1_init_b(0), 
.d0_init_b(0), .d1_init_b(0), .a0_init_c(0), 
.a1_init_c(0), .d0_init_c(0), .d1_init_c(0), 

.cy_dpconfig_a(
{
    `CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC___D0, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM0:  PHASE_LD -- Load D0 -> A0*/
    `CS_ALU_OP__DEC, `CS_SRCA_A0, `CS_SRCB_A0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC__ALU, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM1:  PHASE_CNT -- Decrement A0*/
    `CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_A0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC___F0, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM2:  WAIT_LD -- Load F0 -> A0*/
    `CS_ALU_OP__DEC, `CS_SRCA_A0, `CS_SRCB_A0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC__ALU, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM3:  WAIT_CNT -- Decrement A0*/
    `CS_ALU_OP_PASS, `CS_SRCA_A1, `CS_SRCB_D1,
    `CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC___D1,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGB, `CS_SI_SEL_CFGB,
    `CS_CMP_SEL_CFGB, /*CFGRAM4:  PULSE_LD -- Load D1 -> A1*/
    `CS_ALU_OP__DEC, `CS_SRCA_A1, `CS_SRCB_A1,
    `CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC__ALU,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGB, `CS_SI_SEL_CFGB,
    `CS_CMP_SEL_CFGB, /*CFGRAM5:  PULSE_CNT -- Decrement A1*/
    `CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM6:  */
    `CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM7:  */
    8'hFF, 8'hFF,  /*CFG9:        */
    8'hFF, 8'hFF,  /*CFG11-10:        */
    `SC_CMPB_A1_A0, `SC_CMPA_A0_A0, `SC_CI_B_ARITH,
    `SC_CI_A_ARITH, `SC_C1_MASK_DSBL, `SC_C0_MASK_DSBL,
    `SC_A_MASK_DSBL, `SC_DEF_SI_0, `SC_SI_B_DEFSI,
    `SC_SI_A_DEFSI, /*CFG13-12:  Set A and B compares*/
    `SC_A0_SRC_ACC, `SC_SHIFT_SL, 1'h0,
    1'h0, `SC_FIFO1_BUS, `SC_FIFO0_BUS,
    `SC_MSB_DSBL, `SC_MSB_BIT0, `SC_MSB_NOCHN,
    `SC_FB_NOCHN, `SC_CMP1_NOCHN,
    `SC_CMP0_NOCHN, /*CFG15-14:        */
    10'h00, `SC_FIFO_CLK__DP,`SC_FIFO_CAP_AX,
    `SC_FIFO_LEVEL,`SC_FIFO_ASYNC,`SC_EXTCRC_DSBL,
    `SC_WRK16CAT_DSBL /*CFG17-16:  Set Async*/
}
), .cy_dpconfig_b(
{
    `CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC___D0, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM0:  PHASE_LD -- Load D0 -> A0*/
    `CS_ALU_OP__DEC, `CS_SRCA_A0, `CS_SRCB_A0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC__ALU, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM1:  PHASE_CNT -- Decrement A0*/
    `CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_A0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC___F0, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM2:  WAIT_LD -- Load F0 -> A0*/
    `CS_ALU_OP__DEC, `CS_SRCA_A0, `CS_SRCB_A0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC__ALU, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM3:  WAIT_CNT -- Decrement A0*/
    `CS_ALU_OP_PASS, `CS_SRCA_A1, `CS_SRCB_D1,
    `CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC___D1,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGB, `CS_SI_SEL_CFGB,
    `CS_CMP_SEL_CFGB, /*CFGRAM4:  PULSE_LD -- Load D1 -> A1*/
    `CS_ALU_OP__DEC, `CS_SRCA_A1, `CS_SRCB_A1,
    `CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC__ALU,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGB, `CS_SI_SEL_CFGB,
    `CS_CMP_SEL_CFGB, /*CFGRAM5:  PULSE_CNT -- Decrement A1*/
    `CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM6:  */
    `CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM7:  */
    8'hFF, 8'hFF,  /*CFG9:        */
    8'hFF, 8'hFF,  /*CFG11-10:        */
    `SC_CMPB_A1_A0, `SC_CMPA_A0_A0, `SC_CI_B_CHAIN,
    `SC_CI_A_CHAIN, `SC_C1_MASK_DSBL, `SC_C0_MASK_DSBL,
    `SC_A_MASK_DSBL, `SC_DEF_SI_0, `SC_SI_B_DEFSI,
    `SC_SI_A_DEFSI, /*CFG13-12:  Set A and B compares (Chained)*/
    `SC_A0_SRC_ACC, `SC_SHIFT_SL, 1'h0,
    1'h0, `SC_FIFO1_BUS, `SC_FIFO0_BUS,
    `SC_MSB_DSBL, `SC_MSB_BIT0, `SC_MSB_NOCHN,
    `SC_FB_NOCHN, `SC_CMP1_CHNED,
    `SC_CMP0_CHNED, /*CFG15-14:  Chained*/
    10'h00, `SC_FIFO_CLK__DP,`SC_FIFO_CAP_AX,
    `SC_FIFO_LEVEL,`SC_FIFO_ASYNC,`SC_EXTCRC_DSBL,
    `SC_WRK16CAT_DSBL /*CFG17-16:  Set Async*/
}
), .cy_dpconfig_c(
{
    `CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC___D0, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM0:  PHASE_LD -- Load D0 -> A0*/
    `CS_ALU_OP__DEC, `CS_SRCA_A0, `CS_SRCB_A0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC__ALU, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM1:  PHASE_CNT -- Decrement A0*/
    `CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_A0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC___F0, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM2:  WAIT_LD -- Load F0 -> A0*/
    `CS_ALU_OP__DEC, `CS_SRCA_A0, `CS_SRCB_A0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC__ALU, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM3:  WAIT_CNT -- Decrement A0*/
    `CS_ALU_OP_PASS, `CS_SRCA_A1, `CS_SRCB_D1,
    `CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC___D1,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGB, `CS_SI_SEL_CFGB,
    `CS_CMP_SEL_CFGB, /*CFGRAM4:  PULSE_LD -- Load D1 -> A1*/
    `CS_ALU_OP__DEC, `CS_SRCA_A1, `CS_SRCB_A1,
    `CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC__ALU,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGB, `CS_SI_SEL_CFGB,
    `CS_CMP_SEL_CFGB, /*CFGRAM5:  PULSE_CNT -- Decrement A1*/
    `CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM6:  */
    `CS_ALU_OP_PASS, `CS_SRCA_A0, `CS_SRCB_D0,
    `CS_SHFT_OP_PASS, `CS_A0_SRC_NONE, `CS_A1_SRC_NONE,
    `CS_FEEDBACK_DSBL, `CS_CI_SEL_CFGA, `CS_SI_SEL_CFGA,
    `CS_CMP_SEL_CFGA, /*CFGRAM7:  */
    8'hFF, 8'hFF,  /*CFG9:        */
    8'hFF, 8'hFF,  /*CFG11-10:        */
    `SC_CMPB_A1_A0, `SC_CMPA_A0_A0, `SC_CI_B_CHAIN,
    `SC_CI_A_CHAIN, `SC_C1_MASK_DSBL, `SC_C0_MASK_DSBL,
    `SC_A_MASK_DSBL, `SC_DEF_SI_0, `SC_SI_B_DEFSI,
    `SC_SI_A_DEFSI, /*CFG13-12:  Set A and B compares (Chained)*/
    `SC_A0_SRC_ACC, `SC_SHIFT_SL, 1'h0,
    1'h0, `SC_FIFO1_BUS, `SC_FIFO0_BUS,
    `SC_MSB_DSBL, `SC_MSB_BIT0, `SC_MSB_NOCHN,
    `SC_FB_NOCHN, `SC_CMP1_CHNED,
    `SC_CMP0_CHNED, /*CFG15-14:  Chained*/
    10'h00, `SC_FIFO_CLK__DP,`SC_FIFO_CAP_AX,
    `SC_FIFO_LEVEL,`SC_FIFO_ASYNC,`SC_EXTCRC_DSBL,
    `SC_WRK16CAT_DSBL /*CFG17-16:  Set Async*/
}
)) PWM24DP(
        /*  input                   */  .reset(RST),
        /*  input                   */  .clk(CLK),
        /*  input   [02:00]         */  .cs_addr(state),
        /*  input                   */  .route_si(1'b0),
        /*  input                   */  .route_ci(1'b0),
        /*  input                   */  .f0_load(1'b0),
        /*  input                   */  .f1_load(1'b0),
        /*  input                   */  .d0_load(1'b0),
        /*  input                   */  .d1_load(1'b0),
        /*  output  [02:00]                  */  .ce0(),
        /*  output  [02:00]                  */  .cl0(),
        /*  output  [02:00]                  */  .z0(tc0),
        /*  output  [02:00]                  */  .ff0(),
        /*  output  [02:00]                  */  .ce1(),
        /*  output  [02:00]                  */  .cl1(),
        /*  output  [02:00]                  */  .z1(tc1),
        /*  output  [02:00]                  */  .ff1(),
        /*  output  [02:00]                  */  .ov_msb(),
        /*  output  [02:00]                  */  .co_msb(),
        /*  output  [02:00]                  */  .cmsb(),
        /*  output  [02:00]                  */  .so(),
        /*  output  [02:00]                  */  .f0_bus_stat(),
        /*  output  [02:00]                  */  .f0_blk_stat(),
        /*  output  [02:00]                  */  .f1_bus_stat(),
        /*  output  [02:00]                  */  .f1_blk_stat()
);
endmodule
//`#start footer` -- edit after this line, do not edit this line
//`#end` -- edit above this line, do not edit this line





